<?php
set_time_limit(300); // 设置脚本最大执行时间为60秒
session_start();

// 检查是否已安装
$error = "";
$progress = [];
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $host = $_POST['db_host'];
    $user = $_POST['db_user'];
    $pass = $_POST['db_pass'];
    $dbname = $_POST['db_name'];

    // 创建数据库连接
    $conn = new mysqli($host, $user, $pass);
    if ($conn->connect_error) {
        $error = "数据库连接失败: " . $conn->connect_error;
    } else {
        $progress[] = "成功连接到数据库服务器";

        // 创建数据库
        if ($conn->query("CREATE DATABASE IF NOT EXISTS `$dbname`")) {
            $progress[] = "数据库 `$dbname` 创建成功";
        } else {
            $error = "创建数据库失败: " . $conn->error;
        }

        $conn->select_db($dbname);

        // 读取SQL文件并执行
        $sql_file = "./ca417.sql";
        if (file_exists($sql_file)) {
            $sql = file_get_contents($sql_file);
            $queries = explode(";", $sql);
            foreach ($queries as $query) {
                if (trim($query) != "") {
                    $conn->query($query);
                }
            }
            echo "<script>alert('数据库安装成功，进入下一步！'); window.location = 'set.php';</script>";
            exit;
        } else {
            $error = "找不到 SQL 文件: $sql_file";
        }
    }
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>系统安装 - 副食品系统</title>
    <link rel="stylesheet" href="/static/css/style.css">
    <style>
        body {
            background: linear-gradient(135deg, #2196F3 0%, #4FC3F7 100%);
            min-height: 100vh;
            display: flex;
            align-items: center;
        }

        .container {
            max-width: 800px;
            margin: 2rem auto;
            padding: 0 1rem;
        }

        .install-card {
            background: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1);
            padding: 2rem;
        }

        .form-title {
            text-align: center;
            color: #2c3e50;
            margin-bottom: 1.5rem;
        }

        .form-group {
            margin-bottom: 1.5rem;
        }

        label {
            display: block;
            margin-bottom: 0.5rem;
            font-weight: 500;
            color: rgb(0, 0, 0);
        }

        input {
            width: 100%;
            padding: 0.75rem;
            border: 1px solid #e2e8f0;
            border-radius: 4px;
            transition: border-color 0.3s ease;
        }

        input:focus {
            border-color: #4299e1;
            outline: none;
        }

        .btn-primary {
            width: 100%;
            padding: 0.75rem;
            background: #4299e1;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            transition: background 0.3s ease;
        }

        .btn-primary:hover {
            background: #3182ce;
        }

        .alert {
            padding: 1rem;
            border-radius: 4px;
            margin: 1rem 0;
        }

        .error {
            background: #fff5f5;
            color: #c53030;
            border: 1px solid #fc8181;
        }

        .success {
            background: #f0fff4;
            color: #2f855a;
            border: 1px solid #68d391;
        }

        .progress-list {
            margin: 1rem 0;
            padding-left: 1.5rem;
        }

        .progress-item {
            color: #4a5568;
            margin-bottom: 0.5rem;
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="install-card">
            <h1 class="form-title">副食品系统安装</h1>

            <?php if ($_SERVER["REQUEST_METHOD"] == "POST"): ?>
                <?php if ($error): ?>
                    <div class="alert error">
                        <h3>安装遇到问题</h3>
                        <p><?= $error ?></p>
                    </div>
                <?php else: ?>
                    <div class="alert success">
                        <h3>安装进度</h3>
                        <ul class="progress-list">
                            <?php foreach ($progress as $msg): ?>
                                <li class="progress-item">✔️ <?= $msg ?></li>
                            <?php endforeach; ?>
                        </ul>
                    </div>
                <?php endif; ?>
            <?php endif; ?>

            <form method="post">
                <div class="form-group">
                    <label>数据库主机</label>
                    <input type="text" name="db_host" required value="localhost">
                </div>

                <div class="form-group">
                    <label>数据库名称</label>
                    <input type="text" name="db_name" required>
                </div>

                <div class="form-group">
                    <label>数据库用户名</label>
                    <input type="text" name="db_user" required>
                </div>

                <div class="form-group">
                    <label>数据库密码</label>
                    <input type="password" name="db_pass">
                </div>

                <button type="submit" class="btn-primary">开始安装</button>
            </form>
        </div>
    </div>
</body>

</html>