<?php
session_start();
require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取当前页面
$page = isset($_GET['page']) ? $_GET['page'] : 'popular';

// 页面标题
$pageTitle = '数据分析';
$subTitle = '';

// 获取子页面内容
$contentFile = '';
switch ($page) {
    case 'popular':
        $contentFile = 'popular.php';
        $subTitle = '热门商品分析';
        break;
    case 'inventory':
        $contentFile = 'inventory.php';
        $subTitle = '库存分析';
        break;
    case 'sales':
        $contentFile = 'sales.php';
        $subTitle = '销售分析';
        break;
    case 'profit':
        $contentFile = 'profit.php';
        $subTitle = '利润分析';
        break;
    case 'financial':
        $contentFile = 'financial.php';
        $subTitle = '财务报表';
        break;
    case 'update_stats':
        $contentFile = 'update_stats.php';
        $subTitle = '更新统计数据';
        break;
    default:
        $contentFile = 'popular.php';
        $subTitle = '热门商品分析';
}

// 检查文件是否存在
if (!file_exists($contentFile)) {
    $contentFile = 'popular.php';
    $subTitle = '热门商品分析';
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $subTitle; ?> - <?php echo $pageTitle; ?> - <?php echo SITE_NAME; ?></title>
    <link rel="stylesheet" href="../../css/style.css">
    <style>
        .module-nav-divider {
            height: 1px;
            background-color: rgba(255, 255, 255, 0.2);
            margin: 10px 0;
        }
    </style>
</head>

<body>
    <header class="main-header">
        <div class="user-info">
            <span class="user-name"><?php echo isset($_SESSION['full_name']) ? $_SESSION['full_name'] : '用户'; ?></span>
            <span class="user-role"><?php echo $_SESSION['user_role']; ?></span>
        </div>

        <div class="site-title">
            <h1><?php echo SITE_NAME; ?></h1>
            <p><?php echo SITE_SUBTITLE; ?></p>
        </div>

        <div class="header-actions">
            <a href="../../logout.php" class="btn btn-logout">退出登录</a>
        </div>
    </header>

    <div class="module-layout">
        <aside class="module-sidebar">
            <div class="module-sidebar-header">
                <h2><?php echo $pageTitle; ?></h2>
            </div>

            <nav class="module-nav">
                <a href="../../home.php" class="module-nav-item">返回首页</a>
                <a href="index.php?page=popular" class="module-nav-item <?php echo $page == 'popular' ? 'active' : ''; ?>">热门商品分析</a>
                <a href="index.php?page=inventory" class="module-nav-item <?php echo $page == 'inventory' ? 'active' : ''; ?>">库存分析</a>
                <a href="index.php?page=sales" class="module-nav-item <?php echo $page == 'sales' ? 'active' : ''; ?>">销售分析</a>
                <a href="index.php?page=profit" class="module-nav-item <?php echo $page == 'profit' ? 'active' : ''; ?>">利润分析</a>
                <a href="index.php?page=financial" class="module-nav-item <?php echo $page == 'financial' ? 'active' : ''; ?>">财务报表</a>
                <div class="module-nav-divider"></div>
                <a href="index.php?page=update_stats" class="module-nav-item <?php echo $page == 'update_stats' ? 'active' : ''; ?>">更新统计数据</a>
            </nav>
        </aside>

        <main class="module-content">
            <div class="module-content-header">
                <h2><?php echo $subTitle; ?></h2>
            </div>
            <?php
            // 包含子页面内容
            if (file_exists($contentFile)) {
                include $contentFile;
            } else {
                echo "<div class='alert alert-error'>找不到页面文件: {$contentFile}</div>";
            }
            ?>
        </main>
    </div>

    <footer class="main-footer">
        <p>&copy; <?php echo date('Y'); ?> <?php echo SITE_NAME; ?> - 版权所有</p>
    </footer>
</body>

</html>