<?php
// 防止直接访问
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 确保$conn变量存在
if (!isset($conn) || $conn === null) {
    die("数据库连接失败");
}

// 处理删除仓库操作
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $warehouse_id = (int)$_GET['id'];

    try {
        // 检查仓库是否存在
        $checkSql = "SELECT warehouse_id FROM warehouses WHERE warehouse_id = ?";
        $checkStmt = $conn->prepare($checkSql);
        if ($checkStmt) {
            $checkStmt->bind_param("i", $warehouse_id);
            $checkStmt->execute();
            $checkResult = $checkStmt->get_result();

            if ($checkResult->num_rows > 0) {
                // 检查仓库是否有关联的库存记录
                $inventorySql = "SELECT COUNT(*) as count FROM inventory WHERE warehouse_id = ?";
                $inventoryStmt = $conn->prepare($inventorySql);
                $inventoryStmt->bind_param("i", $warehouse_id);
                $inventoryStmt->execute();
                $inventoryResult = $inventoryStmt->get_result();
                $inventoryCount = $inventoryResult->fetch_assoc()['count'];
                $inventoryStmt->close();

                if ($inventoryCount > 0) {
                    header("Location: index.php?page=warehouse&message=仓库已有关联库存记录，无法删除&type=error");
                    exit;
                }

                // 检查仓库是否有关联的调拨记录
                $transferSql = "SELECT COUNT(*) as count FROM inventory_transfers WHERE from_warehouse_id = ? OR to_warehouse_id = ?";
                $transferStmt = $conn->prepare($transferSql);
                if ($transferStmt) {
                    $transferStmt->bind_param("ii", $warehouse_id, $warehouse_id);
                    $transferStmt->execute();
                    $transferResult = $transferStmt->get_result();
                    $transferCount = $transferResult->fetch_assoc()['count'];
                    $transferStmt->close();

                    if ($transferCount > 0) {
                        header("Location: index.php?page=warehouse&message=仓库已有关联调拨记录，无法删除&type=error");
                        exit;
                    }
                } else {
                    throw new Exception("准备查询调拨记录失败: " . $conn->error);
                }

                // 删除仓库
                $deleteSql = "DELETE FROM warehouses WHERE warehouse_id = ?";
                $deleteStmt = $conn->prepare($deleteSql);
                if ($deleteStmt) {
                    $deleteStmt->bind_param("i", $warehouse_id);
                    if ($deleteStmt->execute()) {
                        // 记录操作日志
                        $warehouse_name = $checkResult->fetch_assoc()['warehouse_name'] ?? "ID: $warehouse_id";
                        $operationDetails = "删除仓库: $warehouse_name";
                        log_operation($_SESSION['user_id'], '删除仓库', $operationDetails);

                        header("Location: index.php?page=warehouse&message=仓库删除成功&type=success");
                    } else {
                        header("Location: index.php?page=warehouse&message=仓库删除失败: " . $conn->error . "&type=error");
                    }
                    $deleteStmt->close();
                } else {
                    throw new Exception("准备删除仓库语句失败: " . $conn->error);
                }
            } else {
                header("Location: index.php?page=warehouse&message=仓库不存在&type=error");
            }
            $checkStmt->close();
        }
    } catch (Exception $e) {
        header("Location: index.php?page=warehouse&message=操作失败: " . $e->getMessage() . "&type=error");
    }
    exit;
}

// 处理添加/编辑仓库表单提交
$error = '';
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $warehouse_id = isset($_POST['warehouse_id']) ? (int)$_POST['warehouse_id'] : 0;
    $warehouse_name = trim($_POST['warehouse_name']);
    $location = trim($_POST['location']);
    $type = trim($_POST['type']);

    // 确保类型是有效的ENUM值
    $valid_types = ['headquarters', 'branch', 'store'];
    if (!in_array($type, $valid_types)) {
        $error = '仓库类型必须是: 总部(headquarters)、分仓(branch)或门店(store)';
    }
    // 验证表单数据
    elseif (empty($warehouse_name)) {
        $error = '仓库名称不能为空';
    } elseif (empty($type)) {
        $error = '仓库类型不能为空';
    } else {
        try {
            // 检查仓库名称是否重复
            $checkSql = "SELECT warehouse_id FROM warehouses WHERE warehouse_name = ? AND warehouse_id != ?";
            $checkStmt = $conn->prepare($checkSql);
            if ($checkStmt) {
                $checkStmt->bind_param("si", $warehouse_name, $warehouse_id);
                $checkStmt->execute();
                $checkResult = $checkStmt->get_result();

                if ($checkResult->num_rows > 0) {
                    $error = '仓库名称已存在';
                } else {
                    if ($warehouse_id > 0) {
                        // 更新仓库
                        $sql = "UPDATE warehouses SET 
                                warehouse_name = ?, 
                                location = ?, 
                                type = ?, 
                                updated_at = NOW() 
                                WHERE warehouse_id = ?";
                        $stmt = $conn->prepare($sql);
                        if ($stmt) {
                            $stmt->bind_param("sssi", $warehouse_name, $location, $type, $warehouse_id);

                            if ($stmt->execute()) {
                                // 记录操作日志
                                $operationDetails = "更新仓库: $warehouse_name";
                                log_operation($_SESSION['user_id'], '更新仓库', $operationDetails);

                                header("Location: index.php?page=warehouse&message=仓库更新成功&type=success");
                                exit;
                            } else {
                                $error = '仓库更新失败: ' . $conn->error;
                            }
                            $stmt->close();
                        } else {
                            $error = '准备更新仓库语句失败: ' . $conn->error;
                        }
                    } else {
                        // 添加仓库
                        $sql = "INSERT INTO warehouses (warehouse_name, location, type, created_at, updated_at) 
                                VALUES (?, ?, ?, NOW(), NOW())";
                        $stmt = $conn->prepare($sql);
                        if ($stmt) {
                            $stmt->bind_param("sss", $warehouse_name, $location, $type);

                            if ($stmt->execute()) {
                                // 记录操作日志
                                $operationDetails = "添加仓库: $warehouse_name";
                                log_operation($_SESSION['user_id'], '添加仓库', $operationDetails);

                                header("Location: index.php?page=warehouse&message=仓库添加成功&type=success");
                                exit;
                            } else {
                                $error = '仓库添加失败: ' . $conn->error;
                            }
                            $stmt->close();
                        } else {
                            $error = '准备添加仓库语句失败: ' . $conn->error;
                        }
                    }
                }
                $checkStmt->close();
            } else {
                $error = '检查仓库名称失败: ' . $conn->error;
            }
        } catch (Exception $e) {
            $error = '操作失败: ' . $e->getMessage();
        }
    }
}

// 获取当前操作
$action = isset($_GET['action']) ? $_GET['action'] : 'list';

// 获取仓库信息（用于编辑）
$warehouse = null;
if (($action == 'edit' || $action == 'view') && isset($_GET['id'])) {
    $warehouse_id = (int)$_GET['id'];
    $sql = "SELECT * FROM warehouses WHERE warehouse_id = ?";
    $stmt = $conn->prepare($sql);
    if ($stmt) {
        $stmt->bind_param("i", $warehouse_id);
        $stmt->execute();
        $result = $stmt->get_result();
        if ($result->num_rows > 0) {
            $warehouse = $result->fetch_assoc();
        }
        $stmt->close();
    } else {
        echo '<div class="alert alert-error">获取仓库信息失败: ' . $conn->error . '</div>';
    }
}

// 获取仓库列表
$warehouses = [];
if ($action == 'list') {
    // 处理搜索条件
    $whereClause = "";
    $params = [];
    $types = "";

    if (isset($_GET['keyword']) && !empty($_GET['keyword'])) {
        $keyword = "%" . $_GET['keyword'] . "%";
        $whereClause = "WHERE warehouse_name LIKE ? OR location LIKE ? OR type LIKE ?";
        $params = [$keyword, $keyword, $keyword];
        $types = "sss";
    }

    $sql = "SELECT * FROM warehouses $whereClause ORDER BY warehouse_id DESC";
    $stmt = $conn->prepare($sql);

    if ($stmt) {
        if (!empty($params)) {
            $stmt->bind_param($types, ...$params);
        }

        $stmt->execute();
        $result = $stmt->get_result();
        while ($row = $result->fetch_assoc()) {
            $warehouses[] = $row;
        }
        $stmt->close();
    } else {
        echo '<div class="alert alert-error">获取仓库列表失败: ' . $conn->error . '</div>';
    }
}

// 获取消息参数
$message = isset($_GET['message']) ? $_GET['message'] : '';
$messageType = isset($_GET['type']) ? $_GET['type'] : '';
?>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<!-- 显示错误信息 -->
<?php if (!empty($error)): ?>
    <div class="alert alert-error"><?php echo $error; ?></div>
<?php endif; ?>

<!-- jQuery库必须在Select2之前引入 -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<!-- 引入Select2库 -->
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>

<!-- 添加/编辑仓库表单 -->
<?php if ($action == 'add' || $action == 'edit'): ?>
    <div class="form-container">
        <h3><?php echo $action == 'add' ? '添加仓库' : '编辑仓库'; ?></h3>
        <form method="post" action="">
            <?php if ($action == 'edit' && $warehouse): ?>
                <input type="hidden" name="warehouse_id" value="<?php echo $warehouse['warehouse_id']; ?>">
            <?php endif; ?>

            <div class="form-group">
                <label for="warehouse_name">仓库名称 <span class="required">*</span></label>
                <input type="text" id="warehouse_name" name="warehouse_name" required value="<?php echo $action == 'edit' && $warehouse ? htmlspecialchars($warehouse['warehouse_name']) : ''; ?>">
            </div>

            <div class="form-group">
                <label for="location">仓库位置</label>
                <input type="text" id="location" name="location" value="<?php echo $action == 'edit' && $warehouse ? htmlspecialchars($warehouse['location']) : ''; ?>">
            </div>

            <div class="form-group">
                <label for="type">仓库类型</label>
                <select id="type" name="type" class="select2-warehouse-type">
                    <option value="headquarters" <?php echo $action == 'edit' && $warehouse && $warehouse['type'] == 'headquarters' ? 'selected' : ''; ?>>总部</option>
                    <option value="branch" <?php echo $action == 'edit' && $warehouse && $warehouse['type'] == 'branch' ? 'selected' : ''; ?>>分仓</option>
                    <option value="store" <?php echo $action == 'edit' && $warehouse && $warehouse['type'] == 'store' ? 'selected' : ''; ?>>门店</option>
                </select>
            </div>

            <div class="form-actions">
                <button type="submit" class="btn btn-primary">保存</button>
                <a href="index.php?page=warehouse" class="btn btn-secondary">取消</a>
            </div>
        </form>
    </div>
    <!-- 查看仓库详情 -->
<?php elseif ($action == 'view' && $warehouse): ?>
    <div class="detail-container">
        <h3>仓库详情</h3>
        <div class="detail-content">
            <div class="detail-group">
                <label>仓库ID:</label>
                <span><?php echo $warehouse['warehouse_id']; ?></span>
            </div>
            <div class="detail-group">
                <label>仓库名称:</label>
                <span><?php echo htmlspecialchars($warehouse['warehouse_name']); ?></span>
            </div>
            <div class="detail-group">
                <label>仓库位置:</label>
                <span><?php echo isset($warehouse['location']) ? htmlspecialchars($warehouse['location']) : '未设置'; ?></span>
            </div>
            <div class="detail-group">
                <label>仓库类型:</label>
                <span><?php echo getWarehouseTypeChinese(isset($warehouse['type']) ? $warehouse['type'] : ''); ?></span>
            </div>
            <div class="detail-group">
                <label>创建时间:</label>
                <span><?php echo isset($warehouse['created_at']) ? $warehouse['created_at'] : '未记录'; ?></span>
            </div>
            <div class="detail-group">
                <label>更新时间:</label>
                <span><?php echo isset($warehouse['updated_at']) ? $warehouse['updated_at'] : '未记录'; ?></span>
            </div>
        </div>
        <div class="detail-actions">
            <a href="index.php?page=warehouse&action=edit&id=<?php echo $warehouse['warehouse_id']; ?>" class="btn btn-primary">编辑</a>
            <a href="index.php?page=warehouse" class="btn btn-secondary">返回</a>
        </div>
    </div>
    <!-- 仓库列表 -->
<?php else: ?>
    <div class="module-tools">
        <div class="tool-left">
            <a href="index.php?page=warehouse&action=add" class="btn btn-primary">添加仓库</a>
        </div>
        <div class="tool-right">
            <form action="index.php" method="get" class="search-form">
                <input type="hidden" name="page" value="warehouse">
                <div class="search-group">
                    <input type="text" name="keyword" class="search-input" placeholder="搜索仓库名称/位置/类型" value="<?php echo isset($_GET['keyword']) ? htmlspecialchars($_GET['keyword']) : ''; ?>">
                </div>
                <button type="submit" class="btn btn-secondary">搜索</button>
                <?php if (isset($_GET['keyword']) && !empty($_GET['keyword'])): ?>
                    <a href="index.php?page=warehouse" class="btn btn-secondary">重置</a>
                <?php endif; ?>
            </form>
        </div>
    </div>

    <div class="data-wrapper">
        <table class="data-table">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>仓库名称</th>
                    <th>位置</th>
                    <th>类型</th>
                    <th>创建时间</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php if (count($warehouses) > 0): ?>
                    <?php foreach ($warehouses as $warehouse): ?>
                        <tr>
                            <td><?php echo $warehouse['warehouse_id']; ?></td>
                            <td><?php echo htmlspecialchars($warehouse['warehouse_name']); ?></td>
                            <td><?php echo htmlspecialchars($warehouse['location']); ?></td>
                            <td><?php echo getWarehouseTypeChinese(isset($warehouse['type']) ? $warehouse['type'] : ''); ?></td>
                            <td><?php echo $warehouse['created_at']; ?></td>
                            <td class="actions">
                                <a href="index.php?page=warehouse&action=view&id=<?php echo $warehouse['warehouse_id']; ?>" class="btn btn-secondary btn-sm">查看</a>
                                <a href="index.php?page=warehouse&action=edit&id=<?php echo $warehouse['warehouse_id']; ?>" class="btn btn-primary btn-sm">编辑</a>
                                <a href="index.php?page=warehouse&action=delete&id=<?php echo $warehouse['warehouse_id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('确定要删除此仓库吗？')">删除</a>
                                <a href="index.php?page=query&warehouse_id=<?php echo $warehouse['warehouse_id']; ?>" class="btn btn-success btn-sm">查看库存</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="9" class="text-center">暂无仓库数据</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>
<?php endif; ?>

<style>
    /* Select2样式修正 */
    .select2-container {
        width: 100% !important;
        margin-bottom: 10px;
    }

    .select2-container .select2-selection--single {
        height: 38px;
        padding: 5px;
    }

    .select2-container--default .select2-selection--single .select2-selection__rendered {
        line-height: 28px;
    }

    .select2-container--default .select2-selection--single .select2-selection__arrow {
        height: 36px;
    }
</style>

<script>
    // 初始化Select2
    $(document).ready(function() {
        $('.select2-warehouse-type').select2({
            placeholder: "请选择仓库类型",
            allowClear: true,
            width: '100%'
        });
    });
</script>