<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 公共函数声明
if (!function_exists('getActivityTypeName')) {
    function getActivityTypeName($type)
    {
        switch ($type) {
            case 'discount':
                return '折扣';
            case 'full_reduction':
                return '满减';
            case 'package':
                return '套餐';
            default:
                return '未知';
        }
    }
}

// 初始化消息变量
$message = '';
$messageType = '';

// 获取活动ID
$activity_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

if ($activity_id <= 0) {
    echo '<div class="alert alert-error">无效的活动ID</div>';
    echo '<div class="form-actions"><a href="index.php?page=activity" class="btn btn-primary">返回活动列表</a></div>';
    exit;
}

// 获取活动信息
$sql = "SELECT * FROM promotion_activities WHERE activity_id = ?";
$result = executeQuery($conn, $sql, 'i', [$activity_id]);

if (!$result['success'] || empty($result['data'])) {
    echo '<div class="alert alert-error">未找到该促销活动</div>';
    echo '<div class="form-actions"><a href="index.php?page=activity" class="btn btn-primary">返回活动列表</a></div>';
    exit;
}

$activity = $result['data'][0];

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // 获取表单数据
    $activity_name = isset($_POST['activity_name']) ? sanitize($_POST['activity_name']) : '';
    $activity_type = isset($_POST['activity_type']) ? sanitize($_POST['activity_type']) : '';
    $start_date = isset($_POST['start_date']) ? sanitize($_POST['start_date']) : '';
    $end_date = isset($_POST['end_date']) ? sanitize($_POST['end_date']) : '';
    $is_active = isset($_POST['is_active']) ? 1 : 0;
    $discount_rate = isset($_POST['discount_rate']) ? (float)($_POST['discount_rate']) : null;
    $min_amount = isset($_POST['min_amount']) ? (float)($_POST['min_amount']) : null;
    $reduction_amount = isset($_POST['reduction_amount']) ? (float)($_POST['reduction_amount']) : null;
    $description = isset($_POST['description']) ? sanitize($_POST['description']) : '';

    // 验证数据
    $errors = [];
    if (empty($activity_name)) {
        $errors[] = '活动名称不能为空';
    }

    if (empty($activity_type)) {
        $errors[] = '请选择活动类型';
    }

    if (empty($start_date)) {
        $errors[] = '开始日期不能为空';
    }

    if (empty($end_date)) {
        $errors[] = '结束日期不能为空';
    }

    if ($activity_type == 'discount') {
        if (empty($discount_rate) || $discount_rate < 0.01 || $discount_rate > 0.99) {
            $errors[] = '折扣率必须在0.01到0.99之间';
        }
    }

    if ($activity_type == 'full_reduction' && (empty($min_amount) || $min_amount <= 0)) {
        $errors[] = '满减类型活动的最低金额必须大于0';
    }

    if ($activity_type == 'full_reduction' && (empty($reduction_amount) || $reduction_amount <= 0)) {
        $errors[] = '满减类型活动的减免金额必须大于0';
    }

    // 检查日期有效性
    if (!empty($start_date) && !empty($end_date)) {
        $start_timestamp = strtotime($start_date);
        $end_timestamp = strtotime($end_date);

        if ($start_timestamp === false || $end_timestamp === false) {
            $errors[] = '日期格式无效';
        } elseif ($start_timestamp > $end_timestamp) {
            $errors[] = '开始日期不能晚于结束日期';
        }
    }

    // 如果没有错误，则保存数据
    if (empty($errors)) {
        // 准备SQL语句
        $sql = "UPDATE promotion_activities SET 
                activity_name = ?, 
                activity_type = ?, 
                start_date = ?, 
                end_date = ?, 
                is_active = ?, 
                discount_rate = ?, 
                min_amount = ?, 
                reduction_amount = ?, 
                description = ? 
                WHERE activity_id = ?";

        $stmt = $conn->prepare($sql);
        if ($stmt) {
            // 绑定参数
            $stmt->bind_param("ssssiiddsi", $activity_name, $activity_type, $start_date, $end_date, $is_active, $discount_rate, $min_amount, $reduction_amount, $description, $activity_id);

            // 执行
            if ($stmt->execute()) {
                // 记录操作日志
                $operationDetails = "用户 {$_SESSION['username']} 更新了促销活动：{$activity_name} (ID: {$activity_id})";
                log_operation($_SESSION['user_id'], '更新', $operationDetails);

                // 设置成功消息并重定向回列表页
                $_SESSION['message'] = '促销活动 "' . $activity_name . '" 更新成功';
                $_SESSION['message_type'] = 'success';

                // 重定向到活动列表页
                header("Location: index.php?page=activity");
                exit;
            } else {
                $message = '更新促销活动失败: ' . $stmt->error;
                $messageType = 'error';
            }
            $stmt->close();
        } else {
            $message = '系统错误: ' . $conn->error;
            $messageType = 'error';
        }
    } else {
        // 显示验证错误
        $message = implode('<br>', $errors);
        $messageType = 'error';
    }
}
?>

<div class="page-header">
    <h3>编辑促销活动</h3>
</div>

<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<div class="form-wrapper">
    <form action="index.php?page=activity&action=edit&id=<?php echo $activity_id; ?>" method="post" class="data-form">
        <div class="form-group">
            <label for="activity_name">活动名称 <span class="required">*</span></label>
            <input type="text" id="activity_name" name="activity_name" class="form-control" value="<?php echo htmlspecialchars($activity['activity_name']); ?>" required>
        </div>

        <div class="form-group">
            <label for="activity_type">活动类型 <span class="required">*</span></label>
            <select id="activity_type" name="activity_type" class="form-control" required>
                <option value="">请选择</option>
                <option value="discount" <?php echo $activity['activity_type'] == 'discount' ? 'selected' : ''; ?>>折扣</option>
                <option value="full_reduction" <?php echo $activity['activity_type'] == 'full_reduction' ? 'selected' : ''; ?>>满减</option>
                <option value="package" <?php echo $activity['activity_type'] == 'package' ? 'selected' : ''; ?>>套餐</option>
            </select>
        </div>

        <div class="form-row">
            <div class="form-group half">
                <label for="start_date">开始日期 <span class="required">*</span></label>
                <input type="date" id="start_date" name="start_date" class="form-control" value="<?php echo htmlspecialchars($activity['start_date']); ?>" required>
            </div>

            <div class="form-group half">
                <label for="end_date">结束日期 <span class="required">*</span></label>
                <input type="date" id="end_date" name="end_date" class="form-control" value="<?php echo htmlspecialchars($activity['end_date']); ?>" required>
            </div>
        </div>

        <div class="form-group">
            <label for="is_active">
                <input type="checkbox" id="is_active" name="is_active" <?php echo $activity['is_active'] ? 'checked' : ''; ?>>
                激活活动
            </label>
        </div>

        <div id="discount_fields" class="dynamic-fields" <?php echo $activity['activity_type'] !== 'discount' ? 'style="display: none;"' : ''; ?>>
            <div class="form-group discount-field">
                <label for="discount_rate">折扣率 <span class="required">*</span></label>
                <input type="number" id="discount_rate" name="discount_rate" class="form-control"
                    value="<?php echo isset($activity['discount_rate']) && $activity['discount_rate'] > 0 ? number_format($activity['discount_rate'], 2, '.', '') : '0.80'; ?>"
                    step="0.01" min="0.01" max="0.99">
                <small>请输入0.01到0.99之间的数字，表示折扣比例，如0.8表示8折</small>
            </div>
        </div>

        <div id="full_reduction_fields" class="dynamic-fields" style="display: <?php echo $activity['activity_type'] == 'full_reduction' ? 'block' : 'none'; ?>;">
            <div class="form-group">
                <label for="min_amount">最低金额 <span class="required">*</span></label>
                <input type="number" id="min_amount" name="min_amount" class="form-control"
                    value="<?php echo $activity['min_amount'] !== null ? number_format($activity['min_amount'], 2, '.', '') : ''; ?>"
                    step="0.01" min="0.01">
            </div>

            <div class="form-group">
                <label for="reduction_amount">减免金额 <span class="required">*</span></label>
                <input type="number" id="reduction_amount" name="reduction_amount" class="form-control"
                    value="<?php echo $activity['reduction_amount'] !== null ? number_format($activity['reduction_amount'], 2, '.', '') : ''; ?>"
                    step="0.01" min="0.01">
            </div>
        </div>

        <div class="form-group">
            <label for="description">活动描述</label>
            <textarea id="description" name="description" class="form-control" rows="4"><?php echo htmlspecialchars($activity['description']); ?></textarea>
        </div>

        <div class="form-actions" style="text-align: center;">
            <button type="submit" class="btn btn-primary">保存</button>
            <a href="index.php?page=activity" class="btn btn-secondary">取消</a>
            <a href="index.php?page=activity&action=products&id=<?php echo $activity_id; ?>" class="btn btn-info">管理关联商品</a>
        </div>
    </form>
</div>

<style>
    .form-wrapper {
        background-color: #f9f9f9;
        padding: 20px;
        border-radius: 5px;
        margin-bottom: 20px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .page-header {
        margin-bottom: 20px;
    }

    .data-form {
        max-width: 800px;
    }

    .form-group {
        margin-bottom: 15px;
    }

    .form-row {
        display: flex;
        flex-wrap: wrap;
        margin-right: -10px;
        margin-left: -10px;
    }

    .form-group.half {
        flex: 0 0 50%;
        max-width: 50%;
        padding-right: 10px;
        padding-left: 10px;
        box-sizing: border-box;
    }

    .form-control {
        display: block;
        width: 100%;
        padding: 8px 12px;
        font-size: 14px;
        line-height: 1.5;
        color: #495057;
        background-color: #fff;
        border: 1px solid #ced4da;
        border-radius: 4px;
        transition: border-color 0.15s ease-in-out;
    }

    .form-control:focus {
        border-color: #80bdff;
        outline: 0;
    }

    .form-actions {
        margin-top: 20px;
        padding-top: 15px;
        border-top: 1px solid #e9ecef;
    }

    .required {
        color: #dc3545;
    }

    label {
        font-weight: bold;
        margin-bottom: 5px;
        display: block;
    }

    small {
        display: block;
        margin-top: 5px;
        color: #6c757d;
    }

    @media (max-width: 767.98px) {
        .form-group.half {
            flex: 0 0 100%;
            max-width: 100%;
        }
    }

    .btn-info {
        background-color: #17a2b8;
        color: #fff;
    }

    .btn-info:hover {
        background-color: #138496;
        text-decoration: none;
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        const activityType = document.getElementById('activity_type');
        const discountFields = document.getElementById('discount_fields');
        const fullReductionFields = document.getElementById('full_reduction_fields');
        const discountRateInput = document.getElementById('discount_rate');
        const minAmountInput = document.getElementById('min_amount');
        const reductionAmountInput = document.getElementById('reduction_amount');

        // 初始化时更新字段可见性
        updateFieldsVisibility(activityType.value);

        // 监听活动类型变化
        activityType.addEventListener('change', function() {
            updateFieldsVisibility(this.value);
        });

        function updateFieldsVisibility(type) {
            // 先全部隐藏并移除必填属性
            discountFields.style.display = 'none';
            fullReductionFields.style.display = 'none';

            discountRateInput.removeAttribute('required');
            minAmountInput.removeAttribute('required');
            reductionAmountInput.removeAttribute('required');

            // 根据类型显示相应字段
            if (type === 'discount') {
                discountFields.style.display = 'block';
                discountRateInput.setAttribute('required', 'required');
            } else if (type === 'full_reduction') {
                fullReductionFields.style.display = 'block';
                minAmountInput.setAttribute('required', 'required');
                reductionAmountInput.setAttribute('required', 'required');
            }
        }
    });
</script>