 <?php
    // 防止直接访问此文件
    defined('IN_SYSTEM') || define('IN_SYSTEM', true);

    // 初始化变量
    $message = '';
    $messageType = '';

    // 检查会话中是否有消息
    if (isset($_SESSION['message']) && !empty($_SESSION['message'])) {
        $message = $_SESSION['message'];
        $messageType = isset($_SESSION['message_type']) ? $_SESSION['message_type'] : 'info';

        // 清除会话消息，防止刷新页面后重复显示
        unset($_SESSION['message']);
        unset($_SESSION['message_type']);
    }

    // 定义通用函数，使用 if(!function_exists) 避免重复声明
    if (!function_exists('getMemberStatusName')) {
        function getMemberStatusName($status)
        {
            switch ($status) {
                case 'active':
                    return '激活';
                case 'inactive':
                    return '停用';
                default:
                    return '未知';
            }
        }
    }

    if (!function_exists('getStatusClass')) {
        function getStatusClass($status)
        {
            return $status == 'active' ? 'success' : 'secondary';
        }
    }

    // 检查是否有action参数
    $action = isset($_GET['action']) ? $_GET['action'] : '';

    // 如果有action参数，则包含对应的文件
    if ($action) {
        $action_file = 'member_' . $action . '.php';
        if (file_exists($action_file)) {
            include_once $action_file;
            exit;
        }
    }

    // 获取会员列表参数
    $page = isset($_GET['listpage']) ? intval($_GET['listpage']) : 1;
    $limit = 10;
    $offset = ($page - 1) * $limit;

    // 获取搜索参数
    $keyword = isset($_GET['keyword']) ? sanitize($_GET['keyword']) : '';
    $status = isset($_GET['status']) && $_GET['status'] !== '' ? sanitize($_GET['status']) : '';
    $levelId = isset($_GET['level_id']) && $_GET['level_id'] !== '' ? intval($_GET['level_id']) : '';

    // 处理删除会员
    if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
        $memberId = intval($_GET['id']);

        // 删除会员
        $sql = "DELETE FROM members WHERE member_id = ?";
        $stmt = $conn->prepare($sql);
        if ($stmt) {
            $stmt->bind_param("i", $memberId);
            if ($stmt->execute()) {
                // 记录操作日志
                $operationDetails = "用户 {$_SESSION['username']} 删除了ID为{$memberId}的会员";
                log_operation($_SESSION['user_id'], '删除', $operationDetails);

                // 显示成功消息
                $message = '会员删除成功';
                $messageType = 'success';
            } else {
                $message = '会员删除失败: ' . $conn->error;
                $messageType = 'error';
            }
            $stmt->close();
        } else {
            $message = '系统错误: ' . $conn->error;
            $messageType = 'error';
        }
    }

    // 处理批量操作
    if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['batch_action']) && isset($_POST['selected_ids'])) {
        $action = $_POST['batch_action'];
        $selected_ids_str = $_POST['selected_ids'];

        if (!empty($selected_ids_str)) {
            $selected_ids = explode(',', $selected_ids_str);
            $selected_ids = array_map('intval', $selected_ids);

            if (!empty($selected_ids)) {
                $status = ($action == 'activate') ? 'active' : 'inactive';
                $placeholders = implode(',', array_fill(0, count($selected_ids), '?'));

                $sql = "UPDATE members SET status = ? WHERE member_id IN ($placeholders)";
                $stmt = $conn->prepare($sql);

                if ($stmt) {
                    $types = 's' . str_repeat('i', count($selected_ids));
                    $params = array_merge([$status], $selected_ids);
                    $stmt->bind_param($types, ...$params);

                    if ($stmt->execute()) {
                        $action_text = $action == 'activate' ? '激活' : '停用';
                        $message = '已成功' . $action_text . '所选会员';
                        $messageType = 'success';

                        // 记录操作日志
                        $operationDetails = "用户 {$_SESSION['username']} 批量{$action_text}了会员：" . implode(',', $selected_ids);
                        log_operation($_SESSION['user_id'], '批量操作', $operationDetails);
                    } else {
                        $message = '操作失败: ' . $conn->error;
                        $messageType = 'error';
                    }
                    $stmt->close();
                }
            } else {
                $message = '请选择要操作的会员';
                $messageType = 'error';
            }
        } else {
            $message = '请选择要操作的会员';
            $messageType = 'error';
        }
    }

    // 获取会员等级信息
    $levelSql = "SELECT * FROM member_levels ORDER BY min_points ASC";
    $levelResult = $conn->query($levelSql);
    $memberLevels = [];
    if ($levelResult) {
        while ($level = $levelResult->fetch_assoc()) {
            $memberLevels[$level['level_id']] = $level;
        }
    }

    // 构建查询
    $sql = "SELECT m.*, c.customer_name, c.phone, ml.level_name 
        FROM members m 
        INNER JOIN customers c ON m.customer_id = c.customer_id 
        INNER JOIN member_levels ml ON m.level_id = ml.level_id 
        WHERE 1=1";
    $countSql = "SELECT COUNT(*) AS total 
             FROM members m 
             INNER JOIN customers c ON m.customer_id = c.customer_id 
             INNER JOIN member_levels ml ON m.level_id = ml.level_id 
             WHERE 1=1";
    $params = [];
    $types = '';

    // 添加搜索条件
    if (!empty($keyword)) {
        $sql .= " AND (m.member_no LIKE ? OR c.customer_name LIKE ? OR c.phone LIKE ?)";
        $countSql .= " AND (m.member_no LIKE ? OR c.customer_name LIKE ? OR c.phone LIKE ?)";
        $params[] = "%$keyword%";
        $params[] = "%$keyword%";
        $params[] = "%$keyword%";
        $types .= 'sss';
    }

    if ($status !== '') {
        $sql .= " AND m.status = ?";
        $countSql .= " AND m.status = ?";
        $params[] = $status;
        $types .= 's';
    }

    if ($levelId !== '') {
        $sql .= " AND m.level_id = ?";
        $countSql .= " AND m.level_id = ?";
        $params[] = $levelId;
        $types .= 'i';
    }

    // 添加排序和分页
    $sql .= " ORDER BY m.member_id DESC LIMIT ?, ?";
    $params[] = $offset;
    $params[] = $limit;
    $types .= 'ii';

    // 执行查询
    $result = executeQuery($conn, $sql, $types, $params);
    $members = $result['success'] ? $result['data'] : [];

    // 获取总记录数
    $countResult = executeQuery($conn, $countSql, substr($types, 0, -2), array_slice($params, 0, -2));
    $total = $countResult['success'] && !empty($countResult['data']) ? $countResult['data'][0]['total'] : 0;
    ?>

 <div class="page-header">
     <div class="header-flex">
         <h3>会员管理</h3>
     </div>
 </div>

 <?php if (!empty($message)): ?>
     <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
 <?php endif; ?>

 <div class="module-tools">
     <div class="tools-left">
         <button onclick="executeBatchAction('activate')" class="btn btn-success">批量激活</button>
         <button onclick="executeBatchAction('deactivate')" class="btn btn-warning">批量停用</button>
     </div>
     <div class="tools-right">
         <a href="index.php?page=member&action=add" class="btn btn-primary">添加新会员</a>
     </div>
 </div>

 <!-- 批量操作表单 -->
 <form id="batch-form" action="index.php?page=member" method="post" class="batch-form">
     <input type="hidden" name="batch_action" id="batch_action" value="">
     <input type="hidden" name="selected_ids" id="selected_ids" value="">
 </form>

 <!-- 搜索表单 -->
 <div class="search-container">
     <form action="" method="get" class="search-form">
         <input type="hidden" name="page" value="member">
         <div class="form-group">
             <select name="status" class="form-control">
                 <option value="" <?php echo $status === '' ? 'selected' : ''; ?>>全部状态</option>
                 <option value="active" <?php echo $status === 'active' ? 'selected' : ''; ?>>激活</option>
                 <option value="inactive" <?php echo $status === 'inactive' ? 'selected' : ''; ?>>停用</option>
             </select>
         </div>
         <div class="form-group">
             <select name="level_id" class="form-control">
                 <option value="">全部等级</option>
                 <?php foreach ($memberLevels as $level): ?>
                     <option value="<?php echo $level['level_id']; ?>" <?php echo $levelId === $level['level_id'] ? 'selected' : ''; ?>>
                         <?php echo htmlspecialchars($level['level_name']); ?>
                     </option>
                 <?php endforeach; ?>
             </select>
         </div>
         <div class="form-group">
             <input type="text" name="keyword" placeholder="会员卡号/客户名称/电话" class="form-control search-input" value="<?php echo htmlspecialchars($keyword); ?>">
         </div>
         <div class="form-group">
             <button type="submit" class="btn btn-secondary">搜索</button>
             <a href="index.php?page=member" class="btn btn-secondary">重置</a>
         </div>
     </form>
 </div>

 <form method="post" id="items-form">
     <table class="data-table">
         <thead>
             <tr>
                 <th width="20"><input type="checkbox" id="select-all"></th>
                 <th width="60">ID</th>
                 <th width="120">会员卡号</th>
                 <th width="180">客户名称</th>
                 <th width="120">联系电话</th>
                 <th width="100">会员等级</th>
                 <th width="80">当前积分</th>
                 <th width="120">累计消费</th>
                 <th width="80">状态</th>
                 <th width="200">操作</th>
             </tr>
         </thead>
         <tbody>
             <?php if (count($members) > 0): ?>
                 <?php foreach ($members as $member): ?>
                     <tr>
                         <td><input type="checkbox" name="select_item[]" class="item-checkbox" value="<?php echo $member['member_id']; ?>"></td>
                         <td><?php echo $member['member_id']; ?></td>
                         <td><?php echo htmlspecialchars($member['member_no']); ?></td>
                         <td><?php echo htmlspecialchars($member['customer_name']); ?></td>
                         <td><?php echo htmlspecialchars($member['phone']); ?></td>
                         <td><?php echo htmlspecialchars($member['level_name']); ?></td>
                         <td><?php echo number_format($member['points']); ?></td>
                         <td><?php echo number_format($member['total_amount'], 2); ?></td>
                         <td>
                             <span class="badge badge-<?php echo getStatusClass($member['status']); ?>">
                                 <?php echo getMemberStatusName($member['status']); ?>
                             </span>
                         </td>
                         <td class="actions">
                             <a href="index.php?page=member&action=view&id=<?php echo $member['member_id']; ?>" class="btn btn-secondary btn-sm">查看</a>
                             <a href="index.php?page=member&action=edit&id=<?php echo $member['member_id']; ?>" class="btn btn-primary btn-sm">编辑</a>
                             <a href="index.php?page=member&action=delete&id=<?php echo $member['member_id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('确定要删除此会员吗？')">删除</a>
                         </td>
                     </tr>
                 <?php endforeach; ?>
             <?php else: ?>
                 <tr>
                     <td colspan="10" class="text-center">没有找到会员记录</td>
                 </tr>
             <?php endif; ?>
         </tbody>
     </table>
 </form>

 <!-- 分页 -->
 <?php
    $queryParams = [];
    if (!empty($keyword)) $queryParams[] = "keyword=" . urlencode($keyword);
    if ($status !== '') $queryParams[] = "status=$status";
    if ($levelId !== '') $queryParams[] = "level_id=$levelId";
    $queryString = !empty($queryParams) ? '&' . implode('&', $queryParams) : '';
    echo generate_pagination($total, $page, $limit, "index.php?page=member" . $queryString . "&listpage=");
    ?>

 <style>
     .badge {
         display: inline-block;
         padding: 3px 8px;
         font-size: 12px;
         font-weight: 600;
         border-radius: 3px;
         color: white;
     }

     .badge-success {
         background-color: #28a745;
     }

     .badge-secondary {
         background-color: #6c757d;
     }

     .text-center {
         text-align: center;
     }

     .form-control {
         padding: 8px 12px;
         border: 1px solid #ced4da;
         border-radius: 4px;
         min-width: 120px;
     }

     .btn-info {
         background-color: #17a2b8;
         color: #fff;
     }

     .btn-info:hover {
         background-color: #138496;
         text-decoration: none;
     }

     .data-table th,
     .data-table td {
         padding: 6px;
         vertical-align: middle;
     }

     .data-table {
         table-layout: fixed;
         width: 100%;
         border-collapse: collapse;
     }

     .actions {
         white-space: nowrap;
         min-height: 36px;
         display: flex;
         flex-wrap: wrap;
         align-items: center;
         justify-content: center;
         gap: 5px;
     }

     .btn-sm {
         padding: 4px 8px;
         font-size: 12px;
         line-height: 1.5;
     }

     th:last-child,
     td:last-child {
         text-align: center;
     }

     .header-flex {
         display: flex;
         justify-content: space-between;
         align-items: center;
         margin-bottom: 20px;
     }

     .module-tools {
         display: flex;
         justify-content: space-between;
         margin-bottom: 15px;
     }

     .tools-left,
     .tools-right {
         display: flex;
         gap: 10px;
     }

     .search-container {
         background-color: #f5f5f5;
         padding: 15px;
         border-radius: 5px;
         margin-bottom: 20px;
     }

     .search-form {
         display: flex;
         flex-wrap: wrap;
         gap: 10px;
         align-items: center;
     }

     .search-form .form-group {
         margin-bottom: 0;
     }

     .search-input {
         min-width: 250px;
     }

     .batch-form {
         display: inline;
     }

     @media (max-width: 768px) {

         .header-flex,
         .module-tools {
             flex-direction: column;
             align-items: flex-start;
         }

         .tools-right {
             margin-top: 10px;
         }

         .search-form {
             flex-direction: column;
             align-items: stretch;
         }

         .search-form .form-group {
             margin-bottom: 10px;
         }
     }
 </style>

 <script>
     document.addEventListener('DOMContentLoaded', function() {
         // 全选功能
         const selectAll = document.getElementById('select-all');
         const checkboxes = document.querySelectorAll('.item-checkbox');

         if (selectAll) {
             selectAll.addEventListener('change', function() {
                 checkboxes.forEach(checkbox => {
                     checkbox.checked = this.checked;
                 });
             });
         }

         checkboxes.forEach(checkbox => {
             checkbox.addEventListener('change', function() {
                 // 检查是否所有复选框都被选中
                 if (selectAll) {
                     const allChecked = Array.from(checkboxes).every(cb => cb.checked);
                     selectAll.checked = allChecked;
                 }
             });
         });
     });

     // 批量操作处理函数
     function executeBatchAction(action) {
         const checkboxes = document.querySelectorAll('.item-checkbox:checked');
         if (checkboxes.length === 0) {
             alert('请至少选择一个会员');
             return;
         }

         const ids = Array.from(checkboxes).map(cb => cb.value);

         // 设置隐藏字段的值
         document.getElementById('batch_action').value = action;
         document.getElementById('selected_ids').value = ids.join(',');

         // 提交表单
         document.getElementById('batch-form').submit();
     }
 </script>