<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 初始化消息变量
$message = '';
$messageType = '';

// 获取商品ID
$product_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

if ($product_id <= 0) {
    echo '<div class="alert alert-error">无效的商品ID</div>';
    echo '<div class="form-actions"><a href="index.php?page=points" class="btn btn-primary">返回商品列表</a></div>';
    exit;
}

// 获取商品信息
$sql = "SELECT * FROM point_products WHERE product_id = ?";
$stmt = $conn->prepare($sql);
if (!$stmt) {
    echo '<div class="alert alert-error">查询准备失败: ' . $conn->error . '</div>';
    echo '<div class="form-actions"><a href="index.php?page=points" class="btn btn-primary">返回商品列表</a></div>';
    exit;
}

$stmt->bind_param("i", $product_id);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows === 0) {
    echo '<div class="alert alert-error">未找到该积分商品</div>';
    echo '<div class="form-actions"><a href="index.php?page=points" class="btn btn-primary">返回商品列表</a></div>';
    exit;
}

$product = $result->fetch_assoc();
$stmt->close();

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // 获取表单数据
    $product_name = isset($_POST['product_name']) ? sanitize($_POST['product_name']) : '';
    $product_type = isset($_POST['product_type']) ? sanitize($_POST['product_type']) : '';
    $points_required = isset($_POST['points_required']) ? intval($_POST['points_required']) : 0;
    $stock_quantity = isset($_POST['stock_quantity']) ? intval($_POST['stock_quantity']) : 0;
    $is_active = isset($_POST['is_active']) ? 1 : 0;
    $description = isset($_POST['description']) ? sanitize($_POST['description']) : '';
    $end_date = isset($_POST['end_date']) && !empty($_POST['end_date']) ? sanitize($_POST['end_date']) : null;

    // 验证数据
    $errors = [];
    if (empty($product_name)) {
        $errors[] = '商品名称不能为空';
    }

    if (empty($product_type)) {
        $errors[] = '请选择商品类型';
    } elseif (!in_array($product_type, ['physical', 'voucher', 'coupon'])) {
        $errors[] = '无效的商品类型';
    }

    if ($points_required <= 0) {
        $errors[] = '所需积分必须大于0';
    }

    if ($stock_quantity < 0) {
        $errors[] = '库存数量不能为负数';
    }

    if ($end_date !== null && !preg_match('/^\d{4}-\d{2}-\d{2}$/', $end_date)) {
        $errors[] = '兑换截止日期格式无效，请使用YYYY-MM-DD格式';
    }

    // 如果没有错误，则更新数据
    if (empty($errors)) {
        // 准备SQL语句
        $sql = "UPDATE point_products SET 
                product_name = ?, 
                product_type = ?, 
                points_required = ?, 
                stock_quantity = ?, 
                is_active = ?, 
                description = ?, 
                end_date = ? 
                WHERE product_id = ?";

        $stmt = $conn->prepare($sql);
        if ($stmt) {
            // 绑定参数
            $stmt->bind_param("ssiisssi", $product_name, $product_type, $points_required, $stock_quantity, $is_active, $description, $end_date, $product_id);

            // 执行
            if ($stmt->execute()) {
                // 记录操作日志
                $operationDetails = "用户 {$_SESSION['username']} 更新了积分商品（ID：{$product_id}，名称：{$product_name}）";
                log_operation($_SESSION['user_id'], '更新', $operationDetails);

                // 设置成功消息并重定向回列表页
                $_SESSION['message'] = '积分商品更新成功！';
                $_SESSION['message_type'] = 'success';

                // 跳转到积分商品列表页面
                header("Location: index.php?page=points");
                exit;
            } else {
                $message = '更新积分商品失败: ' . $stmt->error;
                $messageType = 'error';
            }
            $stmt->close();
        } else {
            $message = '系统错误: ' . $conn->error;
            $messageType = 'error';
        }
    } else {
        // 显示验证错误
        $message = implode('<br>', $errors);
        $messageType = 'error';
    }
}
?>

<div class="page-header">
    <h3>编辑积分商品</h3>
</div>

<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<div class="form-wrapper">
    <form action="index.php?page=points&action=edit&id=<?php echo $product_id; ?>" method="post" class="data-form">
        <div class="form-group">
            <label for="product_name">商品名称 <span class="required">*</span></label>
            <input type="text" id="product_name" name="product_name" class="form-control" value="<?php echo htmlspecialchars(isset($_POST['product_name']) ? $_POST['product_name'] : $product['product_name']); ?>" required>
        </div>

        <div class="form-group">
            <label for="product_type">商品类型 <span class="required">*</span></label>
            <select id="product_type" name="product_type" class="form-control" required>
                <option value="">-- 请选择商品类型 --</option>
                <option value="physical" <?php echo (isset($_POST['product_type']) ? $_POST['product_type'] : $product['product_type']) == 'physical' ? 'selected' : ''; ?>>实物商品</option>
                <option value="voucher" <?php echo (isset($_POST['product_type']) ? $_POST['product_type'] : $product['product_type']) == 'voucher' ? 'selected' : ''; ?>>代金券</option>
                <option value="coupon" <?php echo (isset($_POST['product_type']) ? $_POST['product_type'] : $product['product_type']) == 'coupon' ? 'selected' : ''; ?>>优惠券</option>
            </select>
        </div>

        <div class="form-row">
            <div class="form-group half">
                <label for="points_required">所需积分 <span class="required">*</span></label>
                <input type="number" id="points_required" name="points_required" class="form-control" value="<?php echo isset($_POST['points_required']) ? intval($_POST['points_required']) : $product['points_required']; ?>" min="1" required>
            </div>

            <div class="form-group half">
                <label for="stock_quantity">库存数量 <span class="required">*</span></label>
                <input type="number" id="stock_quantity" name="stock_quantity" class="form-control" value="<?php echo isset($_POST['stock_quantity']) ? intval($_POST['stock_quantity']) : $product['stock_quantity']; ?>" min="0" required>
            </div>
        </div>

        <div class="form-row">
            <div class="form-group half">
                <label for="is_active">是否上架</label>
                <div class="checkbox-wrapper">
                    <input type="checkbox" id="is_active" name="is_active" value="1" <?php echo (isset($_POST['is_active']) ? $_POST['is_active'] : $product['is_active']) ? 'checked' : ''; ?>>
                    <label for="is_active" class="checkbox-label">上架此商品</label>
                </div>
            </div>

            <div class="form-group half">
                <label for="end_date">兑换截止日期</label>
                <input type="date" id="end_date" name="end_date" class="form-control" value="<?php echo htmlspecialchars(isset($_POST['end_date']) ? $_POST['end_date'] : ($product['end_date'] ?? '')); ?>">
                <small>可选，留空表示无截止日期</small>
            </div>
        </div>

        <div class="form-group">
            <label for="description">商品描述</label>
            <textarea id="description" name="description" class="form-control" rows="5"><?php echo htmlspecialchars(isset($_POST['description']) ? $_POST['description'] : $product['description']); ?></textarea>
        </div>

        <div class="form-actions">
            <button type="submit" class="btn btn-primary">保存</button>
            <a href="index.php?page=points" class="btn btn-secondary">取消</a>
            <a href="index.php?page=points&action=view&id=<?php echo $product_id; ?>" class="btn btn-info">查看详情</a>
        </div>
    </form>
</div>

<style>
    .form-wrapper {
        background-color: #f9f9f9;
        padding: 20px;
        border-radius: 5px;
        margin-bottom: 20px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .page-header {
        margin-bottom: 20px;
    }

    .data-form {
        max-width: 800px;
    }

    .form-group {
        margin-bottom: 15px;
    }

    .form-row {
        display: flex;
        flex-wrap: wrap;
        margin-right: -10px;
        margin-left: -10px;
    }

    .form-group.half {
        flex: 0 0 50%;
        max-width: 50%;
        padding-right: 10px;
        padding-left: 10px;
        box-sizing: border-box;
    }

    .form-control {
        display: block;
        width: 100%;
        padding: 8px 12px;
        font-size: 14px;
        line-height: 1.5;
        color: #495057;
        background-color: #fff;
        border: 1px solid #ced4da;
        border-radius: 4px;
        transition: border-color 0.15s ease-in-out;
    }

    .form-control:focus {
        border-color: #80bdff;
        outline: 0;
    }

    .form-actions {
        margin-top: 20px;
        padding-top: 15px;
        border-top: 1px solid #e9ecef;
    }

    .required {
        color: #dc3545;
    }

    label {
        font-weight: bold;
        margin-bottom: 5px;
        display: block;
    }

    .checkbox-wrapper {
        padding-top: 5px;
    }

    .checkbox-label {
        font-weight: normal;
        display: inline;
        margin-left: 5px;
    }

    small {
        display: block;
        margin-top: 5px;
        color: #6c757d;
    }

    @media (max-width: 767.98px) {
        .form-group.half {
            flex: 0 0 100%;
            max-width: 100%;
        }
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 商品类型改变时的事件处理
        document.getElementById('product_type').addEventListener('change', function() {
            updateFormBasedOnProductType(this.value);
        });

        // 初始化时根据商品类型更新表单
        updateFormBasedOnProductType(document.getElementById('product_type').value);

        function updateFormBasedOnProductType(productType) {
            const stockQuantityInput = document.getElementById('stock_quantity');

            // 如果是实物商品，确保库存数量必填
            if (productType === 'physical') {
                stockQuantityInput.setAttribute('required', 'required');
                stockQuantityInput.parentElement.querySelector('label').innerHTML = '库存数量 <span class="required">*</span>';
            } else {
                stockQuantityInput.removeAttribute('required');
                stockQuantityInput.parentElement.querySelector('label').innerHTML = '库存数量';
            }
        }
    });
</script>