<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 初始化消息变量
$message = '';
$messageType = '';

// 获取兑换状态中文名称
if (!function_exists('getRedemptionStatusName')) {
    function getRedemptionStatusName($status)
    {
        switch ($status) {
            case 'pending':
                return '待处理';
            case 'completed':
                return '已完成';
            case 'cancelled':
                return '已取消';
            default:
                return '未知';
        }
    }
}

// 获取兑换状态样式类
if (!function_exists('getRedemptionStatusClass')) {
    function getRedemptionStatusClass($status)
    {
        switch ($status) {
            case 'pending':
                return 'warning';
            case 'completed':
                return 'success';
            case 'cancelled':
                return 'secondary';
            default:
                return 'info';
        }
    }
}

// 获取商品类型中文名称
if (!function_exists('getProductTypeName')) {
    function getProductTypeName($type)
    {
        switch ($type) {
            case 'physical':
                return '实物商品';
            case 'voucher':
                return '代金券';
            case 'coupon':
                return '优惠券';
            default:
                return '未知';
        }
    }
}

// 获取筛选和分页参数
$page = isset($_GET['p']) ? intval($_GET['p']) : 1;
$limit = 10; // 每页显示数量
$offset = ($page - 1) * $limit;

$member_id = isset($_GET['member_id']) ? intval($_GET['member_id']) : 0;
$status = isset($_GET['status']) ? sanitize($_GET['status']) : '';
$search = isset($_GET['search']) ? sanitize($_GET['search']) : '';

// 构建查询条件
$conditions = [];
$params = [];
$types = '';

if ($member_id > 0) {
    $conditions[] = 'r.member_id = ?';
    $params[] = $member_id;
    $types .= 'i';
}

if (!empty($status)) {
    $conditions[] = 'r.status = ?';
    $params[] = $status;
    $types .= 's';
}

if (!empty($search)) {
    $conditions[] = '(p.product_name LIKE ? OR c.customer_name LIKE ? OR m.member_no LIKE ?)';
    $searchParam = "%{$search}%";
    $params[] = $searchParam;
    $params[] = $searchParam;
    $params[] = $searchParam;
    $types .= 'sss';
}

// 构建WHERE子句
$where = '';
if (!empty($conditions)) {
    $where = 'WHERE ' . implode(' AND ', $conditions);
}

// 获取记录总数
$countSql = "SELECT COUNT(*) as total 
             FROM point_redemptions r 
             JOIN members m ON r.member_id = m.member_id 
             JOIN customers c ON m.customer_id = c.customer_id 
             JOIN point_products p ON r.product_id = p.product_id 
             {$where}";
$countResult = executeQuery($conn, $countSql, $types, $params);
$total = $countResult['success'] ? $countResult['data'][0]['total'] : 0;

// 获取分页数据
$sql = "SELECT r.*, m.member_no, c.customer_name, p.product_name, p.product_type, 
               u.username as processed_by_name
        FROM point_redemptions r 
        JOIN members m ON r.member_id = m.member_id 
        JOIN customers c ON m.customer_id = c.customer_id 
        JOIN point_products p ON r.product_id = p.product_id 
        LEFT JOIN users u ON r.processed_by = u.user_id 
        {$where} 
        ORDER BY r.redemption_date DESC 
        LIMIT ?, ?";

$params[] = $offset;
$params[] = $limit;
$types .= 'ii';

$result = executeQuery($conn, $sql, $types, $params);
$redemptions = $result['success'] ? $result['data'] : [];

// 处理状态更新
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['update_status']) && isset($_POST['redemption_id']) && isset($_POST['new_status'])) {
    $redemption_id = intval($_POST['redemption_id']);
    $new_status = sanitize($_POST['new_status']);
    $notes = isset($_POST['notes']) ? sanitize($_POST['notes']) : '';

    // 验证状态值
    if (!in_array($new_status, ['pending', 'completed', 'cancelled'])) {
        $message = '无效的状态值';
        $messageType = 'error';
    } else {
        // 开始事务
        $conn->begin_transaction();

        try {
            // 获取兑换信息
            $redemptionSql = "SELECT r.*, p.product_type, p.product_name FROM point_redemptions r 
                             JOIN point_products p ON r.product_id = p.product_id 
                             WHERE r.redemption_id = ?";
            $redemptionResult = executeQuery($conn, $redemptionSql, 'i', [$redemption_id]);

            if (!$redemptionResult['success'] || empty($redemptionResult['data'])) {
                throw new Exception('找不到该兑换记录');
            }

            $redemption = $redemptionResult['data'][0];
            $old_status = $redemption['status'];

            // 如果状态已经是目标状态，直接返回
            if ($old_status == $new_status) {
                $message = '状态已经是' . getRedemptionStatusName($new_status);
                $messageType = 'info';
                $conn->rollback();
            } else {
                // 更新状态
                $updateSql = "UPDATE point_redemptions SET 
                              status = ?, 
                              notes = CONCAT(notes, '\n[" . date('Y-m-d H:i:s') . "] 状态从 " . getRedemptionStatusName($old_status) . " 变更为 " . getRedemptionStatusName($new_status) . "：" . $notes . "'), 
                              processed_by = ?, 
                              processed_date = NOW() 
                              WHERE redemption_id = ?";
                $updateResult = executeQuery($conn, $updateSql, 'sii', [$new_status, $_SESSION['user_id'], $redemption_id]);

                if (!$updateResult['success']) {
                    throw new Exception('更新状态失败：' . $updateResult['error']);
                }

                // 如果从已完成/已取消变更为待处理，或者从待处理变更为已完成，需要处理积分和库存
                if (($old_status == 'completed' || $old_status == 'cancelled') && $new_status == 'pending') {
                    // 从已完成变为待处理：减少会员积分（之前已退还）
                    if ($old_status == 'completed') {
                        // 减少会员积分
                        $updatePointsSql = "UPDATE members SET points = points - ? WHERE member_id = ?";
                        executeQuery($conn, $updatePointsSql, 'ii', [$redemption['points_used'], $redemption['member_id']]);

                        // 如果是实物商品，减少库存（之前已增加）
                        if ($redemption['product_type'] == 'physical') {
                            $updateStockSql = "UPDATE point_products SET stock_quantity = stock_quantity - ? WHERE product_id = ?";
                            executeQuery($conn, $updateStockSql, 'ii', [$redemption['quantity'], $redemption['product_id']]);
                        }

                        // 记录积分变动
                        $transactionSql = "INSERT INTO point_transactions (member_id, transaction_type, points, description, transaction_date, related_id, created_by) 
                                          VALUES (?, 'adjustment', ?, ?, NOW(), ?, ?)";
                        $description = "兑换状态变更（{$redemption['redemption_id']}）：从已完成变为待处理，扣减积分";
                        $points = -$redemption['points_used']; // 负值表示减少积分
                        executeQuery($conn, $transactionSql, 'iisii', [$redemption['member_id'], $points, $description, $redemption_id, $_SESSION['user_id']]);
                    }
                } else if ($old_status == 'pending' && $new_status == 'cancelled') {
                    // 从待处理变为已取消：退还会员积分
                    $updatePointsSql = "UPDATE members SET points = points + ? WHERE member_id = ?";
                    executeQuery($conn, $updatePointsSql, 'ii', [$redemption['points_used'], $redemption['member_id']]);

                    // 如果是实物商品，增加库存
                    if ($redemption['product_type'] == 'physical') {
                        $updateStockSql = "UPDATE point_products SET stock_quantity = stock_quantity + ? WHERE product_id = ?";
                        executeQuery($conn, $updateStockSql, 'ii', [$redemption['quantity'], $redemption['product_id']]);
                    }

                    // 记录积分变动
                    $transactionSql = "INSERT INTO point_transactions (member_id, transaction_type, points, description, transaction_date, related_id, created_by) 
                                      VALUES (?, 'adjustment', ?, ?, NOW(), ?, ?)";
                    $description = "兑换取消（{$redemption['redemption_id']}）：" . $redemption['product_name'];
                    executeQuery($conn, $transactionSql, 'iisii', [$redemption['member_id'], $redemption['points_used'], $description, $redemption_id, $_SESSION['user_id']]);
                }

                // 提交事务
                $conn->commit();

                // 操作日志
                $operationDetails = "用户 {$_SESSION['username']} 修改了兑换记录ID：{$redemption_id} 的状态，从 {$old_status} 变更为 {$new_status}";
                log_operation($_SESSION['user_id'], '更新', $operationDetails);

                $message = '兑换状态已成功更新';
                $messageType = 'success';

                // 刷新页面以显示最新数据
                header("Location: " . $_SERVER['REQUEST_URI']);
                exit;
            }
        } catch (Exception $e) {
            // 回滚事务
            $conn->rollback();
            $message = $e->getMessage();
            $messageType = 'error';
        }
    }
}

// 生成分页URL
function buildPageUrl($page, $member_id, $status, $search)
{
    $params = [];

    if ($member_id > 0) {
        $params['member_id'] = $member_id;
    }

    if (!empty($status)) {
        $params['status'] = $status;
    }

    if (!empty($search)) {
        $params['search'] = $search;
    }

    $params['p'] = $page;

    return 'index.php?page=points&action=redemptions&' . http_build_query($params);
}

// 生成分页HTML
$pagination = generate_pagination($total, $page, $limit, buildPageUrl($page, $member_id, $status, $search));
?>

<div class="page-header">
    <h3>积分兑换记录</h3>
    <div class="page-header-actions">
        <a href="index.php?page=points" class="btn btn-secondary">返回积分商品</a>
        <a href="index.php?page=points&action=redeem" class="btn btn-primary">新增兑换</a>
    </div>
</div>

<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<div class="filter-box">
    <form method="get" action="index.php" class="filter-form">
        <input type="hidden" name="page" value="points">
        <input type="hidden" name="action" value="redemptions">

        <div class="form-group">
            <input type="text" name="search" class="form-control" placeholder="会员名称/卡号/商品" value="<?php echo htmlspecialchars($search); ?>">
        </div>

        <div class="form-group">
            <select name="status" class="form-control">
                <option value="">全部状态</option>
                <option value="pending" <?php echo $status == 'pending' ? 'selected' : ''; ?>>待处理</option>
                <option value="completed" <?php echo $status == 'completed' ? 'selected' : ''; ?>>已完成</option>
                <option value="cancelled" <?php echo $status == 'cancelled' ? 'selected' : ''; ?>>已取消</option>
            </select>
        </div>

        <div class="form-group">
            <button type="submit" class="btn btn-primary">筛选</button>
            <a href="index.php?page=points&action=redemptions" class="btn btn-secondary">重置</a>
        </div>
    </form>
</div>

<div class="data-table-wrapper">
    <?php if (count($redemptions) > 0): ?>
        <table class="data-table">
            <thead>
                <tr>
                    <th width="60">ID</th>
                    <th>会员信息</th>
                    <th>商品信息</th>
                    <th width="80">数量</th>
                    <th width="100">消耗积分</th>
                    <th width="120">兑换日期</th>
                    <th width="120">处理状态</th>
                    <th width="120">处理人员</th>
                    <th width="120">操作</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($redemptions as $redemption): ?>
                    <tr>
                        <td><?php echo $redemption['redemption_id']; ?></td>
                        <td>
                            <a href="index.php?page=member&action=view&id=<?php echo $redemption['member_id']; ?>">
                                <?php echo htmlspecialchars($redemption['customer_name']); ?>
                            </a>
                            <small>(<?php echo htmlspecialchars($redemption['member_no']); ?>)</small>
                        </td>
                        <td>
                            <a href="index.php?page=points&action=view&id=<?php echo $redemption['product_id']; ?>">
                                <?php echo htmlspecialchars($redemption['product_name']); ?>
                            </a>
                            <small>(<?php echo getProductTypeName($redemption['product_type']); ?>)</small>
                        </td>
                        <td><?php echo $redemption['quantity']; ?></td>
                        <td><?php echo number_format($redemption['points_used']); ?></td>
                        <td><?php echo date('Y-m-d', strtotime($redemption['redemption_date'])); ?></td>
                        <td>
                            <span class="badge badge-<?php echo getRedemptionStatusClass($redemption['status']); ?>">
                                <?php echo getRedemptionStatusName($redemption['status']); ?>
                            </span>
                        </td>
                        <td>
                            <?php if ($redemption['processed_by']): ?>
                                <?php echo htmlspecialchars($redemption['processed_by_name']); ?>
                                <small>(<?php echo date('Y-m-d', strtotime($redemption['processed_date'])); ?>)</small>
                            <?php else: ?>
                                -
                            <?php endif; ?>
                        </td>
                        <td>
                            <div class="action-buttons">
                                <a href="index.php?page=points&action=redemption_detail&id=<?php echo $redemption['redemption_id']; ?>" class="btn btn-sm btn-info">查看详情</a>
                                <?php if ($redemption['status'] == 'pending'): ?>
                                    <a href="javascript:void(0)" onclick="showStatusUpdateModal(<?php echo $redemption['redemption_id']; ?>, 'completed')" class="btn btn-sm btn-success">完成</a>
                                    <a href="javascript:void(0)" onclick="showStatusUpdateModal(<?php echo $redemption['redemption_id']; ?>, 'cancelled')" class="btn btn-sm btn-danger">取消</a>
                                <?php endif; ?>
                            </div>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>

        <div class="pagination">
            <?php echo $pagination; ?>
        </div>
    <?php else: ?>
        <div class="alert alert-info">暂无兑换记录数据</div>
    <?php endif; ?>
</div>

<!-- 状态更新模态框 -->
<div id="status-update-modal" class="modal">
    <div class="modal-content">
        <span class="close" onclick="closeModal()">&times;</span>
        <h3>更新兑换状态</h3>

        <form id="status-update-form" method="post">
            <input type="hidden" id="redemption_id" name="redemption_id" value="">
            <input type="hidden" id="new_status" name="new_status" value="">

            <div class="form-group">
                <label for="notes">备注信息</label>
                <textarea class="form-control" id="notes" name="notes" rows="4" placeholder="请输入处理备注信息..."></textarea>
            </div>

            <div class="modal-actions">
                <button type="submit" class="btn btn-primary">确认更新</button>
                <button type="button" class="btn btn-secondary" onclick="closeModal()">取消</button>
            </div>
        </form>
    </div>
</div>

<style>
    .page-header {
        margin-bottom: 20px;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .page-header-actions {
        display: flex;
        gap: 10px;
    }

    .filter-box {
        background-color: #f8f9fa;
        padding: 15px;
        border-radius: 5px;
        margin-bottom: 20px;
    }

    .filter-form {
        display: flex;
        flex-wrap: wrap;
        gap: 10px;
        align-items: flex-end;
    }

    .filter-form .form-group {
        margin-bottom: 0;
        min-width: 150px;
    }

    .data-table-wrapper {
        overflow-x: auto;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
        margin-bottom: 20px;
    }

    .data-table th,
    .data-table td {
        padding: 12px 10px;
        text-align: left;
        vertical-align: middle;
        border-bottom: 1px solid #e9ecef;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
    }

    .data-table tr:hover {
        background-color: #f2f2f2;
    }

    .data-table small {
        display: block;
        color: #6c757d;
        font-size: 12px;
    }

    .action-buttons {
        display: flex;
        gap: 5px;
        flex-direction: row;
        justify-content: flex-start;
        align-items: center;
        flex-wrap: nowrap;
        width: 100%;
    }

    .action-buttons .btn {
        margin-bottom: 0;
        white-space: nowrap;
        display: inline-flex;
        align-items: center;
        justify-content: center;
        padding: 4px 8px;
        font-size: 12px;
    }

    .badge {
        display: inline-block;
        padding: 3px 8px;
        font-size: 12px;
        font-weight: 600;
        border-radius: 3px;
        color: white;
    }

    .badge-success {
        background-color: #28a745;
    }

    .badge-warning {
        background-color: #ffc107;
        color: #212529;
    }

    .badge-secondary {
        background-color: #6c757d;
    }

    .badge-info {
        background-color: #17a2b8;
    }

    /* 模态框样式 */
    .modal {
        display: none;
        position: fixed;
        z-index: 1000;
        left: 0;
        top: 0;
        width: 100%;
        height: 100%;
        overflow: auto;
        background-color: rgba(0, 0, 0, 0.4);
    }

    .modal-content {
        background-color: #fefefe;
        margin: 10% auto;
        padding: 20px;
        border: 1px solid #888;
        width: 50%;
        border-radius: 5px;
        box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        position: relative;
    }

    .close {
        color: #aaa;
        position: absolute;
        top: 10px;
        right: 20px;
        font-size: 28px;
        font-weight: bold;
        cursor: pointer;
    }

    .close:hover,
    .close:focus {
        color: black;
        text-decoration: none;
    }

    .modal-actions {
        margin-top: 20px;
        display: flex;
        justify-content: flex-end;
        gap: 10px;
    }

    @media (max-width: 767.98px) {
        .modal-content {
            width: 90%;
            margin: 15% auto;
        }
    }
</style>

<script>
    // 显示状态更新模态框
    function showStatusUpdateModal(redemptionId, newStatus) {
        document.getElementById('redemption_id').value = redemptionId;
        document.getElementById('new_status').value = newStatus;

        const statusText = newStatus === 'completed' ? '完成' : '取消';
        document.querySelector('#status-update-modal h3').textContent = '确认将兑换状态改为' + statusText;

        document.getElementById('status-update-modal').style.display = 'block';
    }

    // 关闭模态框
    function closeModal() {
        document.getElementById('status-update-modal').style.display = 'none';
    }

    // 点击模态框外部关闭
    window.onclick = function(event) {
        const statusModal = document.getElementById('status-update-modal');
        if (event.target === statusModal) {
            statusModal.style.display = 'none';
        }
    };
</script>