<?php
session_start();
require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取当前页面
$page = isset($_GET['page']) ? $_GET['page'] : 'supplier';

// 页面标题
$pageTitle = '采购管理';
$subTitle = '';

// 获取子页面内容
$contentFile = '';
switch ($page) {
    case 'supplier':
        $contentFile = 'supplier.php';
        $subTitle = '供应商管理';
        break;
    case 'order':
        $contentFile = 'order.php';
        $subTitle = '采购订单';
        break;
    case 'storage':
        $contentFile = 'storage.php';
        $subTitle = '采购入库';
        break;
    case 'statement':
        $contentFile = 'statement.php';
        $subTitle = '采购对账';
        break;
    default:
        $contentFile = 'supplier.php';
        $subTitle = '供应商管理';
}

// 检查文件是否存在
if (!file_exists($contentFile)) {
    $contentFile = 'supplier.php';
    $subTitle = '供应商管理';
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $subTitle; ?> - <?php echo $pageTitle; ?> - <?php echo SITE_NAME; ?></title>
    <link rel="stylesheet" href="../../css/style.css">
</head>

<body>
    <header class="main-header">
        <div class="user-info">
            <span class="user-name"><?php echo isset($_SESSION['full_name']) ? $_SESSION['full_name'] : '用户'; ?></span>
            <span class="user-role"><?php echo $_SESSION['user_role']; ?></span>
        </div>

        <div class="site-title">
            <h1><?php echo SITE_NAME; ?></h1>
            <p><?php echo SITE_SUBTITLE; ?></p>
        </div>

        <div class="header-actions">
            <a href="../../logout.php" class="btn btn-logout">退出登录</a>
        </div>
    </header>

    <div class="module-layout">
        <aside class="module-sidebar">
            <div class="module-sidebar-header">
                <h2><?php echo $pageTitle; ?></h2>
            </div>

            <nav class="module-nav">
                <a href="../../home.php" class="module-nav-item">返回首页</a>
                <a href="index.php?page=supplier" class="module-nav-item <?php echo $page == 'supplier' ? 'active' : ''; ?>">供应商管理</a>
                <a href="index.php?page=order" class="module-nav-item <?php echo $page == 'order' ? 'active' : ''; ?>">采购订单</a>
                <a href="index.php?page=storage" class="module-nav-item <?php echo $page == 'storage' ? 'active' : ''; ?>">采购入库</a>
                <a href="index.php?page=statement" class="module-nav-item <?php echo $page == 'statement' ? 'active' : ''; ?>">采购对账</a>
            </nav>
        </aside>

        <main class="module-content">
            <div class="module-content-header">
                <h2><?php echo $subTitle; ?></h2>
            </div>
            <?php
            // 包含子页面内容
            if (file_exists($contentFile)) {
                include $contentFile;
            } else {
                echo "<div class='alert alert-error'>找不到页面文件: {$contentFile}</div>";
            }
            ?>
        </main>
    </div>

    <footer class="main-footer">
        <p>&copy; <?php echo date('Y'); ?> <?php echo SITE_NAME; ?> - 版权所有</p>
    </footer>
</body>

</html>