<?php
// 采购入库管理页面
// 防止直接访问
if (!defined('IN_SYSTEM')) {
    define('IN_SYSTEM', true);
}

// 初始化消息变量
$message = '';
$messageType = '';

// 获取采购入库列表
$stockList = [];
$search = isset($_GET['keyword']) ? $_GET['keyword'] : '';

// 处理添加/编辑采购入库
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 获取表单数据
    $order_id = isset($_POST['order_id']) ? (int)$_POST['order_id'] : 0;
    $batch_number = isset($_POST['batch_number']) ? trim($_POST['batch_number']) : '';
    $inspection_status = isset($_POST['inspection_status']) ? trim($_POST['inspection_status']) : 'pending';
    $loss_amount = isset($_POST['loss_amount']) ? (float)$_POST['loss_amount'] : 0;

    // 验证数据
    if (empty($order_id) || empty($batch_number)) {
        $message = '请填写所有必填字段！';
        $messageType = 'error';
    } else {
        // 添加新采购入库
        if ($_POST['action'] == 'add') {
            try {
                $sql = "INSERT INTO purchase_stock (order_id, batch_number, inspection_status, loss_amount) VALUES (?, ?, ?, ?)";
                $stmt = $conn->prepare($sql);
                $stmt->bind_param("issd", $order_id, $batch_number, $inspection_status, $loss_amount);

                if ($stmt->execute()) {
                    $stockId = $stmt->insert_id;
                    $message = "采购入库记录添加成功！";
                    $messageType = 'success';

                    // 记录操作日志
                    $operationDetails = "用户 {$_SESSION['username']} 添加了采购入库记录，批次号: {$batch_number}";
                    log_operation($_SESSION['user_id'], '添加采购入库', $operationDetails);

                    // 重定向到采购入库列表
                    header("Location: index.php?page=storage&message={$message}&type={$messageType}");
                    exit;
                } else {
                    $message = "添加采购入库记录失败: " . $stmt->error;
                    $messageType = 'error';
                }
            } catch (Exception $e) {
                $message = "系统错误: " . $e->getMessage();
                $messageType = 'error';
            }
        }
        // 更新采购入库
        elseif ($_POST['action'] == 'edit' && isset($_POST['stock_id'])) {
            $stock_id = (int)$_POST['stock_id'];

            try {
                $sql = "UPDATE purchase_stock SET order_id = ?, batch_number = ?, inspection_status = ?, loss_amount = ? WHERE stock_id = ?";
                $stmt = $conn->prepare($sql);
                $stmt->bind_param("issdi", $order_id, $batch_number, $inspection_status, $loss_amount, $stock_id);

                if ($stmt->execute()) {
                    $message = "采购入库记录更新成功！";
                    $messageType = 'success';

                    // 记录操作日志
                    $operationDetails = "用户 {$_SESSION['username']} 更新了采购入库记录，批次号: {$batch_number}";
                    log_operation($_SESSION['user_id'], '更新采购入库', $operationDetails);

                    // 重定向到采购入库列表
                    header("Location: index.php?page=storage&message={$message}&type={$messageType}");
                    exit;
                } else {
                    $message = "更新采购入库记录失败: " . $stmt->error;
                    $messageType = 'error';
                }
            } catch (Exception $e) {
                $message = "系统错误: " . $e->getMessage();
                $messageType = 'error';
            }
        }
    }
}

// 处理批量更新质检状态
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['batch_action']) && isset($_POST['stock_ids'])) {
    $action = $_POST['batch_action'];
    $stockIds = $_POST['stock_ids'];
    $updatedCount = 0;
    $failedCount = 0;

    if (!empty($stockIds) && in_array($action, ['passed', 'failed', 'pending'])) {
        try {
            // 准备SQL语句
            $sql = "UPDATE purchase_stock SET inspection_status = ? WHERE stock_id = ?";
            $stmt = $conn->prepare($sql);

            if ($stmt === false) {
                $message = "准备批量更新质检状态的SQL语句失败: " . $conn->error;
                $messageType = 'error';
            } else {
                foreach ($stockIds as $stockId) {
                    $stmt->bind_param("si", $action, $stockId);

                    if ($stmt->execute()) {
                        $updatedCount++;
                    } else {
                        $failedCount++;
                    }
                }

                // 记录操作日志
                $actionText = '';
                switch ($action) {
                    case 'passed':
                        $actionText = '已通过';
                        break;
                    case 'failed':
                        $actionText = '未通过';
                        break;
                    case 'pending':
                        $actionText = '待检验';
                        break;
                }

                $operationDetails = "用户 {$_SESSION['username']} 批量将 {$updatedCount} 个采购入库记录设置为{$actionText}";
                log_operation($_SESSION['user_id'], '批量更新采购入库质检状态', $operationDetails);

                $message = "成功更新 {$updatedCount} 个入库记录质检状态";
                if ($failedCount > 0) {
                    $message .= "，{$failedCount} 个记录更新失败";
                }
                $messageType = ($failedCount > 0) ? 'warning' : 'success';

                // 添加重定向以刷新页面
                header("Location: index.php?page=storage&message=" . urlencode($message) . "&type=" . urlencode($messageType));
                exit;
            }
        } catch (Exception $e) {
            $message = "批量更新质检状态失败: " . $e->getMessage();
            $messageType = 'error';
        }
    } else {
        $message = "请选择要处理的入库记录和有效的操作";
        $messageType = 'error';
    }
}

// 处理快速更新质检状态
if (isset($_GET['action']) && $_GET['action'] == 'update_inspection' && isset($_GET['id']) && isset($_GET['status'])) {
    $stock_id = (int)$_GET['id'];
    $new_status = $_GET['status'];

    // 验证状态值有效性
    if (in_array($new_status, ['pending', 'passed', 'failed'])) {
        try {
            $sql = "UPDATE purchase_stock SET inspection_status = ? WHERE stock_id = ?";
            $stmt = $conn->prepare($sql);

            if ($stmt === false) {
                $message = "准备更新质检状态的SQL语句失败: " . $conn->error;
                $messageType = 'error';
            } else {
                $stmt->bind_param("si", $new_status, $stock_id);

                if ($stmt->execute()) {
                    // 获取批次号用于日志记录
                    $stockSql = "SELECT batch_number FROM purchase_stock WHERE stock_id = ?";
                    $stockStmt = $conn->prepare($stockSql);
                    $batch_number = '';

                    if ($stockStmt !== false) {
                        $stockStmt->bind_param("i", $stock_id);
                        if ($stockStmt->execute()) {
                            $stockResult = $stockStmt->get_result();
                            if ($stockResult && $stockResult->num_rows > 0) {
                                $stockData = $stockResult->fetch_assoc();
                                $batch_number = $stockData['batch_number'];
                            }
                        }
                        $stockStmt->close();
                    }

                    $statusText = '';
                    switch ($new_status) {
                        case 'passed':
                            $statusText = '已通过';
                            break;
                        case 'failed':
                            $statusText = '未通过';
                            break;
                        default:
                            $statusText = '待检验';
                    }

                    $message = "批次 {$batch_number} 质检状态更新为{$statusText}！";
                    $messageType = 'success';

                    // 记录操作日志
                    $operationDetails = "用户 {$_SESSION['username']} 将采购入库批次 {$batch_number} 质检状态更新为{$statusText}";
                    log_operation($_SESSION['user_id'], '更新采购入库质检状态', $operationDetails);
                } else {
                    $message = "更新质检状态失败: " . $stmt->error;
                    $messageType = 'error';
                }
                $stmt->close();
            }
        } catch (Exception $e) {
            $message = "系统错误: " . $e->getMessage();
            $messageType = 'error';
        }
    } else {
        $message = "无效的质检状态值！";
        $messageType = 'error';
    }

    // 重定向回入库列表
    header("Location: index.php?page=storage&message={$message}&type={$messageType}");
    exit;
}

// 处理删除采购入库
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $stock_id = (int)$_GET['id'];

    try {
        // 先获取采购入库信息用于日志记录
        $sql = "SELECT batch_number FROM purchase_stock WHERE stock_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $stock_id);
        $stmt->execute();
        $result = $stmt->get_result();
        $stock = $result->fetch_assoc();

        if ($stock) {
            // 删除采购入库商品
            $sql = "DELETE FROM purchase_stock_items WHERE stock_id = ?";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param("i", $stock_id);
            $stmt->execute();

            // 执行删除采购入库操作
            $sql = "DELETE FROM purchase_stock WHERE stock_id = ?";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param("i", $stock_id);

            if ($stmt->execute()) {
                $message = "采购入库记录删除成功！";
                $messageType = 'success';

                // 记录操作日志
                $operationDetails = "用户 {$_SESSION['username']} 删除了采购入库记录，批次号: {$stock['batch_number']}";
                log_operation($_SESSION['user_id'], '删除采购入库', $operationDetails);
            } else {
                $message = "删除采购入库记录失败: " . $stmt->error;
                $messageType = 'error';
            }
        } else {
            $message = "找不到指定的采购入库记录！";
            $messageType = 'error';
        }
    } catch (Exception $e) {
        $message = "系统错误: " . $e->getMessage();
        $messageType = 'error';
    }

    // 重定向到采购入库列表
    header("Location: index.php?page=storage&message={$message}&type={$messageType}");
    exit;
}

// 获取要编辑的采购入库信息
$editStock = null;
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $stock_id = (int)$_GET['id'];

    try {
        $sql = "SELECT * FROM purchase_stock WHERE stock_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $stock_id);
        $stmt->execute();
        $result = $stmt->get_result();
        $editStock = $result->fetch_assoc();

        if (!$editStock) {
            $message = "找不到指定的采购入库记录！";
            $messageType = 'error';
        }
    } catch (Exception $e) {
        $message = "系统错误: " . $e->getMessage();
        $messageType = 'error';
    }
}

// 获取要查看的采购入库详情
$viewStock = null;
$stockItems = [];
if (isset($_GET['action']) && $_GET['action'] == 'view' && isset($_GET['id'])) {
    $stock_id = (int)$_GET['id'];

    try {
        // 获取采购入库信息
        $sql = "SELECT ps.*, po.order_number, s.supplier_name 
                FROM purchase_stock ps 
                LEFT JOIN purchase_orders po ON ps.order_id = po.order_id 
                LEFT JOIN suppliers s ON po.supplier_id = s.supplier_id 
                WHERE ps.stock_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $stock_id);
        $stmt->execute();
        $result = $stmt->get_result();
        $viewStock = $result->fetch_assoc();

        if ($viewStock) {
            // 获取采购入库商品明细
            $sql = "SELECT * FROM purchase_stock_items WHERE stock_id = ?";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param("i", $stock_id);
            $stmt->execute();
            $result = $stmt->get_result();

            while ($row = $result->fetch_assoc()) {
                $stockItems[] = $row;
            }
        } else {
            $message = "找不到指定的采购入库记录！";
            $messageType = 'error';
        }
    } catch (Exception $e) {
        $message = "系统错误: " . $e->getMessage();
        $messageType = 'error';
    }
}

// 获取采购订单列表（用于表单选择）
$orders = [];
try {
    $sql = "SELECT po.order_id, po.order_number, s.supplier_name 
            FROM purchase_orders po 
            LEFT JOIN suppliers s ON po.supplier_id = s.supplier_id 
            WHERE po.status = 'approved' 
            ORDER BY po.order_id DESC";
    $stmt = $conn->prepare($sql);

    if ($stmt === false) {
        $message = "准备查询采购订单列表的SQL语句失败: " . $conn->error;
        $messageType = 'error';
    } else {
        if ($stmt->execute()) {
            $result = $stmt->get_result();

            if ($result) {
                while ($row = $result->fetch_assoc()) {
                    $orders[] = $row;
                }
            } else {
                $message = "获取采购订单列表结果集失败";
                $messageType = 'error';
            }
        } else {
            $message = "执行查询采购订单列表失败: " . $stmt->error;
            $messageType = 'error';
        }
        $stmt->close();
    }
} catch (Exception $e) {
    $message = "获取采购订单列表失败: " . $e->getMessage();
    $messageType = 'error';
}

// 获取采购入库列表（用于显示在页面上）
try {
    // 处理搜索
    if (!empty($search)) {
        $searchTerm = "%{$search}%";
        $sql = "SELECT ps.*, po.order_number, s.supplier_name 
                FROM purchase_stock ps 
                LEFT JOIN purchase_orders po ON ps.order_id = po.order_id 
                LEFT JOIN suppliers s ON po.supplier_id = s.supplier_id 
                WHERE ps.batch_number LIKE ? OR po.order_number LIKE ? OR s.supplier_name LIKE ? 
                ORDER BY ps.stock_id DESC";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $message = "准备查询采购入库记录的SQL语句失败: " . $conn->error;
            $messageType = 'error';
        } else {
            $stmt->bind_param("sss", $searchTerm, $searchTerm, $searchTerm);

            if ($stmt->execute()) {
                $result = $stmt->get_result();

                if ($result) {
                    while ($row = $result->fetch_assoc()) {
                        $stockList[] = $row;
                    }
                } else {
                    $message = "获取结果集失败: " . $stmt->error;
                    $messageType = 'error';
                }
            } else {
                $message = "执行查询失败: " . $stmt->error;
                $messageType = 'error';
            }
            $stmt->close();
        }
    } else {
        $sql = "SELECT ps.*, po.order_number, s.supplier_name 
                FROM purchase_stock ps 
                LEFT JOIN purchase_orders po ON ps.order_id = po.order_id 
                LEFT JOIN suppliers s ON po.supplier_id = s.supplier_id 
                ORDER BY ps.stock_id DESC";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $message = "准备查询采购入库记录的SQL语句失败: " . $conn->error;
            $messageType = 'error';
        } else {
            if ($stmt->execute()) {
                $result = $stmt->get_result();

                if ($result) {
                    while ($row = $result->fetch_assoc()) {
                        $stockList[] = $row;
                    }
                } else {
                    $message = "获取结果集失败: " . $stmt->error;
                    $messageType = 'error';
                }
            } else {
                $message = "执行查询失败: " . $stmt->error;
                $messageType = 'error';
            }
            $stmt->close();
        }
    }
} catch (Exception $e) {
    $message = "获取采购入库列表失败: " . $e->getMessage();
    $messageType = 'error';
}

// 处理从URL传来的消息
if (isset($_GET['message']) && isset($_GET['type'])) {
    $message = $_GET['message'];
    $messageType = $_GET['type'];
}

// 生成批次号
function generateBatchNumber()
{
    return 'BATCH' . date('YmdHis') . rand(100, 999);
}
?>

<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>">
        <?php echo $message; ?>
    </div>
<?php endif; ?>

<!-- 添加或编辑采购入库表单 -->
<?php if (isset($_GET['action']) && ($_GET['action'] == 'add' || ($_GET['action'] == 'edit' && $editStock))): ?>
    <div class="form-container">
        <h3><?php echo $_GET['action'] == 'add' ? '添加采购入库' : '编辑采购入库'; ?></h3>
        <form action="" method="post">
            <input type="hidden" name="action" value="<?php echo $_GET['action']; ?>">
            <?php if ($_GET['action'] == 'edit'): ?>
                <input type="hidden" name="stock_id" value="<?php echo $editStock['stock_id']; ?>">
            <?php endif; ?>

            <div class="form-group">
                <label for="order_id">关联采购订单 <span class="required">*</span></label>
                <select id="order_id" name="order_id" required>
                    <option value="">请选择采购订单</option>
                    <?php foreach ($orders as $order): ?>
                        <option value="<?php echo $order['order_id']; ?>" <?php echo ($editStock && $editStock['order_id'] == $order['order_id']) ? 'selected' : ''; ?>>
                            <?php echo $order['order_number'] . ' - ' . $order['supplier_name']; ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="form-group">
                <label for="batch_number">批次号 <span class="required">*</span></label>
                <input type="text" id="batch_number" name="batch_number" value="<?php echo $editStock ? $editStock['batch_number'] : generateBatchNumber(); ?>" required>
            </div>

            <div class="form-group">
                <label for="inspection_status">质检状态 <span class="required">*</span></label>
                <select id="inspection_status" name="inspection_status" required>
                    <option value="pending" <?php echo ($editStock && $editStock['inspection_status'] == 'pending') ? 'selected' : ''; ?>>待检验</option>
                    <option value="passed" <?php echo ($editStock && $editStock['inspection_status'] == 'passed') ? 'selected' : ''; ?>>通过</option>
                    <option value="failed" <?php echo ($editStock && $editStock['inspection_status'] == 'failed') ? 'selected' : ''; ?>>未通过</option>
                </select>
            </div>

            <div class="form-group">
                <label for="loss_amount">损耗金额</label>
                <input type="number" id="loss_amount" name="loss_amount" step="0.01" min="0" value="<?php echo $editStock ? $editStock['loss_amount'] : '0.00'; ?>">
            </div>

            <div class="form-group">
                <button type="submit" class="btn btn-primary">保存</button>
                <a href="index.php?page=storage" class="btn btn-secondary">取消</a>
            </div>
        </form>
    </div>
    <!-- 查看采购入库详情 -->
<?php elseif (isset($_GET['action']) && $_GET['action'] == 'view' && $viewStock): ?>
    <div class="user-details">
        <h3>采购入库详情</h3>
        <div class="detail-group">
            <label>入库ID:</label>
            <span><?php echo $viewStock['stock_id']; ?></span>
        </div>
        <div class="detail-group">
            <label>采购订单:</label>
            <span><?php echo $viewStock['order_number']; ?></span>
        </div>
        <div class="detail-group">
            <label>供应商:</label>
            <span><?php echo $viewStock['supplier_name']; ?></span>
        </div>
        <div class="detail-group">
            <label>批次号:</label>
            <span><?php echo $viewStock['batch_number']; ?></span>
        </div>
        <div class="detail-group">
            <label>质检状态:</label>
            <span>
                <?php
                switch ($viewStock['inspection_status']) {
                    case 'pending':
                        echo '<span class="badge badge-warning">待检验</span>';
                        break;
                    case 'passed':
                        echo '<span class="badge badge-success">通过</span>';
                        break;
                    case 'failed':
                        echo '<span class="badge badge-danger">未通过</span>';
                        break;
                    default:
                        echo $viewStock['inspection_status'];
                }
                ?>
            </span>
        </div>
        <div class="detail-group">
            <label>损耗金额:</label>
            <span>￥<?php echo number_format($viewStock['loss_amount'], 2); ?></span>
        </div>
        <div class="detail-group">
            <label>创建时间:</label>
            <span><?php echo $viewStock['created_at']; ?></span>
        </div>
        <div class="detail-group">
            <label>最后更新:</label>
            <span><?php echo $viewStock['updated_at']; ?></span>
        </div>

        <h4>入库商品明细</h4>
        <?php if (count($stockItems) > 0): ?>
            <table class="data-table stock-items-table">
                <thead>
                    <tr>
                        <th>商品名称</th>
                        <th>数量</th>
                        <th>单价</th>
                        <th>总价</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($stockItems as $item): ?>
                        <tr>
                            <td><?php echo $item['product_name']; ?></td>
                            <td><?php echo $item['quantity']; ?></td>
                            <td>￥<?php echo number_format($item['unit_price'], 2); ?></td>
                            <td>￥<?php echo number_format($item['total_price'], 2); ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        <?php else: ?>
            <p>暂无商品明细</p>
        <?php endif; ?>

        <div class="detail-actions">
            <a href="index.php?page=storage" class="btn btn-secondary">返回入库列表</a>
            <a href="index.php?page=storage&action=edit&id=<?php echo $viewStock['stock_id']; ?>" class="btn btn-primary">编辑入库记录</a>
        </div>
    </div>

    <style>
        /* 入库详情页面样式 */
        .user-details {
            background-color: #f9f9f9;
            padding: 20px;
            border-radius: 5px;
            margin-bottom: 20px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            border: 1px solid #e0e0e0;
        }

        .user-details h3,
        .user-details h4 {
            margin-top: 0;
            margin-bottom: 20px;
            color: #333;
            border-bottom: 1px solid #ddd;
            padding-bottom: 10px;
            font-size: 1.2em;
        }

        .user-details h4 {
            margin-top: 20px;
            font-size: 1.1em;
        }

        .detail-group {
            margin-bottom: 12px;
            display: flex;
            align-items: center;
            border-bottom: 1px dashed #eee;
            padding-bottom: 8px;
        }

        .detail-group:last-of-type {
            border-bottom: none;
        }

        .detail-group label {
            font-weight: bold;
            width: 120px;
            color: #555;
            flex-shrink: 0;
        }

        .detail-group span {
            flex-grow: 1;
            color: #333;
        }

        .stock-items-table {
            margin-bottom: 20px;
            width: 100%;
        }

        .detail-actions {
            margin-top: 20px;
            padding-top: 15px;
            border-top: 1px solid #ddd;
            display: flex;
            gap: 10px;
        }

        .detail-actions .btn {
            padding: 8px 16px;
            text-decoration: none;
            border-radius: 4px;
            font-weight: normal;
            text-align: center;
        }

        .badge {
            display: inline-block;
            padding: 0.25em 0.6em;
            font-size: 75%;
            font-weight: 700;
            line-height: 1;
            text-align: center;
            white-space: nowrap;
            vertical-align: baseline;
            border-radius: 0.25rem;
        }

        .badge-warning {
            color: #212529;
            background-color: #ffc107;
        }

        .badge-success {
            color: #fff;
            background-color: #28a745;
        }

        .badge-danger {
            color: #fff;
            background-color: #dc3545;
        }
    </style>
    <!-- 采购入库列表 -->
<?php else: ?>
    <div class="module-tools">
        <div class="tool-left">
            <a href="index.php?page=storage&action=add" class="btn btn-primary">添加入库记录</a>

            <!-- 批量操作部分 -->
            <form method="post" id="batch-form" class="batch-form">
                <div class="batch-actions">
                    <select name="batch_action" class="form-control">
                        <option value="">批量操作...</option>
                        <option value="passed">批量设为已通过</option>
                        <option value="failed">批量设为未通过</option>
                        <option value="pending">批量设为待检验</option>
                    </select>
                    <button type="submit" class="btn btn-primary" onclick="return confirm('确定要执行所选操作吗？')">应用</button>
                </div>
            </form>
        </div>
        <div class="tool-right">
            <form action="index.php" method="get" class="search-form">
                <input type="hidden" name="page" value="storage">
                <div class="search-group">
                    <input type="text" name="keyword" placeholder="批次号/订单编号/供应商" class="search-input" value="<?php echo htmlspecialchars($search); ?>">
                    <button type="submit" class="btn btn-primary">搜索</button>
                    <?php if (!empty($search)): ?>
                        <a href="index.php?page=storage" class="btn btn-secondary">清除</a>
                    <?php endif; ?>
                </div>
            </form>
        </div>
    </div>

    <div class="data-wrapper">
        <table class="data-table">
            <thead>
                <tr>
                    <th><input type="checkbox" id="select-all"></th>
                    <th>ID</th>
                    <th>批次号</th>
                    <th>订单编号</th>
                    <th>供应商</th>
                    <th>质检状态</th>
                    <th>损耗金额</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php if (count($stockList) > 0): ?>
                    <?php foreach ($stockList as $stock): ?>
                        <tr>
                            <td><input type="checkbox" name="stock_ids[]" value="<?php echo $stock['stock_id']; ?>" class="stock-checkbox" form="batch-form"></td>
                            <td><?php echo $stock['stock_id']; ?></td>
                            <td><?php echo $stock['batch_number']; ?></td>
                            <td><?php echo $stock['order_number']; ?></td>
                            <td><?php echo $stock['supplier_name']; ?></td>
                            <td>
                                <?php
                                switch ($stock['inspection_status']) {
                                    case 'pending':
                                        echo '<span class="badge badge-warning">待检验</span> ';
                                        echo '<a href="javascript:void(0);" onclick="if(confirm(\'确定要将质检状态更新为已通过吗？\')) window.location.href=\'index.php?page=storage&action=update_inspection&id=' . $stock['stock_id'] . '&status=passed\';" class="btn btn-xs btn-success" title="一键通过"><i class="fa fa-check"></i></a>';
                                        echo ' <a href="javascript:void(0);" onclick="if(confirm(\'确定要将质检状态更新为未通过吗？\')) window.location.href=\'index.php?page=storage&action=update_inspection&id=' . $stock['stock_id'] . '&status=failed\';" class="btn btn-xs btn-danger" title="一键不通过"><i class="fa fa-times"></i></a>';
                                        break;
                                    case 'passed':
                                        echo '<span class="badge badge-success">通过</span> ';
                                        echo '<a href="javascript:void(0);" onclick="if(confirm(\'确定要将质检状态撤回到待检验吗？\')) window.location.href=\'index.php?page=storage&action=update_inspection&id=' . $stock['stock_id'] . '&status=pending\';" class="btn btn-xs btn-warning" title="撤销通过"><i class="fa fa-undo"></i></a>';
                                        break;
                                    case 'failed':
                                        echo '<span class="badge badge-danger">未通过</span> ';
                                        echo '<a href="javascript:void(0);" onclick="if(confirm(\'确定要将质检状态撤回到待检验吗？\')) window.location.href=\'index.php?page=storage&action=update_inspection&id=' . $stock['stock_id'] . '&status=pending\';" class="btn btn-xs btn-warning" title="撤销不通过"><i class="fa fa-undo"></i></a>';
                                        break;
                                    default:
                                        echo $stock['inspection_status'];
                                }
                                ?>
                            </td>
                            <td>￥<?php echo number_format($stock['loss_amount'], 2); ?></td>
                            <td class="actions">
                                <a href="index.php?page=storage&action=view&id=<?php echo $stock['stock_id']; ?>" class="btn btn-secondary btn-sm">查看</a>
                                <a href="index.php?page=storage&action=edit&id=<?php echo $stock['stock_id']; ?>" class="btn btn-primary btn-sm">编辑</a>
                                <a href="index.php?page=storage&action=delete&id=<?php echo $stock['stock_id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('确定要删除此采购入库记录吗？')">删除</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="8" class="text-center">暂无采购入库数据</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <script>
        // 全选/取消全选
        document.getElementById('select-all').addEventListener('change', function() {
            var checkboxes = document.getElementsByClassName('stock-checkbox');
            for (var i = 0; i < checkboxes.length; i++) {
                checkboxes[i].checked = this.checked;
            }
        });

        // 如果所有复选框都被勾选，则"全选"复选框也应该被勾选
        var stockCheckboxes = document.getElementsByClassName('stock-checkbox');
        for (var i = 0; i < stockCheckboxes.length; i++) {
            stockCheckboxes[i].addEventListener('change', function() {
                var allChecked = true;
                for (var j = 0; j < stockCheckboxes.length; j++) {
                    if (!stockCheckboxes[j].checked) {
                        allChecked = false;
                        break;
                    }
                }
                document.getElementById('select-all').checked = allChecked;
            });
        }
    </script>

    <style>
        /* 入库列表页面样式 */
        .badge {
            display: inline-block;
            padding: 0.25em 0.6em;
            font-size: 75%;
            font-weight: 700;
            line-height: 1;
            text-align: center;
            white-space: nowrap;
            vertical-align: baseline;
            border-radius: 0.25rem;
        }

        .badge-warning {
            color: #212529;
            background-color: #ffc107;
        }

        .badge-success {
            color: #fff;
            background-color: #28a745;
        }

        .badge-danger {
            color: #fff;
            background-color: #dc3545;
        }

        /* 快速操作按钮样式 */
        .btn-xs {
            padding: 0.1rem 0.25rem;
            font-size: 0.675rem;
            line-height: 1.5;
            border-radius: 0.2rem;
        }

        td .btn-xs {
            margin-right: 2px;
        }

        td .btn-xs i {
            font-size: 10px;
        }

        td.actions {
            white-space: nowrap;
        }

        /* 批量操作和搜索框样式 */
        .module-tools {
            display: flex;
            justify-content: space-between;
            margin-bottom: 15px;
            flex-wrap: wrap;
        }

        .tool-left,
        .tool-right {
            display: flex;
            align-items: center;
            gap: 10px;
            margin-bottom: 10px;
        }

        .batch-form {
            display: inline-block;
            margin-left: 15px;
        }

        .batch-actions {
            display: flex;
            gap: 10px;
            align-items: center;
        }

        .batch-actions select {
            width: auto;
            display: inline-block;
            padding: 6px 12px;
            font-size: 14px;
            font-weight: 400;
            line-height: 1.5;
            color: #495057;
            background-color: #fff;
            background-clip: padding-box;
            border: 1px solid #ced4da;
            border-radius: 0.25rem;
            transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
        }

        .data-table th:first-child,
        .data-table td:first-child {
            width: 40px;
            text-align: center;
        }

        .search-group {
            display: flex;
            align-items: center;
        }

        .search-input {
            padding: 6px 12px;
            font-size: 14px;
            line-height: 1.5;
            color: #495057;
            background-color: #fff;
            background-clip: padding-box;
            border: 1px solid #ced4da;
            border-radius: 0.25rem 0 0 0.25rem;
            transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
        }

        .search-group .btn {
            border-radius: 0 0.25rem 0.25rem 0;
            margin-left: -1px;
        }

        .text-center {
            text-align: center;
        }
    </style>
<?php endif; ?>