<?php
// 防止直接访问
defined('IN_SYSTEM') || die('禁止访问');

// 获取仓库列表（用于搜索筛选）
$warehouseSql = "SELECT warehouse_id, warehouse_name FROM warehouses ORDER BY warehouse_name";
$warehouseResult = $conn->query($warehouseSql);
$warehouses = [];
while ($warehouseResult && $row = $warehouseResult->fetch_assoc()) {
    $warehouses[] = $row;
}
?>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<div class="module-tools">
    <div class="tool-left">
        <a href="index.php?page=delivery&action=add" class="btn btn-primary">创建销售出库单</a>
    </div>
    <div class="tool-right">
        <form action="index.php" method="get" class="search-form">
            <input type="hidden" name="page" value="delivery">
            <div class="search-group">
                <input type="text" name="search" class="search-input" placeholder="搜索出库单号或客户" value="<?php echo htmlspecialchars($search); ?>">
            </div>
            <div class="search-group">
                <select name="status" class="search-input">
                    <option value="">所有状态</option>
                    <option value="pending" <?php echo $status == 'pending' ? 'selected' : ''; ?>>待处理</option>
                    <option value="in_progress" <?php echo $status == 'in_progress' ? 'selected' : ''; ?>>进行中</option>
                    <option value="completed" <?php echo $status == 'completed' ? 'selected' : ''; ?>>已完成</option>
                    <option value="cancelled" <?php echo $status == 'cancelled' ? 'selected' : ''; ?>>已取消</option>
                </select>
            </div>
            <div class="search-group">
                <select name="warehouse_id" class="search-input">
                    <option value="">所有仓库</option>
                    <?php foreach ($warehouses as $warehouse): ?>
                        <option value="<?php echo $warehouse['warehouse_id']; ?>" <?php echo $warehouse_id == $warehouse['warehouse_id'] ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($warehouse['warehouse_name']); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="search-group">
                <input type="date" name="start_date" class="search-input date" placeholder="开始日期" value="<?php echo htmlspecialchars($start_date); ?>">
            </div>
            <div class="search-group">
                <input type="date" name="end_date" class="search-input date" placeholder="结束日期" value="<?php echo htmlspecialchars($end_date); ?>">
            </div>
            <button type="submit" class="btn btn-secondary">搜索</button>
            <a href="index.php?page=delivery" class="btn btn-secondary">重置</a>
        </form>
    </div>
</div>

<!-- 出库单列表 -->
<div class="data-wrapper">
    <h4 class="data-title">销售出库单列表 (<?php echo $totalRecords; ?>条记录)</h4>

    <table class="data-table">
        <thead>
            <tr>
                <th>出库单号</th>
                <th>客户</th>
                <th>仓库</th>
                <th>出库日期</th>
                <th>联系人</th>
                <th>联系电话</th>
                <th>出库状态</th>
                <th>创建时间</th>
                <th>操作</th>
            </tr>
        </thead>
        <tbody>
            <?php if (count($deliveries) > 0): ?>
                <?php foreach ($deliveries as $delivery): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($delivery['delivery_number']); ?></td>
                        <td><?php echo htmlspecialchars($delivery['customer_name'] ?? '未知客户'); ?></td>
                        <td><?php echo htmlspecialchars($delivery['warehouse_name'] ?? '未知仓库'); ?></td>
                        <td><?php echo $delivery['delivery_date'] ?? ''; ?></td>
                        <td><?php echo htmlspecialchars($delivery['contact_person'] ?? ''); ?></td>
                        <td><?php echo htmlspecialchars($delivery['contact_phone'] ?? ''); ?></td>
                        <td>
                            <span class="badge badge-<?php echo getDeliveryStatusBadgeClass($delivery['delivery_status'] ?? 'pending'); ?>">
                                <?php echo getDeliveryStatusName($delivery['delivery_status'] ?? 'pending'); ?>
                            </span>
                        </td>
                        <td><?php echo $delivery['created_at'] ?? ''; ?></td>
                        <td>
                            <a href="index.php?page=delivery&action=view&id=<?php echo $delivery['delivery_id']; ?>" class="btn btn-sm btn-info">查看</a>
                            <a href="index.php?page=delivery&action=edit&id=<?php echo $delivery['delivery_id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                            <?php if (($delivery['delivery_status'] ?? 'pending') == 'pending'): ?>
                                <a href="javascript:void(0);" onclick="confirmDelete(<?php echo $delivery['delivery_id']; ?>, '<?php echo htmlspecialchars($delivery['delivery_number']); ?>')" class="btn btn-sm btn-danger">删除</a>
                            <?php endif; ?>
                        </td>
                    </tr>
                <?php endforeach; ?>
            <?php else: ?>
                <tr>
                    <td colspan="9" class="text-center">暂无出库单数据</td>
                </tr>
            <?php endif; ?>
        </tbody>
    </table>

    <!-- 分页控件 -->
    <?php if ($totalPages > 1): ?>
        <div class="pagination">
            <?php if ($page > 1): ?>
                <a href="index.php?page=delivery&listpage=1&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&warehouse_id=<?php echo $warehouse_id; ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item">首页</a>
                <a href="index.php?page=delivery&listpage=<?php echo $page - 1; ?>&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&warehouse_id=<?php echo $warehouse_id; ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item">上一页</a>
            <?php endif; ?>

            <?php
            $startPage = max(1, $page - 2);
            $endPage = min($totalPages, $page + 2);

            for ($i = $startPage; $i <= $endPage; $i++):
            ?>
                <a href="index.php?page=delivery&listpage=<?php echo $i; ?>&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&warehouse_id=<?php echo $warehouse_id; ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item <?php echo $i == $page ? 'active' : ''; ?>"><?php echo $i; ?></a>
            <?php endfor; ?>

            <?php if ($page < $totalPages): ?>
                <a href="index.php?page=delivery&listpage=<?php echo $page + 1; ?>&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&warehouse_id=<?php echo $warehouse_id; ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item">下一页</a>
                <a href="index.php?page=delivery&listpage=<?php echo $totalPages; ?>&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&warehouse_id=<?php echo $warehouse_id; ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item">末页</a>
            <?php endif; ?>
        </div>
    <?php endif; ?>
</div>

<script>
    // 删除出库单确认
    function confirmDelete(deliveryId, deliveryNumber) {
        if (confirm('确定要删除出库单 ' + deliveryNumber + ' 吗？此操作不可恢复！')) {
            window.location.href = 'index.php?page=delivery&action=delete&id=' + deliveryId;
        }
    }
</script>