<?php
session_start();
require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取当前页面
$page = isset($_GET['page']) ? $_GET['page'] : 'customer';

// 检查是否为AJAX请求
$isAjax = false;
if (strpos($page, 'ajax/') === 0) {
    $isAjax = true;
    $ajaxFile = substr($page, 5) . '.php'; // 移除'ajax/'前缀，添加.php后缀
}

// 如果是AJAX请求，直接处理并退出
if ($isAjax) {
    $ajaxPath = __DIR__ . '/ajax/' . $ajaxFile;
    if (file_exists($ajaxPath)) {
        require_once $ajaxPath;
        exit;
    } else {
        header('HTTP/1.1 404 Not Found');
        echo json_encode(['success' => false, 'message' => '找不到AJAX处理文件: ' . $ajaxFile]);
        exit;
    }
}

// 页面标题
$pageTitle = '销售管理';
$subTitle = '';

// 获取子页面内容
$contentFile = '';
switch ($page) {
    case 'customer':
        $contentFile = 'customer.php';
        $subTitle = '客户管理';
        break;
    case 'order':
        $contentFile = 'order.php';
        $subTitle = '销售订单';
        break;
    case 'invoice':
        $contentFile = 'invoice.php';
        $subTitle = '销售开单';
        break;
    case 'delivery':
        $contentFile = 'delivery.php';
        $subTitle = '销售出库';
        break;
    case 'statement':
        $contentFile = 'statement.php';
        $subTitle = '对账结算';
        break;
    case 'custom_bill':
        $contentFile = 'custom_bill.php';
        $subTitle = '自定义账单';
        break;
    default:
        $contentFile = 'customer.php';
        $subTitle = '客户管理';
}

// 检查文件是否存在
if (!file_exists($contentFile)) {
    $contentFile = 'customer.php';
    $subTitle = '客户管理';
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $subTitle; ?> - <?php echo $pageTitle; ?> - <?php echo SITE_NAME; ?></title>
    <link rel="stylesheet" href="../../css/style.css">
    <!-- 添加jQuery和Bootstrap JS支持，用于模态框等功能 -->
    <script src="https://cdn.jsdelivr.net/npm/jquery@3.6.4/dist/jquery.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.2/dist/js/bootstrap.bundle.min.js"></script>
</head>

<body>
    <header class="main-header">
        <div class="user-info">
            <span class="user-name"><?php echo isset($_SESSION['full_name']) ? $_SESSION['full_name'] : '用户'; ?></span>
            <span class="user-role"><?php echo $_SESSION['user_role']; ?></span>
        </div>

        <div class="site-title">
            <h1><?php echo SITE_NAME; ?></h1>
            <p><?php echo SITE_SUBTITLE; ?></p>
        </div>

        <div class="header-actions">
            <a href="../../logout.php" class="btn btn-logout">退出登录</a>
        </div>
    </header>

    <div class="module-layout">
        <aside class="module-sidebar">
            <div class="module-sidebar-header">
                <h2><?php echo $pageTitle; ?></h2>
            </div>

            <nav class="module-nav">
                <a href="../../home.php" class="module-nav-item">返回首页</a>
                <a href="index.php?page=customer" class="module-nav-item <?php echo $page == 'customer' ? 'active' : ''; ?>">客户管理</a>
                <a href="index.php?page=order" class="module-nav-item <?php echo $page == 'order' ? 'active' : ''; ?>">销售订单</a>
                <a href="index.php?page=invoice" class="module-nav-item <?php echo $page == 'invoice' ? 'active' : ''; ?>">销售开单</a>
                <a href="index.php?page=delivery" class="module-nav-item <?php echo $page == 'delivery' ? 'active' : ''; ?>">销售出库</a>
                <a href="index.php?page=statement" class="module-nav-item <?php echo $page == 'statement' ? 'active' : ''; ?>">对账结算</a>
                <a href="index.php?page=custom_bill" class="module-nav-item <?php echo $page == 'custom_bill' ? 'active' : ''; ?>">自定义账单</a>
            </nav>
        </aside>

        <main class="module-content">
            <div class="module-content-header">
                <h2><?php echo $subTitle; ?></h2>
            </div>
            <?php
            // 处理URL中的消息参数
            if (isset($_GET['message'])) {
                $message = $_GET['message'];
                $messageType = isset($_GET['messageType']) ? $_GET['messageType'] : 'info';
            }

            // 包含子页面内容
            if (file_exists($contentFile)) {
                include $contentFile;
            } else {
                echo "<div class='alert alert-error'>找不到页面文件: {$contentFile}</div>";
            }
            ?>
        </main>
    </div>

    <footer class="main-footer">
        <p>&copy; <?php echo date('Y'); ?> <?php echo SITE_NAME; ?> - 版权所有</p>
    </footer>
</body>

</html>