<?php
// 定义系统内访问标志
define('IN_SYSTEM', true);

// 获取操作
$action = isset($_GET['action']) ? $_GET['action'] : 'list';

// 消息提示
$message = '';
$messageType = 'info'; // success, info, warning, error

// 设置页码、搜索条件等参数
$page = isset($_GET['listpage']) ? max(1, intval($_GET['listpage'])) : 1;
$limit = 10;
$offset = ($page - 1) * $limit;
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$status = isset($_GET['status']) ? trim($_GET['status']) : '';
$type = isset($_GET['type']) ? trim($_GET['type']) : '';
$start_date = isset($_GET['start_date']) ? trim($_GET['start_date']) : '';
$end_date = isset($_GET['end_date']) ? trim($_GET['end_date']) : '';

// 处理不同操作
switch ($action) {
    case 'add':
        // 添加发票
        if ($_SERVER['REQUEST_METHOD'] == 'POST') {
            // 记录表单提交数据用于调试
            error_log("销售开单表单提交数据: " . print_r($_POST, true));

            // 特别记录枚举字段的原始值用于调试
            error_log("原始payment_status值: '" . ($_POST['payment_status'] ?? '未设置') . "'");
            error_log("原始invoice_status值: '" . ($_POST['invoice_status'] ?? '未设置') . "'");
            error_log("原始invoice_type值: '" . ($_POST['invoice_type'] ?? '未设置') . "'");

            // 添加更多调试日志
            $debugMode = isset($_GET['debug']) || isset($_POST['_debug_submit']);
            if ($debugMode) {
                error_log("发票数据 - 调试模式激活");
                error_log("HTTP请求方法: " . $_SERVER['REQUEST_METHOD']);
                error_log("请求URL: " . $_SERVER['REQUEST_URI']);
                error_log("发票编号: " . ($_POST['invoice_number'] ?? '未提供'));
                error_log("客户ID: " . ($_POST['customer_id'] ?? '未提供'));
                error_log("订单ID: " . ($_POST['order_id'] ?? '未提供'));
                error_log("发票类型: " . ($_POST['invoice_type'] ?? '未提供'));

                if (isset($_POST['items']) && is_array($_POST['items'])) {
                    error_log("检测到items数组，数量: " . count($_POST['items']));
                    foreach ($_POST['items'] as $index => $item) {
                        error_log("商品 #$index - 商品ID: " . ($item['product_id'] ?? '无') .
                            ", 仓库ID: " . ($item['warehouse_id'] ?? '无') .
                            ", 批次ID: " . ($item['batch_id'] ?? '无'));
                    }
                } else if (isset($_POST['product_id']) && is_array($_POST['product_id'])) {
                    error_log("检测到product_id数组，数量: " . count($_POST['product_id']));
                    foreach ($_POST['product_id'] as $index => $productId) {
                        error_log("商品 #$index - 商品ID: $productId, " .
                            "仓库ID: " . ($_POST['warehouse_id'][$index] ?? '无') .
                            ", 批次ID: " . ($_POST['batch_id'][$index] ?? '无'));
                    }
                } else {
                    error_log("未检测到商品数据！");
                }
            }

            // 处理表单提交
            $formData = $_POST;
            $errors = validateInvoiceData($formData);

            if (empty($errors)) {
                try {
                    // 检查客户是否存在
                    $checkCustomerSql = "SELECT COUNT(*) as cnt FROM customers WHERE customer_id = ?";
                    $checkStmt = $conn->prepare($checkCustomerSql);
                    $checkStmt->bind_param("i", $formData['customer_id']);
                    $checkStmt->execute();
                    $result = $checkStmt->get_result();
                    $row = $result->fetch_assoc();
                    if ($row['cnt'] == 0) {
                        throw new Exception("客户ID不存在: " . $formData['customer_id']);
                    }

                    // 如果有订单ID，检查订单是否存在
                    $orderId = !empty($formData['order_id']) ? $formData['order_id'] : null;
                    if (!empty($orderId)) {
                        $checkOrderSql = "SELECT COUNT(*) as cnt FROM sales_orders WHERE order_id = ?";
                        $checkStmt = $conn->prepare($checkOrderSql);
                        $checkStmt->bind_param("i", $orderId);
                        $checkStmt->execute();
                        $result = $checkStmt->get_result();
                        $row = $result->fetch_assoc();
                        if ($row['cnt'] == 0) {
                            throw new Exception("订单ID不存在: " . $orderId);
                        }
                    }

                    $invoiceId = createInvoice($conn, $formData);
                    if ($invoiceId) {
                        // 记录操作日志
                        $operationDetails = "创建销售开单: " . $formData['invoice_number'];
                        log_operation($_SESSION['user_id'], '创建销售开单', $operationDetails);

                        // 重定向到列表页
                        header('Location: index.php?page=invoice&message=创建销售开单成功&messageType=success');
                        exit;
                    } else {
                        error_log("创建销售开单失败,但没有抛出异常");
                        $message = '创建销售开单失败，请重试';
                        $messageType = 'error';
                    }
                } catch (Exception $e) {
                    error_log("创建销售开单异常: " . $e->getMessage());
                    $message = '系统错误: ' . $e->getMessage();
                    $messageType = 'error';
                }
            } else {
                // 记录验证错误
                error_log("销售开单表单验证错误: " . print_r($errors, true));

                // 显示验证错误
                $message = implode('<br>', $errors);
                $messageType = 'error';
            }
        }
        // 显示添加表单
        include 'invoice_form.php';
        break;

    case 'edit':
        // 编辑发票
        $id = isset($_GET['id']) ? intval($_GET['id']) : 0;

        if ($id <= 0) {
            $message = '未指定发票ID';
            $messageType = 'error';
            include 'invoice_list.php';
            break;
        }

        if ($_SERVER['REQUEST_METHOD'] == 'POST') {
            // 处理表单提交
            $formData = $_POST;

            // 确保POST中包含invoice_id字段
            if (empty($formData['invoice_id'])) {
                $message = '未指定发票ID';
                $messageType = 'error';
                include 'invoice_list.php';
                break;
            }

            // 使用表单中提交的发票ID
            $id = intval($formData['invoice_id']);
            error_log("编辑模式 - 使用POST提交的invoice_id值: " . $id);

            // 记录枚举字段的原始值用于调试
            error_log("编辑模式 - 原始payment_status值: '" . ($formData['payment_status'] ?? '未设置') . "'");
            error_log("编辑模式 - 原始invoice_status值: '" . ($formData['invoice_status'] ?? '未设置') . "'");
            error_log("编辑模式 - 原始invoice_type值: '" . ($formData['invoice_type'] ?? '未设置') . "'");

            $errors = validateInvoiceData($formData);

            if (empty($errors)) {
                try {
                    // 更新发票
                    if (updateInvoice($conn, $id, $formData)) {
                        // 记录操作日志
                        $operationDetails = "更新销售开单: " . $formData['invoice_number'];
                        log_operation($_SESSION['user_id'], '更新销售开单', $operationDetails);

                        // 重定向到列表页
                        header('Location: index.php?page=invoice&message=更新销售开单成功&messageType=success');
                        exit;
                    } else {
                        $message = '更新销售开单失败，请重试';
                        $messageType = 'error';
                    }
                } catch (Exception $e) {
                    $message = '系统错误: ' . $e->getMessage();
                    $messageType = 'error';
                    error_log($e->getMessage());
                }
            } else {
                // 显示验证错误
                $message = implode('<br>', $errors);
                $messageType = 'error';
            }
        }

        // 获取发票数据和发票明细
        $invoiceSql = "SELECT * FROM sales_invoices WHERE invoice_id = ?";
        $stmt = $conn->prepare($invoiceSql);
        $stmt->bind_param("i", $id);
        $stmt->execute();
        $result = $stmt->get_result();
        $invoice = $result->fetch_assoc();

        if (!$invoice) {
            $message = '找不到指定的发票';
            $messageType = 'error';
            include 'invoice_list.php';
            break;
        }

        // 获取发票明细
        $itemsSql = "SELECT si.*, p.unit FROM sales_invoice_items si 
                    LEFT JOIN products p ON si.product_id = p.product_id
                    WHERE si.invoice_id = ?";
        $stmt = $conn->prepare($itemsSql);
        $stmt->bind_param("i", $id);
        $stmt->execute();
        $result = $stmt->get_result();
        $invoiceItems = [];
        while ($row = $result->fetch_assoc()) {
            // 获取该商品的最近一次入库记录以推断仓库ID
            $warehouseSql = "SELECT warehouse_id 
                           FROM inventory 
                           WHERE product_id = ? 
                           LIMIT 1";
            $warehouseStmt = $conn->prepare($warehouseSql);
            $warehouseStmt->bind_param("i", $row['product_id']);
            $warehouseStmt->execute();
            $warehouseResult = $warehouseStmt->get_result();
            $warehouseRow = $warehouseResult->fetch_assoc();

            // 设置默认仓库ID（如果存在记录）
            $row['warehouse_id'] = $warehouseRow ? $warehouseRow['warehouse_id'] : null;

            // 获取批次信息
            if ($row['warehouse_id']) {
                $batchesSql = "SELECT pb.batch_id, pb.batch_number, SUM(i.quantity) as quantity  
                              FROM product_batches pb
                              JOIN inventory i ON pb.batch_id = i.batch_id
                              WHERE i.product_id = ? AND i.warehouse_id = ?
                              GROUP BY pb.batch_id, pb.batch_number
                              HAVING SUM(i.quantity) > 0";
                $batchesStmt = $conn->prepare($batchesSql);
                $batchesStmt->bind_param("ii", $row['product_id'], $row['warehouse_id']);
                $batchesStmt->execute();
                $batchesResult = $batchesStmt->get_result();

                $row['batches'] = [];
                while ($batchRow = $batchesResult->fetch_assoc()) {
                    $row['batches'][] = $batchRow;
                }
            }

            $invoiceItems[] = $row;
        }

        // 显示编辑表单
        include 'invoice_form.php';
        break;

    case 'update':
        // 处理编辑表单提交
        if ($_SERVER['REQUEST_METHOD'] != 'POST') {
            header('Location: index.php?page=invoice');
            exit;
        }

        // 处理表单提交
        $formData = $_POST;

        // 确保POST中包含invoice_id字段
        if (empty($formData['invoice_id'])) {
            $message = '未指定发票ID';
            $messageType = 'error';
            include 'invoice_list.php';
            break;
        }

        // 使用表单中提交的发票ID
        $id = intval($formData['invoice_id']);
        error_log("更新模式 - 使用POST提交的invoice_id值: " . $id);

        // 记录枚举字段的原始值用于调试
        error_log("更新模式 - 原始payment_status值: '" . ($formData['payment_status'] ?? '未设置') . "'");
        error_log("更新模式 - 原始invoice_status值: '" . ($formData['invoice_status'] ?? '未设置') . "'");
        error_log("更新模式 - 原始invoice_type值: '" . ($formData['invoice_type'] ?? '未设置') . "'");

        $errors = validateInvoiceData($formData);

        if (empty($errors)) {
            try {
                // 更新发票
                if (updateInvoice($conn, $id, $formData)) {
                    // 记录操作日志
                    $operationDetails = "更新销售开单: " . $formData['invoice_number'];
                    log_operation($_SESSION['user_id'], '更新销售开单', $operationDetails);

                    // 重定向到列表页
                    header('Location: index.php?page=invoice&message=更新销售开单成功&messageType=success');
                    exit;
                } else {
                    $message = '更新销售开单失败，请重试';
                    $messageType = 'error';
                }
            } catch (Exception $e) {
                $message = '系统错误: ' . $e->getMessage();
                $messageType = 'error';
                error_log($e->getMessage());
            }
        } else {
            // 显示验证错误
            $message = implode('<br>', $errors);
            $messageType = 'error';
        }

        // 如果出现错误，重定向回编辑页面
        header('Location: index.php?page=invoice&action=edit&id=' . $id . '&message=' . urlencode($message) . '&messageType=' . $messageType);
        exit;
        break;

    case 'view':
        // 查看发票详情
        $id = isset($_GET['id']) ? intval($_GET['id']) : 0;

        if ($id <= 0) {
            $message = '未指定发票ID';
            $messageType = 'error';
            include 'invoice_list.php';
            break;
        }

        // 显示详情页
        include 'invoice_view.php';
        break;

    case 'delete':
        // 删除发票
        $id = isset($_GET['id']) ? intval($_GET['id']) : 0;

        if ($id <= 0) {
            $message = '未指定发票ID';
            $messageType = 'error';
            include 'invoice_list.php';
            break;
        }

        // 获取发票信息用于日志记录
        $stmt = $conn->prepare("SELECT invoice_number FROM sales_invoices WHERE invoice_id = ?");
        $stmt->bind_param("i", $id);
        $stmt->execute();
        $result = $stmt->get_result();
        $invoiceNumber = '';
        if ($row = $result->fetch_assoc()) {
            $invoiceNumber = $row['invoice_number'];
        }

        // 先删除发票明细
        $deleteItemsSql = "DELETE FROM sales_invoice_items WHERE invoice_id = ?";
        $stmt = $conn->prepare($deleteItemsSql);
        $stmt->bind_param("i", $id);
        $stmt->execute();

        // 再删除发票主记录
        $deleteInvoiceSql = "DELETE FROM sales_invoices WHERE invoice_id = ?";
        $stmt = $conn->prepare($deleteInvoiceSql);
        $stmt->bind_param("i", $id);
        $result = $stmt->execute();

        if ($result) {
            // 记录操作日志
            $operationDetails = "删除销售开单: " . $invoiceNumber;
            log_operation($_SESSION['user_id'], '删除销售开单', $operationDetails);

            $message = '销售开单删除成功';
            $messageType = 'success';
        } else {
            $message = '销售开单删除失败: ' . $conn->error;
            $messageType = 'error';
        }

        // 重定向到列表页
        header('Location: index.php?page=invoice&message=' . urlencode($message) . '&messageType=' . $messageType);
        exit;
        break;

    case 'list':
    default:
        // 从GET参数获取消息和消息类型
        if (isset($_GET['message'])) {
            $message = $_GET['message'];
            $messageType = isset($_GET['messageType']) ? $_GET['messageType'] : 'info';
        }

        // 初始化变量以避免未定义错误
        $totalRecords = 0;
        $invoices = [];
        $totalPages = 1;

        // 构建查询条件
        $where = "1=1";
        $params = [];
        $types = "";

        if (!empty($search)) {
            $where .= " AND (invoice_number LIKE ? OR c.customer_name LIKE ?)";
            $searchParam = "%{$search}%";
            $params[] = $searchParam;
            $params[] = $searchParam;
            $types .= "ss";
        }

        if (!empty($status)) {
            $where .= " AND invoice_status = ?";
            $params[] = $status;
            $types .= "s";
        }

        if (!empty($type)) {
            $where .= " AND invoice_type = ?";
            $params[] = $type;
            $types .= "s";
        }

        if (!empty($start_date)) {
            $where .= " AND invoice_date >= ?";
            $params[] = $start_date;
            $types .= "s";
        }

        if (!empty($end_date)) {
            $where .= " AND invoice_date <= ?";
            $params[] = $end_date;
            $types .= "s";
        }

        // 获取总记录数
        $countSql = "SELECT COUNT(*) as total FROM sales_invoices i LEFT JOIN customers c ON i.customer_id = c.customer_id WHERE $where";
        if (!empty($params)) {
            $stmt = $conn->prepare($countSql);
            $stmt->bind_param($types, ...$params);
            $stmt->execute();
            $result = $stmt->get_result();
            $row = $result->fetch_assoc();
            $totalRecords = $row['total'] ?? 0;
        } else {
            $result = $conn->query($countSql);
            $row = $result->fetch_assoc();
            $totalRecords = $row['total'] ?? 0;
        }

        // 计算总页数
        $totalPages = ceil($totalRecords / $limit);
        $page = min($page, max(1, $totalPages));

        // 获取发票列表
        $sql = "SELECT i.*, c.customer_name 
                FROM sales_invoices i 
                LEFT JOIN customers c ON i.customer_id = c.customer_id 
                WHERE $where 
                ORDER BY i.invoice_date DESC, i.invoice_id DESC 
                LIMIT ?, ?";

        $limitParams = [$offset, $limit];
        $limitTypes = "ii";

        $allParams = array_merge($params, $limitParams);
        $allTypes = $types . $limitTypes;

        $stmt = $conn->prepare($sql);
        $stmt->bind_param($allTypes, ...$allParams);
        $stmt->execute();
        $result = $stmt->get_result();

        $invoices = [];
        while ($result && $row = $result->fetch_assoc()) {
            $invoices[] = $row;
        }

        // 包含列表页面
        include 'invoice_list.php';
        break;
}

/**
 * 验证销售开单数据
 * @param array $data 表单数据
 * @return array 错误信息
 */
function validateInvoiceData($data)
{
    $errors = [];

    // 记录验证开始及数据
    error_log("开始验证销售开单数据: " . print_r($data, true));

    // 适应items数组格式的表单提交
    if (isset($data['items']) && is_array($data['items'])) {
        error_log("检测到items数组格式，进行数据适配");

        // 初始化数组
        if (!isset($data['product_id'])) $data['product_id'] = [];
        if (!isset($data['warehouse_id'])) $data['warehouse_id'] = [];
        if (!isset($data['batch_id'])) $data['batch_id'] = [];
        if (!isset($data['quantity'])) $data['quantity'] = [];
        if (!isset($data['unit_price'])) $data['unit_price'] = [];
        if (!isset($data['discount_rate'])) $data['discount_rate'] = [];
        if (!isset($data['item_remark'])) $data['item_remark'] = [];

        // 从items中提取数据
        foreach ($data['items'] as $index => $item) {
            if (!empty($item['product_id'])) {
                $data['product_id'][] = $item['product_id'];
                $data['warehouse_id'][] = $item['warehouse_id'] ?? '';
                $data['batch_id'][] = $item['batch_id'] ?? '';
                $data['quantity'][] = $item['quantity'] ?? 0;
                $data['unit_price'][] = $item['unit_price'] ?? 0;
                $data['discount_rate'][] = $item['discount_rate'] ?? 0;
                $data['item_remark'][] = $item['remark'] ?? '';
            }
        }

        error_log("数据适配后结果: " .
            "商品数: " . count($data['product_id']) . ", " .
            "仓库数: " . count($data['warehouse_id']) . ", " .
            "批次数: " . count($data['batch_id']));
    } else {
        error_log("使用标准数组格式验证");
    }

    // 验证发票号
    if (empty($data['invoice_number'])) {
        $errors[] = '发票编号不能为空';
    }

    // 验证客户ID
    if (empty($data['customer_id'])) {
        $errors[] = '请选择客户';
    }

    // 验证发票日期
    if (empty($data['invoice_date'])) {
        $errors[] = '发票日期不能为空';
    }

    // 验证发票类型
    if (empty($data['invoice_type']) || !in_array($data['invoice_type'], ['retail', 'wholesale'])) {
        $errors[] = '请选择有效的发票类型';
    }

    // 验证发票状态
    if (empty($data['invoice_status']) || !in_array($data['invoice_status'], ['draft', 'issued', 'cancelled'])) {
        $errors[] = '请选择有效的发票状态';
    }

    // 验证付款状态
    if (empty($data['payment_status'])) {
        $errors[] = '请选择有效的付款状态';
        error_log("付款状态为空");
    } else {
        // 修剪并检查payment_status的有效性
        $data['payment_status'] = trim($data['payment_status']);
        // 转换为小写，避免大小写问题
        $data['payment_status'] = strtolower($data['payment_status']);
        // 过滤掉所有不可见字符和特殊字符，只保留字母
        $data['payment_status'] = preg_replace('/[^a-z]/', '', $data['payment_status']);

        error_log("清理后的付款状态: '" . $data['payment_status'] . "', 长度: " . strlen($data['payment_status']));
        error_log("二进制表示: " . bin2hex($data['payment_status']));

        if (!in_array($data['payment_status'], ['unpaid', 'partial', 'paid'])) {
            $errors[] = '请选择有效的付款状态';
            error_log("无效的付款状态: '" . $data['payment_status'] . "'");
        }
    }

    // 验证商品明细
    if (empty($data['product_id']) || !is_array($data['product_id']) || count($data['product_id']) == 0) {
        $errors[] = '请至少添加一个商品';
        error_log("商品验证失败: " . (empty($data['product_id']) ? "product_id为空" : (is_array($data['product_id']) ? "数组长度为" . count($data['product_id']) : "product_id不是数组")));
    } else {
        // 验证每个商品的数量和单价
        foreach ($data['product_id'] as $index => $productId) {
            if (empty($productId)) {
                $errors[] = '请选择商品';
                error_log("商品ID为空，index=$index");
                break;
            }

            // 记录每个项目的数据
            error_log("检查商品项目 index=$index: product_id=$productId");

            if (!isset($data['warehouse_id'][$index]) || empty($data['warehouse_id'][$index])) {
                $errors[] = '请选择仓库';
                error_log("仓库ID为空，index=$index");
                break;
            }

            if (!isset($data['batch_id'][$index]) || empty($data['batch_id'][$index])) {
                $errors[] = '请选择批次';
                error_log("批次ID为空，index=$index");
                break;
            }

            $quantity = isset($data['quantity'][$index]) ? intval($data['quantity'][$index]) : 0;
            if ($quantity <= 0) {
                $errors[] = '商品数量必须大于0';
                error_log("商品数量无效: quantity=$quantity, index=$index");
                break;
            }

            $unitPrice = isset($data['unit_price'][$index]) ? floatval($data['unit_price'][$index]) : 0;
            if ($unitPrice <= 0) {
                $errors[] = '商品单价必须大于0';
                error_log("商品单价无效: unit_price=$unitPrice, index=$index");
                break;
            }
        }
    }

    // 记录验证结果
    error_log("销售开单数据验证结果: " . (empty($errors) ? "验证通过" : "验证失败，错误: " . implode(", ", $errors)));

    return $errors;
}

/**
 * 创建销售开单
 * @param mysqli $conn 数据库连接
 * @param array $data 表单数据
 * @return int|bool 成功返回发票ID，失败返回false
 */
function createInvoice($conn, $data)
{
    // 记录创建开始
    error_log("开始创建销售开单，数据: " . json_encode(array_keys($data)));

    // 开始事务
    $conn->begin_transaction();

    try {
        error_log("计算总金额...");

        // 计算总金额
        $totalAmount = 0;

        // 根据表单提交的格式计算总金额
        if (isset($data['items']) && is_array($data['items'])) {
            error_log("使用items格式计算总金额，项目数: " . count($data['items']));
            foreach ($data['items'] as $item) {
                if (!empty($item['product_id'])) {
                    $quantity = isset($item['quantity']) ? intval($item['quantity']) : 0;
                    $unitPrice = isset($item['unit_price']) ? floatval($item['unit_price']) : 0;
                    $discountRate = isset($item['discount_rate']) ? floatval($item['discount_rate']) : 0;

                    $itemAmount = $quantity * $unitPrice * (1 - $discountRate / 100);
                    $totalAmount += $itemAmount;

                    error_log("商品: {$item['product_id']}, 数量: $quantity, 单价: $unitPrice, 折扣: $discountRate%, 小计: $itemAmount");
                }
            }
        } else if (isset($data['product_id']) && is_array($data['product_id'])) {
            error_log("使用标准数组格式计算总金额，商品数: " . count($data['product_id']));
            foreach ($data['product_id'] as $index => $productId) {
                $quantity = isset($data['quantity'][$index]) ? intval($data['quantity'][$index]) : 0;
                $unitPrice = isset($data['unit_price'][$index]) ? floatval($data['unit_price'][$index]) : 0;
                $discountRate = isset($data['discount_rate'][$index]) ? floatval($data['discount_rate'][$index]) : 0;

                $itemAmount = $quantity * $unitPrice * (1 - $discountRate / 100);
                $totalAmount += $itemAmount;

                error_log("商品: $productId, 数量: $quantity, 单价: $unitPrice, 折扣: $discountRate%, 小计: $itemAmount");
            }
        } else {
            error_log("警告：未找到有效的商品数据!");
        }

        error_log("总金额计算完成: $totalAmount");
        error_log("准备插入发票主记录...");

        // 准备SQL参数
        $invoice_number = $conn->real_escape_string($data['invoice_number']);
        $order_id = !empty($data['order_id']) ? intval($data['order_id']) : "NULL";
        $customer_id = intval($data['customer_id']);
        $invoice_date = $conn->real_escape_string($data['invoice_date']);

        // 安全处理枚举值
        $invoice_type = 'retail'; // 默认值
        if (!empty($data['invoice_type']) && in_array($data['invoice_type'], ['retail', 'wholesale'])) {
            $invoice_type = $conn->real_escape_string($data['invoice_type']);
        }

        $invoice_status = 'draft'; // 默认值
        if (!empty($data['invoice_status']) && in_array($data['invoice_status'], ['draft', 'issued', 'cancelled'])) {
            $invoice_status = $conn->real_escape_string($data['invoice_status']);
        }

        $payment_status = 'unpaid'; // 默认值
        if (!empty($data['payment_status']) && in_array($data['payment_status'], ['unpaid', 'partial', 'paid'])) {
            $payment_status = $conn->real_escape_string($data['payment_status']);
        }

        $paid_amount = !empty($data['paid_amount']) ? floatval($data['paid_amount']) : 0;
        $due_date = !empty($data['due_date']) ? "'" . $conn->real_escape_string($data['due_date']) . "'" : "NULL";
        $remark = !empty($data['remark']) ? "'" . $conn->real_escape_string($data['remark']) . "'" : "''";
        $created_by = intval($_SESSION['user_id']);

        // 记录参数
        error_log("构建SQL参数...");
        error_log("invoice_number: $invoice_number");
        error_log("order_id: " . ($order_id === "NULL" ? "NULL" : $order_id));
        error_log("customer_id: $customer_id");
        error_log("invoice_date: $invoice_date");
        error_log("invoice_type: $invoice_type (来自表单, 已验证)");
        error_log("invoice_status: $invoice_status (来自表单, 已验证)");
        error_log("payment_status: $payment_status (来自表单, 已验证)");
        error_log("total_amount: $totalAmount");
        error_log("paid_amount: $paid_amount");
        error_log("due_date: " . ($due_date === "NULL" ? "NULL" : $due_date));
        error_log("remark: $remark");
        error_log("created_by: $created_by");

        // 构建SQL语句，使用直接值而不是参数绑定
        $sql = "INSERT INTO sales_invoices (
                    invoice_number, order_id, customer_id, invoice_date, 
                    invoice_type, invoice_status, payment_status, 
                    total_amount, paid_amount, due_date, remark, created_by
                ) VALUES (
                    '$invoice_number', 
                    " . ($order_id === "NULL" ? "NULL" : $order_id) . ", 
                    $customer_id, 
                    '$invoice_date', 
                    '$invoice_type', 
                    '$invoice_status', 
                    '$payment_status', 
                    $totalAmount, 
                    $paid_amount, 
                    " . ($due_date === "NULL" ? "NULL" : $due_date) . ", 
                    $remark, 
                    $created_by
                )";

        error_log("执行SQL: " . $sql);
        $result = $conn->query($sql);

        if (!$result) {
            $errorInfo = $conn->error ? $conn->error : "未知错误";
            error_log("插入失败，错误信息: " . $errorInfo);
            error_log("SQL语句: " . $sql);
            throw new Exception("创建销售开单失败: " . $errorInfo);
        }

        $invoiceId = $conn->insert_id;
        error_log("发票主记录插入成功，ID: $invoiceId");

        // 插入发票明细
        error_log("开始插入发票明细...");

        // 根据表单提交的格式插入明细
        if (isset($data['items']) && is_array($data['items'])) {
            error_log("使用items格式插入明细，项目数: " . count($data['items']));
            foreach ($data['items'] as $item) {
                if (!empty($item['product_id'])) {
                    $productId = intval($item['product_id']);
                    $warehouseId = isset($item['warehouse_id']) ? intval($item['warehouse_id']) : "NULL";
                    $batchId = isset($item['batch_id']) ? intval($item['batch_id']) : "NULL";
                    $quantity = isset($item['quantity']) ? intval($item['quantity']) : 0;
                    $unitPrice = isset($item['unit_price']) ? floatval($item['unit_price']) : 0;
                    $discountRate = isset($item['discount_rate']) ? floatval($item['discount_rate']) : 0;
                    $itemRemark = isset($item['remark']) ? "'" . $conn->real_escape_string($item['remark']) . "'" : "''";

                    $itemAmount = $quantity * $unitPrice * (1 - $discountRate / 100);

                    error_log("插入明细 - 商品: $productId, 仓库: " . ($warehouseId === "NULL" ? "NULL" : $warehouseId) . ", 批次: " . ($batchId === "NULL" ? "NULL" : $batchId) . ", 数量: $quantity, 单价: $unitPrice");

                    $itemSql = "INSERT INTO sales_invoice_items (
                                    invoice_id, product_id, warehouse_id, batch_id, quantity, 
                                    unit_price, discount_rate, item_amount, remark
                                ) VALUES (
                                    $invoiceId,
                                    $productId,
                                    " . ($warehouseId === "NULL" ? "NULL" : $warehouseId) . ",
                                    " . ($batchId === "NULL" ? "NULL" : $batchId) . ",
                                    $quantity,
                                    $unitPrice,
                                    $discountRate,
                                    $itemAmount,
                                    $itemRemark
                                )";

                    $itemResult = $conn->query($itemSql);
                    if (!$itemResult) {
                        throw new Exception("添加发票明细失败，商品ID: $productId, 错误: " . $conn->error);
                    }
                }
            }
        } else if (isset($data['product_id']) && is_array($data['product_id'])) {
            error_log("使用标准数组格式插入明细，商品数: " . count($data['product_id']));
            foreach ($data['product_id'] as $index => $productId) {
                $productId = intval($productId);
                $warehouseId = isset($data['warehouse_id'][$index]) ? intval($data['warehouse_id'][$index]) : "NULL";
                $batchId = isset($data['batch_id'][$index]) ? intval($data['batch_id'][$index]) : "NULL";
                $quantity = isset($data['quantity'][$index]) ? intval($data['quantity'][$index]) : 0;
                $unitPrice = isset($data['unit_price'][$index]) ? floatval($data['unit_price'][$index]) : 0;
                $discountRate = isset($data['discount_rate'][$index]) ? floatval($data['discount_rate'][$index]) : 0;
                $itemRemark = isset($data['item_remark'][$index]) ? "'" . $conn->real_escape_string($data['item_remark'][$index]) . "'" : "''";

                $itemAmount = $quantity * $unitPrice * (1 - $discountRate / 100);

                error_log("插入明细 - 商品: $productId, 仓库: " . ($warehouseId === "NULL" ? "NULL" : $warehouseId) . ", 批次: " . ($batchId === "NULL" ? "NULL" : $batchId) . ", 数量: $quantity, 单价: $unitPrice");

                $itemSql = "INSERT INTO sales_invoice_items (
                                invoice_id, product_id, warehouse_id, batch_id, quantity, 
                                unit_price, discount_rate, item_amount, remark
                            ) VALUES (
                                $invoiceId,
                                $productId,
                                " . ($warehouseId === "NULL" ? "NULL" : $warehouseId) . ",
                                " . ($batchId === "NULL" ? "NULL" : $batchId) . ",
                                $quantity,
                                $unitPrice,
                                $discountRate,
                                $itemAmount,
                                $itemRemark
                            )";

                $itemResult = $conn->query($itemSql);
                if (!$itemResult) {
                    throw new Exception("添加发票明细失败，商品ID: $productId, 错误: " . $conn->error);
                }
            }
        } else {
            throw new Exception("无有效的商品数据，无法创建发票明细");
        }

        error_log("所有发票明细插入成功");
        error_log("提交事务...");

        // 提交事务
        $conn->commit();
        error_log("销售开单创建成功，ID: $invoiceId");
        return $invoiceId;
    } catch (Exception $e) {
        // 回滚事务
        $conn->rollback();
        error_log("创建销售开单失败: " . $e->getMessage());
        error_log("事务已回滚");
        return false;
    }
}

/**
 * 更新销售开单
 * @param mysqli $conn 数据库连接
 * @param int $invoiceId 发票ID
 * @param array $data 表单数据
 * @return bool 成功返回true，失败返回false
 */
function updateInvoice($conn, $invoiceId, $data)
{
    // 开始事务
    $conn->begin_transaction();

    try {
        error_log("更新销售开单，ID: $invoiceId");
        error_log("接收到的数据: " . print_r($data, true));

        // 检查是否使用了items格式的表单提交
        if (isset($data['items']) && is_array($data['items'])) {
            error_log("检测到items数组格式，进行数据适配");

            // 初始化数组
            if (!isset($data['product_id'])) $data['product_id'] = [];
            if (!isset($data['warehouse_id'])) $data['warehouse_id'] = [];
            if (!isset($data['batch_id'])) $data['batch_id'] = [];
            if (!isset($data['quantity'])) $data['quantity'] = [];
            if (!isset($data['unit_price'])) $data['unit_price'] = [];
            if (!isset($data['discount_rate'])) $data['discount_rate'] = [];
            if (!isset($data['item_remark'])) $data['item_remark'] = [];

            // 从items中提取数据
            foreach ($data['items'] as $index => $item) {
                if (!empty($item['product_id'])) {
                    $data['product_id'][] = $item['product_id'];
                    $data['warehouse_id'][] = $item['warehouse_id'] ?? '';
                    $data['batch_id'][] = $item['batch_id'] ?? '';
                    $data['quantity'][] = $item['quantity'] ?? 0;
                    $data['unit_price'][] = $item['unit_price'] ?? 0;
                    $data['discount_rate'][] = $item['discount_rate'] ?? 0;
                    $data['item_remark'][] = $item['remark'] ?? '';
                }
            }

            error_log("数据适配后结果: " .
                "商品数: " . count($data['product_id']) . ", " .
                "仓库数: " . count($data['warehouse_id']) . ", " .
                "批次数: " . count($data['batch_id']));
        } else {
            error_log("使用标准数组格式更新");
        }

        // 检查是否有商品数据
        if (!isset($data['product_id']) || !is_array($data['product_id']) || empty($data['product_id'])) {
            error_log("错误：未找到有效的商品数据，无法更新发票！");
            throw new Exception("无商品数据，更新失败");
        }

        // 计算总金额
        $totalAmount = 0;
        foreach ($data['product_id'] as $index => $productId) {
            $quantity = isset($data['quantity'][$index]) ? intval($data['quantity'][$index]) : 0;
            $unitPrice = isset($data['unit_price'][$index]) ? floatval($data['unit_price'][$index]) : 0;
            $discountRate = isset($data['discount_rate'][$index]) ? floatval($data['discount_rate'][$index]) : 0;

            $itemAmount = $quantity * $unitPrice * (1 - $discountRate / 100);
            $totalAmount += $itemAmount;
        }

        // 准备SQL参数
        $invoice_number = $conn->real_escape_string($data['invoice_number']);
        $order_id = !empty($data['order_id']) ? intval($data['order_id']) : "NULL";
        $customer_id = intval($data['customer_id']);
        $invoice_date = $conn->real_escape_string($data['invoice_date']);

        // 安全处理枚举值
        $invoice_type = 'retail'; // 默认值
        if (!empty($data['invoice_type']) && in_array($data['invoice_type'], ['retail', 'wholesale'])) {
            $invoice_type = $conn->real_escape_string($data['invoice_type']);
        }

        $invoice_status = 'draft'; // 默认值
        if (!empty($data['invoice_status']) && in_array($data['invoice_status'], ['draft', 'issued', 'cancelled'])) {
            $invoice_status = $conn->real_escape_string($data['invoice_status']);
        }

        $payment_status = 'unpaid'; // 默认值
        if (!empty($data['payment_status']) && in_array($data['payment_status'], ['unpaid', 'partial', 'paid'])) {
            $payment_status = $conn->real_escape_string($data['payment_status']);
        }

        $paid_amount = !empty($data['paid_amount']) ? floatval($data['paid_amount']) : 0;
        $due_date = !empty($data['due_date']) ? "'" . $conn->real_escape_string($data['due_date']) . "'" : "NULL";
        $remark = !empty($data['remark']) ? "'" . $conn->real_escape_string($data['remark']) . "'" : "''";
        $invoiceId = intval($invoiceId);

        // 记录参数
        error_log("构建SQL参数...");
        error_log("invoice_number: $invoice_number");
        error_log("order_id: " . ($order_id === "NULL" ? "NULL" : $order_id));
        error_log("customer_id: $customer_id");
        error_log("invoice_date: $invoice_date");
        error_log("invoice_type: $invoice_type (来自表单, 已验证)");
        error_log("invoice_status: $invoice_status (来自表单, 已验证)");
        error_log("payment_status: $payment_status (来自表单, 已验证)");
        error_log("total_amount: $totalAmount");
        error_log("paid_amount: $paid_amount");
        error_log("due_date: " . ($due_date === "NULL" ? "NULL" : $due_date));
        error_log("remark: $remark");
        error_log("invoice_id: $invoiceId");

        // 构建SQL语句
        $sql = "UPDATE sales_invoices SET 
                invoice_number = '$invoice_number', 
                order_id = " . ($order_id === "NULL" ? "NULL" : $order_id) . ", 
                customer_id = $customer_id, 
                invoice_date = '$invoice_date', 
                invoice_type = '$invoice_type', 
                invoice_status = '$invoice_status', 
                payment_status = '$payment_status', 
                total_amount = $totalAmount, 
                paid_amount = $paid_amount, 
                due_date = " . ($due_date === "NULL" ? "NULL" : $due_date) . ", 
                remark = $remark 
                WHERE invoice_id = $invoiceId";

        error_log("执行SQL: " . $sql);
        $result = $conn->query($sql);

        if (!$result) {
            $errorInfo = $conn->error ? $conn->error : "未知错误";
            error_log("更新失败，错误信息: " . $errorInfo);
            error_log("SQL语句: " . $sql);
            throw new Exception("更新销售开单失败: " . $errorInfo);
        }

        // 删除原有的发票明细
        $deleteSql = "DELETE FROM sales_invoice_items WHERE invoice_id = $invoiceId";
        $deleteResult = $conn->query($deleteSql);
        if (!$deleteResult) {
            throw new Exception("删除原有发票明细失败: " . $conn->error);
        }

        // 插入新的发票明细
        error_log("开始插入更新后的发票明细...");

        foreach ($data['product_id'] as $index => $productId) {
            $productId = intval($productId);
            $warehouseId = isset($data['warehouse_id'][$index]) ? intval($data['warehouse_id'][$index]) : "NULL";
            $batchId = isset($data['batch_id'][$index]) ? intval($data['batch_id'][$index]) : "NULL";
            $quantity = isset($data['quantity'][$index]) ? intval($data['quantity'][$index]) : 0;
            $unitPrice = isset($data['unit_price'][$index]) ? floatval($data['unit_price'][$index]) : 0;
            $discountRate = isset($data['discount_rate'][$index]) ? floatval($data['discount_rate'][$index]) : 0;
            $itemRemark = isset($data['item_remark'][$index]) ? "'" . $conn->real_escape_string($data['item_remark'][$index]) . "'" : "''";

            $itemAmount = $quantity * $unitPrice * (1 - $discountRate / 100);

            error_log("插入明细 - 商品: $productId, 仓库: " . ($warehouseId === "NULL" ? "NULL" : $warehouseId) . ", 批次: " . ($batchId === "NULL" ? "NULL" : $batchId) . ", 数量: $quantity, 单价: $unitPrice");

            $itemSql = "INSERT INTO sales_invoice_items (
                            invoice_id, product_id, warehouse_id, batch_id, quantity, 
                            unit_price, discount_rate, item_amount, remark
                        ) VALUES (
                            $invoiceId,
                            $productId,
                            " . ($warehouseId === "NULL" ? "NULL" : $warehouseId) . ",
                            " . ($batchId === "NULL" ? "NULL" : $batchId) . ",
                            $quantity,
                            $unitPrice,
                            $discountRate,
                            $itemAmount,
                            $itemRemark
                        )";

            $itemResult = $conn->query($itemSql);
            if (!$itemResult) {
                throw new Exception("添加发票明细失败，商品ID: $productId, 错误: " . $conn->error);
            }
        }

        error_log("所有发票明细更新成功");
        error_log("提交事务...");

        // 提交事务
        $conn->commit();
        error_log("销售开单更新成功，ID: $invoiceId");
        return true;
    } catch (Exception $e) {
        // 回滚事务
        $conn->rollback();
        error_log("更新销售开单失败: " . $e->getMessage());
        error_log("事务已回滚");
        return false;
    }
}

/**
 * 生成发票编号
 * @return string 发票编号
 */
function generateInvoiceNumber()
{
    // 格式：INV + 年月 + 3位数字序号
    $prefix = 'INV' . date('Ym');

    global $conn;
    $sql = "SELECT MAX(invoice_number) as max_number FROM sales_invoices WHERE invoice_number LIKE ?";
    $stmt = $conn->prepare($sql);
    $pattern = $prefix . '%';
    $stmt->bind_param("s", $pattern);
    $stmt->execute();
    $result = $stmt->get_result();
    $row = $result->fetch_assoc();

    if ($row && $row['max_number']) {
        // 提取序号部分
        $lastNumber = $row['max_number'];
        $sequence = intval(substr($lastNumber, -3));
        $newSequence = $sequence + 1;
    } else {
        $newSequence = 1;
    }

    // 格式化为3位数字
    return $prefix . str_pad($newSequence, 3, '0', STR_PAD_LEFT);
}

/**
 * 获取发票状态名称
 * @param string $status 状态代码
 * @return string 状态名称
 */
function getInvoiceStatusName($status)
{
    $statusMap = [
        'draft' => '草稿',
        'issued' => '已开票',
        'cancelled' => '已取消'
    ];

    return isset($statusMap[$status]) ? $statusMap[$status] : $status;
}

/**
 * 获取发票类型名称
 * @param string $type 类型代码
 * @return string 类型名称
 */
function getInvoiceTypeName($type)
{
    $typeMap = [
        'retail' => '零售',
        'wholesale' => '批发'
    ];

    return isset($typeMap[$type]) ? $typeMap[$type] : $type;
}

/**
 * 获取付款状态名称
 * @param string $status 状态代码
 * @return string 状态名称
 */
function getPaymentStatusName($status)
{
    $statusMap = [
        'unpaid' => '未支付',
        'partial' => '部分支付',
        'paid' => '已支付'
    ];

    return isset($statusMap[$status]) ? $statusMap[$status] : $status;
}

/**
 * 获取发票状态徽章样式
 * @param string $status 状态代码
 * @return string CSS类名
 */
function getInvoiceStatusBadgeClass($status)
{
    $classMap = [
        'draft' => 'warning',
        'issued' => 'success',
        'cancelled' => 'danger'
    ];

    return isset($classMap[$status]) ? $classMap[$status] : 'default';
}

/**
 * 获取付款状态徽章样式
 * @param string $status 状态代码
 * @return string CSS类名
 */
function getPaymentStatusBadgeClass($status)
{
    $classMap = [
        'unpaid' => 'danger',
        'partial' => 'warning',
        'paid' => 'success'
    ];

    return isset($classMap[$status]) ? $classMap[$status] : 'default';
}
