<?php
// 防止直接访问
defined('IN_SYSTEM') || die('禁止访问');

// 获取发票数据
$invoice = [];
$invoiceItems = [];
if (isset($id)) {
    $invoiceSql = "SELECT i.*, c.customer_name, o.order_number
                   FROM sales_invoices i 
                   LEFT JOIN customers c ON i.customer_id = c.customer_id 
                   LEFT JOIN sales_orders o ON i.order_id = o.order_id
                   WHERE i.invoice_id = ?";
    $stmt = $conn->prepare($invoiceSql);
    $stmt->bind_param("i", $id);
    $stmt->execute();
    $result = $stmt->get_result();
    if ($result && $row = $result->fetch_assoc()) {
        $invoice = $row;

        // 获取发票明细
        $itemsSql = "SELECT ii.*, p.product_name, b.batch_number 
                     FROM sales_invoice_items ii 
                     LEFT JOIN products p ON ii.product_id = p.product_id 
                     LEFT JOIN product_batches b ON ii.batch_id = b.batch_id
                     WHERE ii.invoice_id = ?";
        $stmt = $conn->prepare($itemsSql);
        $stmt->bind_param("i", $id);
        $stmt->execute();
        $result = $stmt->get_result();
        while ($row = $result->fetch_assoc()) {
            $invoiceItems[] = $row;
        }
    }
}
?>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<div class="module-tools">
    <div class="tool-left">
        <a href="index.php?page=invoice" class="btn btn-secondary">返回列表</a>
        <?php if (($invoice['invoice_status'] ?? '') == 'draft'): ?>
            <a href="index.php?page=invoice&action=edit&id=<?php echo $id; ?>" class="btn btn-primary">编辑销售开单</a>
        <?php endif; ?>
    </div>
</div>

<div class="detail-container">
    <h3>销售开单详情</h3>

    <div class="row">
        <div class="col-md-6">
            <div class="card">
                <div class="card-header">
                    <h4>基本信息</h4>
                </div>
                <div class="card-body">
                    <div class="detail-group">
                        <label>发票编号：</label>
                        <span><?php echo htmlspecialchars($invoice['invoice_number'] ?? ''); ?></span>
                    </div>
                    <div class="detail-group">
                        <label>关联订单：</label>
                        <span>
                            <?php if (!empty($invoice['order_number'])): ?>
                                <a href="index.php?page=order&action=view&id=<?php echo $invoice['order_id']; ?>">
                                    <?php echo htmlspecialchars($invoice['order_number']); ?>
                                </a>
                            <?php else: ?>
                                无关联订单
                            <?php endif; ?>
                        </span>
                    </div>
                    <div class="detail-group">
                        <label>客户名称：</label>
                        <span><?php echo htmlspecialchars($invoice['customer_name'] ?? '未知客户'); ?></span>
                    </div>
                    <div class="detail-group">
                        <label>发票日期：</label>
                        <span><?php echo $invoice['invoice_date'] ?? ''; ?></span>
                    </div>
                    <div class="detail-group">
                        <label>发票类型：</label>
                        <span><?php echo getInvoiceTypeName($invoice['invoice_type'] ?? 'retail'); ?></span>
                    </div>
                    <div class="detail-group">
                        <label>付款截止日期：</label>
                        <span><?php echo !empty($invoice['due_date']) ? $invoice['due_date'] : '未设置'; ?></span>
                    </div>
                </div>
            </div>
        </div>

        <div class="col-md-6">
            <div class="card">
                <div class="card-header">
                    <h4>状态信息</h4>
                </div>
                <div class="card-body">
                    <div class="detail-group">
                        <label>发票状态：</label>
                        <span>
                            <span class="badge badge-<?php echo getInvoiceStatusBadgeClass($invoice['invoice_status'] ?? 'draft'); ?>">
                                <?php echo getInvoiceStatusName($invoice['invoice_status'] ?? 'draft'); ?>
                            </span>
                        </span>
                    </div>
                    <div class="detail-group">
                        <label>付款状态：</label>
                        <span>
                            <span class="badge badge-<?php echo getPaymentStatusBadgeClass($invoice['payment_status'] ?? 'unpaid'); ?>">
                                <?php echo getPaymentStatusName($invoice['payment_status'] ?? 'unpaid'); ?>
                            </span>
                        </span>
                    </div>
                    <div class="detail-group">
                        <label>总金额：</label>
                        <span><?php echo number_format($invoice['total_amount'] ?? 0, 2); ?> 元</span>
                    </div>
                    <div class="detail-group">
                        <label>已付金额：</label>
                        <span><?php echo number_format($invoice['paid_amount'] ?? 0, 2); ?> 元</span>
                    </div>
                    <div class="detail-group">
                        <label>创建人：</label>
                        <span><?php echo $invoice['created_by'] ?? ''; ?></span>
                    </div>
                    <div class="detail-group">
                        <label>创建时间：</label>
                        <span><?php echo $invoice['created_at'] ?? ''; ?></span>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="row mt-4">
        <div class="col-md-12">
            <div class="card">
                <div class="card-header">
                    <h4>发票明细</h4>
                </div>
                <div class="card-body">
                    <div class="table-responsive">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>商品</th>
                                    <th>批次</th>
                                    <th>单价(元)</th>
                                    <th>数量</th>
                                    <th>折扣率(%)</th>
                                    <th>小计(元)</th>
                                    <th>备注</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (count($invoiceItems) > 0): ?>
                                    <?php foreach ($invoiceItems as $item): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($item['product_name'] ?? '未知商品'); ?></td>
                                            <td><?php echo htmlspecialchars($item['batch_number'] ?? '无批次'); ?></td>
                                            <td class="text-right"><?php echo number_format($item['unit_price'] ?? 0, 2); ?></td>
                                            <td class="text-right"><?php echo $item['quantity'] ?? 0; ?></td>
                                            <td class="text-right"><?php echo $item['discount_rate'] ?? 0; ?></td>
                                            <td class="text-right"><?php echo number_format($item['item_amount'] ?? 0, 2); ?></td>
                                            <td><?php echo htmlspecialchars($item['remark'] ?? ''); ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <tr>
                                        <td colspan="7" class="text-center">暂无发票明细</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                            <tfoot>
                                <tr>
                                    <td colspan="5" class="text-right"><strong>总计：</strong></td>
                                    <td class="text-right"><strong><?php echo number_format($invoice['total_amount'] ?? 0, 2); ?></strong></td>
                                    <td></td>
                                </tr>
                            </tfoot>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <?php if (!empty($invoice['remark'])): ?>
        <div class="row mt-4">
            <div class="col-md-12">
                <div class="card">
                    <div class="card-header">
                        <h4>备注</h4>
                    </div>
                    <div class="card-body">
                        <div class="detail-group">
                            <p><?php echo nl2br(htmlspecialchars($invoice['remark'])); ?></p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    <?php endif; ?>
</div>