<?php
// 防止直接访问
if (!defined('IN_SYSTEM')) {
    define('IN_SYSTEM', true);
}

// 获取操作类型
$action = isset($_GET['action']) ? $_GET['action'] : 'list';

// 获取分页参数
$page = isset($_GET['listpage']) ? intval($_GET['listpage']) : 1;
$limit = 20;
$offset = ($page - 1) * $limit;

// 获取搜索参数
$search = isset($_GET['search']) ? sanitize($_GET['search']) : '';
$status = isset($_GET['status']) ? sanitize($_GET['status']) : '';
$customer_id = isset($_GET['customer_id']) ? intval($_GET['customer_id']) : 0;
$start_date = isset($_GET['start_date']) ? sanitize($_GET['start_date']) : '';
$end_date = isset($_GET['end_date']) ? sanitize($_GET['end_date']) : '';

// 生成应收账款编号
function generateReceivableNumber()
{
    global $conn;

    // 获取下一个整数ID
    $sql = "SELECT MAX(receivable_id) AS max_id FROM sales_receivables";
    $result = $conn->query($sql);

    if ($result && $row = $result->fetch_assoc()) {
        $maxId = $row['max_id'] ? intval($row['max_id']) : 0;
        return $maxId + 1;
    } else {
        return 1; // 第一条记录
    }
}

// 获取支付状态名称
function getPaymentStatusName($status)
{
    switch ($status) {
        case 'unpaid':
            return '待付款';
        case 'partial':
            return '部分付款';
        case 'paid':
            return '已付清';
        case 'overdue':
            return '已逾期';
        default:
            return '未知状态';
    }
}

// 获取支付状态徽章样式类
function getPaymentStatusBadgeClass($status)
{
    switch ($status) {
        case 'unpaid':
            return 'secondary';
        case 'partial':
            return 'info';
        case 'paid':
            return 'success';
        case 'overdue':
            return 'danger';
        default:
            return 'secondary';
    }
}

// 验证应收账款数据
function validateReceivableData($data)
{
    $errors = [];

    if (empty($data['customer_id'])) {
        $errors[] = '请选择客户';
    }

    if (empty($data['amount']) || !is_numeric($data['amount']) || $data['amount'] <= 0) {
        $errors[] = '请输入有效的应收金额';
    }

    if (empty($data['due_date'])) {
        $errors[] = '请输入账期日期';
    }

    return $errors;
}

// 处理不同操作
switch ($action) {
    case 'list':
        // 构建查询条件
        $conditions = [];
        $params = [];
        $types = '';

        if (!empty($search)) {
            $searchTerm = "%" . $search . "%";
            $conditions[] = "(r.receivable_id LIKE ? OR r.remark LIKE ?)";
            $params[] = $searchTerm;
            $params[] = $searchTerm;
            $types .= "ss";
        }

        if (!empty($status)) {
            $conditions[] = "r.payment_status = ?";
            $params[] = $status;
            $types .= 's';
        }

        if ($customer_id > 0) {
            $conditions[] = "r.customer_id = ?";
            $params[] = $customer_id;
            $types .= 'i';
        }

        if (!empty($start_date)) {
            $conditions[] = "r.due_date >= ?";
            $params[] = $start_date;
            $types .= 's';
        }

        if (!empty($end_date)) {
            $conditions[] = "r.due_date <= ?";
            $params[] = $end_date;
            $types .= 's';
        }

        $whereClause = !empty($conditions) ? "WHERE " . implode(" AND ", $conditions) : "";

        // 获取客户列表（用于筛选）
        $customerSql = "SELECT customer_id, customer_name FROM customers ORDER BY customer_name";
        $customerResult = $conn->query($customerSql);
        $customers = [];
        while ($customerResult && $row = $customerResult->fetch_assoc()) {
            $customers[] = $row;
        }

        // 获取应收账款总数
        $countSql = "SELECT COUNT(*) as total FROM sales_receivables r $whereClause";

        // 只有在有参数的情况下才进行参数绑定
        if (!empty($params)) {
            $countStmt = $conn->prepare($countSql);
            // 复制类型和参数以避免分页参数影响
            $countTypes = $types;
            $countParams = $params;
            $countStmt->bind_param($countTypes, ...$countParams);
            $countStmt->execute();
            $countResult = $countStmt->get_result();
            $totalRecords = $countResult->fetch_assoc()['total'];
        } else {
            // 无需参数绑定的简单查询
            $countResult = $conn->query($countSql);
            $totalRecords = $countResult->fetch_assoc()['total'];
        }

        // 计算总页数
        $totalPages = ceil($totalRecords / $limit);

        // 验证当前页码在有效范围内
        if ($page < 1) $page = 1;
        if ($page > $totalPages && $totalPages > 0) $page = $totalPages;

        // 获取应收账款列表
        $sql = "SELECT 
            r.*, 
            c.customer_name
        FROM 
            sales_receivables r
        LEFT JOIN 
            customers c ON r.customer_id = c.customer_id
        $whereClause
        ORDER BY 
            r.due_date ASC, 
            r.receivable_id DESC
        LIMIT ?, ?";

        // 添加分页参数
        $params[] = $offset;
        $params[] = $limit;
        $types .= 'ii';

        $stmt = $conn->prepare($sql);
        $stmt->bind_param($types, ...$params);
        $stmt->execute();
        $result = $stmt->get_result();
        $receivables = [];

        while ($row = $result->fetch_assoc()) {
            $receivables[] = $row;
        }

        // 显示列表页面
        include 'statement_list.php';
        break;

    case 'add':
        // 添加应收账款
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            // 验证表单数据
            $data = [
                'customer_id' => isset($_POST['customer_id']) ? intval($_POST['customer_id']) : 0,
                'amount' => isset($_POST['amount']) ? floatval($_POST['amount']) : 0,
                'due_date' => isset($_POST['due_date']) ? sanitize($_POST['due_date']) : '',
                'remark' => isset($_POST['remark']) ? sanitize($_POST['remark']) : ''
            ];

            // 调试信息
            error_log("新建应收账款表单数据: " . print_r($data, true));
            error_log("POST数据: " . print_r($_POST, true));

            // 验证数据
            $errors = validateReceivableData($data);

            if (empty($errors)) {
                // 开始事务
                $conn->begin_transaction();

                try {
                    // 验证发票ID
                    $invoice_id = null;
                    if (isset($_POST['invoice_id']) && !empty($_POST['invoice_id'])) {
                        $invoice_id = intval($_POST['invoice_id']);
                    } else {
                        // 设置为0，因为MySQL外键约束可能不允许NULL
                        $invoice_id = 0;
                    }

                    error_log("使用的invoice_id: " . $invoice_id);

                    // 插入应收账款记录
                    $sql = "INSERT INTO sales_receivables (
                                invoice_id, 
                                customer_id, 
                                amount,
                                due_date, 
                                payment_status, 
                                paid_amount, 
                                remaining_amount,
                                remark,
                                created_at
                            ) VALUES (?, ?, ?, ?, 'unpaid', 0, ?, ?, NOW())";

                    error_log("INSERT SQL: " . $sql);

                    $stmt = $conn->prepare($sql);
                    if (!$stmt) {
                        // SQL语句准备失败，输出错误信息
                        throw new Exception("SQL准备错误: " . $conn->error);
                    }

                    $remaining_amount = $data['amount']; // 初始未付金额等于总金额

                    // 调试信息
                    error_log("INSERT参数: invoice_id={$invoice_id}, customer_id={$data['customer_id']}, amount={$data['amount']}, due_date={$data['due_date']}, remaining_amount={$remaining_amount}, remark={$data['remark']}");

                    // 绑定参数时明确检查是否成功
                    $bindResult = $stmt->bind_param("iidsds", $invoice_id, $data['customer_id'], $data['amount'], $data['due_date'], $remaining_amount, $data['remark']);
                    if (!$bindResult) {
                        throw new Exception("绑定参数失败: " . $stmt->error);
                    }

                    if (!$stmt->execute()) {
                        throw new Exception("执行SQL失败: " . $stmt->error);
                    }

                    $receivableId = $stmt->insert_id;
                    error_log("成功创建应收账款，ID: " . $receivableId . "，invoice_id: " . $invoice_id . ", SQL: " . $sql);

                    // 处理关联订单
                    if (isset($_POST['order_ids']) && is_array($_POST['order_ids'])) {
                        error_log("处理关联订单: " . json_encode($_POST['order_ids']));
                        foreach ($_POST['order_ids'] as $orderId) {
                            if (!empty($orderId)) {
                                $updateOrderSql = "UPDATE sales_orders SET receivable_id = ? WHERE order_id = ?";
                                $updateOrderStmt = $conn->prepare($updateOrderSql);
                                if (!$updateOrderStmt) {
                                    error_log("更新订单SQL准备错误: " . $conn->error);
                                    continue;
                                }
                                $updateOrderStmt->bind_param("ii", $receivableId, $orderId);
                                if ($updateOrderStmt->execute()) {
                                    error_log("成功关联订单ID: " . $orderId . " 到应收账款ID: " . $receivableId);
                                } else {
                                    error_log("关联订单失败: " . $updateOrderStmt->error);
                                }
                            }
                        }
                    } else {
                        error_log("没有订单需要关联");
                    }

                    // 处理关联发票
                    if (isset($_POST['invoice_ids']) && is_array($_POST['invoice_ids'])) {
                        error_log("处理关联发票: " . json_encode($_POST['invoice_ids']));
                        foreach ($_POST['invoice_ids'] as $invoiceId) {
                            if (!empty($invoiceId)) {
                                $updateInvoiceSql = "UPDATE sales_invoices SET receivable_id = ? WHERE invoice_id = ?";
                                $updateInvoiceStmt = $conn->prepare($updateInvoiceSql);
                                if (!$updateInvoiceStmt) {
                                    error_log("更新发票SQL准备错误: " . $conn->error);
                                    continue;
                                }
                                $updateInvoiceStmt->bind_param("ii", $receivableId, $invoiceId);
                                if ($updateInvoiceStmt->execute()) {
                                    error_log("成功关联发票ID: " . $invoiceId . " 到应收账款ID: " . $receivableId);
                                } else {
                                    error_log("关联发票失败: " . $updateInvoiceStmt->error);
                                }
                            }
                        }
                    } else {
                        error_log("没有发票需要关联");
                    }

                    // 提交事务
                    $conn->commit();

                    // 记录操作日志
                    log_operation($_SESSION['user_id'], '添加应收账款', "创建应收账款记录：AR" . str_pad($receivableId, 6, '0', STR_PAD_LEFT) . "，客户ID：{$data['customer_id']}，金额：{$data['amount']}");

                    // 重定向到列表页面
                    header("Location: index.php?page=statement&message=应收账款记录创建成功&messageType=success");
                    exit;
                } catch (Exception $e) {
                    // 回滚事务
                    $conn->rollback();
                    $message = "创建应收账款记录失败：" . $e->getMessage();
                    $messageType = "error";
                }
            } else {
                $message = "表单数据验证失败：" . implode("，", $errors);
                $messageType = "error";
            }
        }

        // 获取客户列表
        $customerSql = "SELECT customer_id, customer_name FROM customers ORDER BY customer_name";
        $customerResult = $conn->query($customerSql);
        $customers = [];
        while ($customerResult && $row = $customerResult->fetch_assoc()) {
            $customers[] = $row;
        }

        // 显示添加表单
        include 'statement_form.php';
        break;

    case 'edit':
        // 编辑应收账款
        $id = isset($_GET['id']) ? intval($_GET['id']) : 0;

        if (!$id) {
            header("Location: index.php?page=statement&message=缺少应收账款ID&messageType=error");
            exit;
        }

        // 获取应收账款记录
        $sql = "SELECT 
            r.*, 
            c.customer_name
        FROM 
            sales_receivables r
        JOIN 
            customers c ON r.customer_id = c.customer_id
        WHERE 
            r.receivable_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $id);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows === 0) {
            header("Location: index.php?page=statement&message=应收账款记录不存在&messageType=error");
            exit;
        }

        $formData = $result->fetch_assoc();

        // 处理表单提交
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $data = [
                'customer_id' => isset($_POST['customer_id']) ? intval($_POST['customer_id']) : 0,
                'amount' => isset($_POST['amount']) ? floatval($_POST['amount']) : 0,
                'due_date' => isset($_POST['due_date']) ? sanitize($_POST['due_date']) : '',
                'remark' => isset($_POST['remark']) ? sanitize($_POST['remark']) : ''
            ];

            // 调试信息
            error_log("编辑表单数据: " . json_encode($data));

            // 验证数据
            $errors = validateReceivableData($data);

            // 验证金额不小于已付金额
            if ($data['amount'] < $formData['paid_amount']) {
                $errors[] = "应收金额不能小于已付金额（{$formData['paid_amount']}元）";
            }

            if (empty($errors)) {
                // 更新应收账款记录
                $sql = "UPDATE sales_receivables SET 
                            customer_id = ?, 
                            amount = ?, 
                            due_date = ?, 
                            remark = ?,
                            remaining_amount = ?,
                            updated_at = NOW()
                        WHERE receivable_id = ?";

                $stmt = $conn->prepare($sql);
                if (!$stmt) {
                    // SQL语句准备失败，输出错误信息
                    echo "SQL准备错误: " . $conn->error;
                    exit;
                }
                // 计算新的未付金额
                $newRemainingAmount = $data['amount'] - $formData['paid_amount'];
                $stmt->bind_param("idssdi", $data['customer_id'], $data['amount'], $data['due_date'], $data['remark'], $newRemainingAmount, $id);

                if ($stmt->execute()) {
                    // 记录操作日志
                    log_operation($_SESSION['user_id'], '编辑应收账款', "更新应收账款记录ID：{$id}，客户ID：{$data['customer_id']}，金额：{$data['amount']}");

                    // 重定向到列表页面
                    header("Location: index.php?page=statement&message=应收账款记录更新成功&messageType=success");
                    exit;
                } else {
                    $message = "更新应收账款记录失败：" . $conn->error;
                    $messageType = "error";
                }
            } else {
                $message = "表单数据验证失败：" . implode("，", $errors);
                $messageType = "error";
            }
        }

        // 获取客户列表
        $customerSql = "SELECT customer_id, customer_name FROM customers ORDER BY customer_name";
        $customerResult = $conn->query($customerSql);
        $customers = [];
        while ($customerResult && $row = $customerResult->fetch_assoc()) {
            $customers[] = $row;
        }

        // 显示编辑表单
        include 'statement_form.php';
        break;

    case 'view':
        // 查看应收账款详情
        $id = isset($_GET['id']) ? intval($_GET['id']) : 0;

        if (!$id) {
            header("Location: index.php?page=statement&message=缺少应收账款ID&messageType=error");
            exit;
        }

        // 获取应收账款记录
        $sql = "SELECT 
            r.*, 
            c.customer_name
        FROM 
            sales_receivables r
        JOIN 
            customers c ON r.customer_id = c.customer_id
        WHERE 
            r.receivable_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $id);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows === 0) {
            header("Location: index.php?page=statement&message=应收账款记录不存在&messageType=error");
            exit;
        }

        $viewData = $result->fetch_assoc();

        // 获取回款记录
        $paymentsSql = "SELECT p.payment_id, p.payment_number, pd.amount, p.payment_date, 
                        p.payment_method, p.remark, p.created_at, p.created_by,
                        u.full_name as created_by_name
                        FROM sales_payment_details pd
                        JOIN sales_payments p ON pd.payment_id = p.payment_id
                        LEFT JOIN users u ON p.created_by = u.user_id
                        WHERE pd.receivable_id = ?
                        ORDER BY p.payment_date DESC";

        // 添加调试信息
        error_log("获取回款记录SQL: " . $paymentsSql . ", ID: " . $id);

        $paymentsStmt = $conn->prepare($paymentsSql);
        if (!$paymentsStmt) {
            // SQL准备失败，记录错误但继续执行
            error_log("获取回款记录SQL准备失败: " . $conn->error);
            $viewPayments = []; // 初始化为空数组继续执行
        } else {
            $paymentsStmt->bind_param("i", $id);
            $paymentsStmt->execute();
            $paymentsResult = $paymentsStmt->get_result();
            $viewPayments = [];

            while ($payment = $paymentsResult->fetch_assoc()) {
                $viewPayments[] = $payment;
            }
        }

        // 显示详情页面
        include 'statement_view.php';
        break;

    case 'add_payment':
        // 添加回款记录
        $id = isset($_GET['id']) ? intval($_GET['id']) : 0;

        if (!$id) {
            header("Location: index.php?page=statement&message=缺少应收账款ID&messageType=error");
            exit;
        }

        // 获取应收账款记录
        $sql = "SELECT 
            r.*, 
            c.customer_name
        FROM 
            sales_receivables r
        JOIN 
            customers c ON r.customer_id = c.customer_id
        WHERE 
            r.receivable_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $id);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows === 0) {
            header("Location: index.php?page=statement&message=应收账款记录不存在&messageType=error");
            exit;
        }

        $receivableData = $result->fetch_assoc();

        // 检查是否已经付清
        if ($receivableData['payment_status'] === 'paid') {
            header("Location: index.php?page=statement&action=view&id={$id}&message=该应收账款已付清，无需添加回款&messageType=warning");
            exit;
        }

        // 处理表单提交
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $data = [
                'amount' => isset($_POST['amount']) ? floatval($_POST['amount']) : 0,
                'payment_date' => isset($_POST['payment_date']) ? sanitize($_POST['payment_date']) : date('Y-m-d'),
                'payment_method' => isset($_POST['payment_method']) ? sanitize($_POST['payment_method']) : '',
                'reference' => isset($_POST['reference']) ? sanitize($_POST['reference']) : '',
                'notes' => isset($_POST['notes']) ? sanitize($_POST['notes']) : ''
            ];

            // 验证数据
            $errors = [];

            if ($data['amount'] <= 0) {
                $errors[] = '回款金额必须大于0';
            }

            $remainingAmount = $receivableData['amount'] - $receivableData['paid_amount'];
            if ($data['amount'] > $remainingAmount) {
                $errors[] = "回款金额不能超过未付金额（{$remainingAmount}元）";
            }

            if (empty($data['payment_date'])) {
                $errors[] = '请输入回款日期';
            }

            if (empty($data['payment_method'])) {
                $errors[] = '请选择回款方式';
            }

            if (empty($errors)) {
                // 开始事务
                $conn->begin_transaction();

                try {
                    // 插入回款记录
                    $paymentSql = "INSERT INTO sales_payments (
                                    payment_number,
                                    customer_id,
                                    amount,
                                    payment_date,
                                    payment_method,
                                    remark,
                                    created_by,
                                    created_at
                                ) VALUES (?, ?, ?, ?, ?, ?, ?, NOW())";

                    // 生成付款编号
                    $payment_number = 'PAY' . date('YmdHis') . rand(100, 999);

                    // 获取客户ID
                    $customer_id = $receivableData['customer_id'];

                    // 合并备注和参考号
                    $remark = '参考号：' . $data['reference'] . "\n" . $data['notes'];

                    $created_by = $_SESSION['user_id'];

                    // 调试信息
                    error_log("添加回款记录: payment_number={$payment_number}, customer_id={$customer_id}, amount={$data['amount']}, date={$data['payment_date']}, method={$data['payment_method']}, remark={$remark}, created_by={$created_by}");

                    $paymentStmt = $conn->prepare($paymentSql);
                    if (!$paymentStmt) {
                        throw new Exception("SQL准备错误: " . $conn->error);
                    }

                    $paymentStmt->bind_param("sidsssi", $payment_number, $customer_id, $data['amount'], $data['payment_date'], $data['payment_method'], $remark, $created_by);

                    if (!$paymentStmt->execute()) {
                        throw new Exception("执行SQL失败: " . $paymentStmt->error);
                    }

                    $paymentId = $paymentStmt->insert_id;

                    // 在支付明细表中添加记录，关联应收账款
                    $detailSql = "INSERT INTO sales_payment_details (
                                    payment_id,
                                    receivable_id,
                                    amount,
                                    created_at
                                ) VALUES (?, ?, ?, NOW())";

                    $detailStmt = $conn->prepare($detailSql);
                    if (!$detailStmt) {
                        throw new Exception("支付明细SQL准备错误: " . $conn->error);
                    }

                    $detailStmt->bind_param("iid", $paymentId, $id, $data['amount']);

                    if (!$detailStmt->execute()) {
                        throw new Exception("支付明细SQL执行失败: " . $detailStmt->error);
                    }

                    // 更新应收账款的已付金额
                    $newPaidAmount = $receivableData['paid_amount'] + $data['amount'];

                    // 确定付款状态
                    $newStatus = 'partial';
                    if ($newPaidAmount >= $receivableData['amount']) {
                        $newStatus = 'paid';
                    }

                    // 更新支付记录
                    $updateSql = "UPDATE sales_receivables SET 
                                   paid_amount = ?,
                                   remaining_amount = ?,
                                   payment_status = ?,
                                   updated_at = NOW()
                                 WHERE receivable_id = ?";

                    $updateStmt = $conn->prepare($updateSql);
                    $newRemainingAmount = $receivableData['amount'] - $newPaidAmount;
                    $updateStmt->bind_param("ddsi", $newPaidAmount, $newRemainingAmount, $newStatus, $id);
                    $updateStmt->execute();

                    // 提交事务
                    $conn->commit();

                    // 记录操作日志
                    log_operation($_SESSION['user_id'], '添加回款记录', "为应收账款ID：{$id}添加回款记录，金额：{$data['amount']}元，方式：{$data['payment_method']}");

                    // 重定向到详情页面
                    header("Location: index.php?page=statement&action=view&id={$id}&message=回款记录添加成功&messageType=success");
                    exit;
                } catch (Exception $e) {
                    // 回滚事务
                    $conn->rollback();
                    $message = "添加回款记录失败：" . $e->getMessage();
                    $messageType = "error";
                }
            } else {
                $message = "表单数据验证失败：" . implode("，", $errors);
                $messageType = "error";
            }
        }

        // 显示回款表单
        include 'statement_payment.php';
        break;

    case 'delete':
        // 删除应收账款
        $id = isset($_GET['id']) ? intval($_GET['id']) : 0;

        if (!$id) {
            header("Location: index.php?page=statement&message=缺少应收账款ID&messageType=error");
            exit;
        }

        // 检查是否存在回款记录
        $checkSql = "SELECT COUNT(*) as count FROM sales_payment_details WHERE receivable_id = ?";
        $checkStmt = $conn->prepare($checkSql);
        $checkStmt->bind_param("i", $id);
        $checkStmt->execute();
        $checkResult = $checkStmt->get_result();
        $paymentCount = $checkResult->fetch_assoc()['count'];

        if ($paymentCount > 0) {
            header("Location: index.php?page=statement&message=该应收账款已有回款记录，无法删除&messageType=error");
            exit;
        }

        // 获取应收账款编号用于日志记录
        $getSql = "SELECT receivable_id, invoice_id FROM sales_receivables WHERE receivable_id = ?";
        $getStmt = $conn->prepare($getSql);
        $getStmt->bind_param("i", $id);
        $getStmt->execute();
        $getResult = $getStmt->get_result();

        if ($getResult->num_rows === 0) {
            header("Location: index.php?page=statement&message=应收账款记录不存在&messageType=error");
            exit;
        }

        $record = $getResult->fetch_assoc();
        $receivableId = $record['receivable_id'];
        $invoiceId = $record['invoice_id'] ?? '无';
        $receivableNumber = "ID: " . $receivableId . " (发票ID: " . $invoiceId . ")";

        // 开始事务
        $conn->begin_transaction();

        try {
            // 解除关联的订单
            $updateOrderSql = "UPDATE sales_orders SET receivable_id = NULL WHERE receivable_id = ?";
            $updateOrderStmt = $conn->prepare($updateOrderSql);
            $updateOrderStmt->bind_param("i", $id);
            $updateOrderStmt->execute();

            // 解除关联的发票
            $updateInvoiceSql = "UPDATE sales_invoices SET receivable_id = NULL WHERE receivable_id = ?";
            $updateInvoiceStmt = $conn->prepare($updateInvoiceSql);
            $updateInvoiceStmt->bind_param("i", $id);
            $updateInvoiceStmt->execute();

            // 删除应收账款记录
            $deleteSql = "DELETE FROM sales_receivables WHERE receivable_id = ?";
            $deleteStmt = $conn->prepare($deleteSql);
            $deleteStmt->bind_param("i", $id);
            $deleteStmt->execute();

            // 提交事务
            $conn->commit();

            // 记录操作日志
            log_operation($_SESSION['user_id'], '删除应收账款', "删除应收账款记录：{$receivableNumber}，ID：{$id}");

            // 重定向到列表页面
            header("Location: index.php?page=statement&message=应收账款记录删除成功&messageType=success");
            exit;
        } catch (Exception $e) {
            // 回滚事务
            $conn->rollback();
            header("Location: index.php?page=statement&message=删除应收账款记录失败：{$e->getMessage()}&messageType=error");
            exit;
        }
        break;

    case 'update_status':
        // 更新付款状态
        $id = isset($_GET['id']) ? intval($_GET['id']) : 0;
        $status = isset($_GET['status']) ? sanitize($_GET['status']) : '';
        $return = isset($_GET['return']) ? sanitize($_GET['return']) : 'list';

        if (!$id || empty($status)) {
            header("Location: index.php?page=statement&message=参数错误&messageType=error");
            exit;
        }

        // 验证状态值
        $validStatuses = ['unpaid', 'partial', 'paid', 'overdue'];
        if (!in_array($status, $validStatuses)) {
            header("Location: index.php?page=statement&message=无效的状态值&messageType=error");
            exit;
        }

        // 映射状态值 - 将'overdue'转换为数据库允许的'unpaid'
        $dbStatus = $status;
        if ($status === 'overdue') {
            $dbStatus = 'unpaid'; // 在数据库中保存为'unpaid'，但UI上显示为'overdue'
        }

        // 更新状态
        $sql = "UPDATE sales_receivables SET payment_status = ?, updated_at = NOW() WHERE receivable_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("si", $dbStatus, $id);

        if ($stmt->execute()) {
            // 记录操作日志
            log_operation($_SESSION['user_id'], '更新应收账款状态', "更新应收账款ID：{$id}的付款状态为：{$status}");

            // 确定重定向目标
            $redirectUrl = $return === 'view'
                ? "index.php?page=statement&action=view&id={$id}&message=状态更新成功&messageType=success"
                : "index.php?page=statement&message=状态更新成功&messageType=success";

            header("Location: {$redirectUrl}");
            exit;
        } else {
            $message = "更新状态失败：" . $conn->error;
            $messageType = "error";

            // 如果更新失败，返回到之前的页面
            header("Location: index.php?page=statement&message={$message}&messageType={$messageType}");
            exit;
        }
        break;

    default:
        // 默认显示列表
        header("Location: index.php?page=statement&message=未知操作&messageType=error");
        exit;
}
