<?php
// 防止直接访问
defined('IN_SYSTEM') || die('禁止访问');

// 判断是添加还是编辑
$isEdit = isset($formData);
$pageTitle = $isEdit ? '编辑应收账款' : '创建应收账款';

// 设置默认值
if (!$isEdit) {
    $formData = [
        'customer_id' => '',
        'amount' => '',
        'due_date' => date('Y-m-d', strtotime('+30 days')),
        'remark' => ''
    ];
}
?>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<div class="module-tools">
    <div class="tool-left">
        <a href="index.php?page=statement" class="btn btn-secondary">返回列表</a>
    </div>
</div>

<div class="form-container">
    <h3><?php echo $pageTitle; ?></h3>

    <form action="<?php echo $isEdit ? "index.php?page=statement&action=edit&id=" . $formData['receivable_id'] : "index.php?page=statement&action=add"; ?>" method="post" id="statement-form">
        <div class="form-group">
            <label for="customer_id">客户：<span class="required">*</span></label>
            <select name="customer_id" id="customer_id" class="form-control" required>
                <option value="">-- 请选择客户 --</option>
                <?php foreach ($customers as $customer): ?>
                    <option value="<?php echo $customer['customer_id']; ?>" <?php echo $formData['customer_id'] == $customer['customer_id'] ? 'selected' : ''; ?>>
                        <?php echo htmlspecialchars($customer['customer_name']); ?>
                    </option>
                <?php endforeach; ?>
            </select>
        </div>

        <div class="form-group">
            <label for="amount">应收金额(元)：<span class="required">*</span></label>
            <input type="number" name="amount" id="amount" min="0.01" step="0.01" class="form-control" required
                value="<?php echo htmlspecialchars($formData['amount'] ?? ''); ?>">
        </div>

        <div class="form-group">
            <label for="due_date">账期日期：<span class="required">*</span></label>
            <input type="date" name="due_date" id="due_date" class="form-control" required
                value="<?php echo htmlspecialchars($formData['due_date'] ?? ''); ?>">
        </div>

        <div class="form-group">
            <label for="remark">备注：</label>
            <textarea name="remark" id="remark" class="form-control" rows="4"><?php echo htmlspecialchars($formData['remark'] ?? ''); ?></textarea>
        </div>

        <?php if (!$isEdit): ?>
            <div class="form-group">
                <label>关联订单 (可选)：</label>
                <div id="orders-container">
                    <!-- 待关联订单选择区 -->
                    <div class="order-selection">
                        <div class="selection-row">
                            <select name="order_ids[]" class="form-control">
                                <option value="">-- 选择订单 --</option>
                                <?php
                                // 获取未关联应收账款的订单
                                $ordersSql = "SELECT order_id, order_number, total_amount 
                                             FROM sales_orders 
                                             WHERE (receivable_id IS NULL OR receivable_id = 0)
                                             ORDER BY order_date DESC";

                                error_log("订单查询SQL: " . $ordersSql);
                                $ordersResult = $conn->query($ordersSql);

                                $orderCount = 0;
                                if ($ordersResult) {
                                    $orderCount = $ordersResult->num_rows;
                                    error_log("找到 {$orderCount} 个可关联订单");

                                    while ($order = $ordersResult->fetch_assoc()) {
                                        echo '<option value="' . $order['order_id'] . '">' .
                                            htmlspecialchars($order['order_number']) . ' - ' .
                                            number_format($order['total_amount'], 2) . '元</option>';
                                    }
                                } else {
                                    error_log("订单查询失败: " . $conn->error);
                                }

                                if ($orderCount == 0) {
                                    echo '<option value="" disabled>没有可关联的订单</option>';
                                }
                                ?>
                            </select>
                            <!-- 初始选择项不显示删除按钮 -->
                        </div>
                        <button type="button" class="btn btn-sm btn-secondary add-order-btn">添加更多订单</button>
                    </div>
                </div>
            </div>

            <div class="form-group">
                <label>关联发票 (可选)：</label>
                <div id="invoices-container">
                    <!-- 待关联发票选择区 -->
                    <div class="invoice-selection">
                        <div class="selection-row">
                            <select name="invoice_ids[]" class="form-control">
                                <option value="">-- 选择发票 --</option>
                                <?php
                                // 获取未关联应收账款的发票
                                $invoicesSql = "SELECT invoice_id, invoice_number, total_amount 
                                               FROM sales_invoices 
                                               WHERE (receivable_id IS NULL OR receivable_id = 0)
                                               ORDER BY invoice_date DESC";

                                error_log("发票查询SQL: " . $invoicesSql);
                                $invoicesResult = $conn->query($invoicesSql);

                                $invoiceCount = 0;
                                if ($invoicesResult) {
                                    $invoiceCount = $invoicesResult->num_rows;
                                    error_log("找到 {$invoiceCount} 个可关联发票");

                                    while ($invoice = $invoicesResult->fetch_assoc()) {
                                        echo '<option value="' . $invoice['invoice_id'] . '">' .
                                            htmlspecialchars($invoice['invoice_number']) . ' - ' .
                                            number_format($invoice['total_amount'], 2) . '元</option>';
                                    }
                                } else {
                                    error_log("发票查询失败: " . $conn->error);
                                }

                                if ($invoiceCount == 0) {
                                    echo '<option value="" disabled>没有可关联的发票</option>';
                                }
                                ?>
                            </select>
                            <!-- 初始选择项不显示删除按钮 -->
                        </div>
                        <button type="button" class="btn btn-sm btn-secondary add-invoice-btn">添加更多发票</button>
                    </div>
                </div>
            </div>
        <?php endif; ?>

        <div class="form-group">
            <button type="submit" class="btn btn-primary"><?php echo $isEdit ? '更新' : '创建'; ?></button>
            <a href="index.php?page=statement" class="btn btn-secondary">取消</a>
        </div>
    </form>
</div>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 表单提交调试
        document.getElementById('statement-form').addEventListener('submit', function(e) {
            // 不阻止表单提交，但在控制台输出表单数据，便于调试
            console.log('提交表单数据：', {
                customer_id: document.getElementById('customer_id').value,
                amount: document.getElementById('amount').value,
                due_date: document.getElementById('due_date').value,
                remark: document.getElementById('remark').value,
                order_ids: Array.from(document.querySelectorAll('select[name="order_ids[]"]'))
                    .map(select => select.value)
                    .filter(value => value),
                invoice_ids: Array.from(document.querySelectorAll('select[name="invoice_ids[]"]'))
                    .map(select => select.value)
                    .filter(value => value)
            });
        });

        // 添加更多订单
        document.querySelector('.add-order-btn').addEventListener('click', function() {
            var container = document.getElementById('orders-container');

            // 创建新的行
            var newRow = document.createElement('div');
            newRow.className = 'selection-row';

            // 克隆第一个选择框
            var selectClone = container.querySelector('select').cloneNode(true);
            newRow.appendChild(selectClone);

            // 添加删除按钮
            var deleteBtn = document.createElement('button');
            deleteBtn.type = 'button';
            deleteBtn.className = 'btn btn-sm btn-danger delete-selection-btn';
            deleteBtn.textContent = '删除';
            deleteBtn.style.marginLeft = '10px';

            // 删除按钮点击事件
            deleteBtn.addEventListener('click', function() {
                newRow.remove();
            });

            newRow.appendChild(deleteBtn);

            // 添加到容器
            container.querySelector('.order-selection').insertBefore(newRow, container.querySelector('.add-order-btn'));
        });

        // 添加更多发票
        document.querySelector('.add-invoice-btn').addEventListener('click', function() {
            var container = document.getElementById('invoices-container');

            // 创建新的行
            var newRow = document.createElement('div');
            newRow.className = 'selection-row';

            // 克隆第一个选择框
            var selectClone = container.querySelector('select').cloneNode(true);
            newRow.appendChild(selectClone);

            // 添加删除按钮
            var deleteBtn = document.createElement('button');
            deleteBtn.type = 'button';
            deleteBtn.className = 'btn btn-sm btn-danger delete-selection-btn';
            deleteBtn.textContent = '删除';
            deleteBtn.style.marginLeft = '10px';

            // 删除按钮点击事件
            deleteBtn.addEventListener('click', function() {
                newRow.remove();
            });

            newRow.appendChild(deleteBtn);

            // 添加到容器
            container.querySelector('.invoice-selection').insertBefore(newRow, container.querySelector('.add-invoice-btn'));
        });
    });
</script>

<style>
    .selection-row {
        display: flex;
        align-items: center;
        margin-bottom: 10px;
    }

    .selection-row select {
        flex: 1;
    }

    .delete-selection-btn {
        flex-shrink: 0;
    }
</style>