<?php
// 防止直接访问
defined('IN_SYSTEM') || die('禁止访问');
?>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<div class="module-tools">
    <div class="tool-left">
        <a href="index.php?page=statement&action=add" class="btn btn-primary">创建应收账款</a>
    </div>
</div>

<div class="data-wrapper">
    <h4 class="data-title">应收账款管理</h4>

    <!-- 搜索表单 -->
    <div class="search-bar">
        <form action="index.php" method="get" class="search-form">
            <input type="hidden" name="page" value="statement">
            <div class="search-group">
                <input type="text" id="search" name="search" placeholder="搜索编号、备注..." value="<?php echo htmlspecialchars($search ?? ''); ?>" class="search-input">
            </div>
            <div class="search-group">
                <select name="customer_id" id="customer_id" class="search-input">
                    <option value="">-- 所有客户 --</option>
                    <?php foreach ($customers as $customer): ?>
                        <option value="<?php echo $customer['customer_id']; ?>" <?php echo $customer_id == $customer['customer_id'] ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($customer['customer_name']); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="search-group">
                <select name="status" id="status" class="search-input">
                    <option value="">-- 所有状态 --</option>
                    <option value="unpaid" <?php echo $status == 'unpaid' ? 'selected' : ''; ?>>待付款</option>
                    <option value="partial" <?php echo $status == 'partial' ? 'selected' : ''; ?>>部分付款</option>
                    <option value="paid" <?php echo $status == 'paid' ? 'selected' : ''; ?>>已付清</option>
                    <option value="overdue" <?php echo $status == 'overdue' ? 'selected' : ''; ?>>已逾期</option>
                </select>
            </div>
            <div class="search-group">
                <input type="date" id="start_date" name="start_date" value="<?php echo htmlspecialchars($start_date ?? ''); ?>" class="search-input date">
            </div>
            <div class="search-group">
                <input type="date" id="end_date" name="end_date" value="<?php echo htmlspecialchars($end_date ?? ''); ?>" class="search-input date">
            </div>
            <button type="submit" class="btn btn-primary">搜索</button>
            <a href="index.php?page=statement" class="btn btn-secondary">重置</a>
        </form>
    </div>

    <!-- 数据列表 -->
    <table class="data-table">
        <thead>
            <tr>
                <th>编号</th>
                <th>客户</th>
                <th>应收金额(元)</th>
                <th>已付金额(元)</th>
                <th>未付金额(元)</th>
                <th>账期日期</th>
                <th>付款状态</th>
                <th>创建时间</th>
                <th>操作</th>
            </tr>
        </thead>
        <tbody>
            <?php if (count($receivables) > 0): ?>
                <?php foreach ($receivables as $receivable): ?>
                    <?php
                    // 判断是否逾期
                    $today = date('Y-m-d');
                    $dueDate = $receivable['due_date'] ?? '';
                    $isOverdue = $today > $dueDate && $receivable['payment_status'] != 'paid';
                    $isDueToday = $today == $dueDate && $receivable['payment_status'] != 'paid';

                    // 设置行样式
                    $rowClass = '';
                    if ($isOverdue && $receivable['payment_status'] != 'overdue') {
                        $rowClass = 'overdue';
                    } elseif ($isDueToday) {
                        $rowClass = 'due-today';
                    }

                    // 计算未付金额
                    $unpaidAmount = ($receivable['amount'] ?? 0) - ($receivable['paid_amount'] ?? 0);
                    ?>
                    <tr class="<?php echo $rowClass; ?>">
                        <td><?php echo "AR" . str_pad($receivable['receivable_id'] ?? '', 6, '0', STR_PAD_LEFT); ?></td>
                        <td><?php echo htmlspecialchars($receivable['customer_name'] ?? ''); ?></td>
                        <td class="text-right"><?php echo number_format($receivable['amount'] ?? 0, 2); ?></td>
                        <td class="text-right"><?php echo number_format($receivable['paid_amount'] ?? 0, 2); ?></td>
                        <td class="text-right"><?php echo number_format($unpaidAmount, 2); ?></td>
                        <td>
                            <?php echo $receivable['due_date'] ?? ''; ?>
                            <?php if ($isDueToday): ?>
                                <span class="badge badge-warning">今日到期</span>
                            <?php endif; ?>
                        </td>
                        <td>
                            <span class="badge badge-<?php echo getPaymentStatusBadgeClass($receivable['payment_status'] ?? 'unpaid'); ?>">
                                <?php
                                // 检查是否是应该显示为逾期的记录
                                $status = $receivable['payment_status'] ?? 'unpaid';
                                $today = date('Y-m-d');
                                $dueDate = $receivable['due_date'] ?? '';
                                $isOverdue = $today > $dueDate && $status != 'paid';

                                if ($isOverdue && $status == 'unpaid') {
                                    echo getPaymentStatusName('overdue');
                                } else {
                                    echo getPaymentStatusName($status);
                                }
                                ?>
                            </span>
                        </td>
                        <td><?php echo $receivable['created_at'] ?? ''; ?></td>
                        <td>
                            <a href="index.php?page=statement&action=view&id=<?php echo $receivable['receivable_id']; ?>" class="btn btn-sm btn-info">查看</a>

                            <?php if ($receivable['payment_status'] != 'paid'): ?>
                                <a href="index.php?page=statement&action=edit&id=<?php echo $receivable['receivable_id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                <a href="index.php?page=statement&action=add_payment&id=<?php echo $receivable['receivable_id']; ?>" class="btn btn-sm btn-success">记录回款</a>
                            <?php endif; ?>

                            <?php if (in_array($receivable['payment_status'], ['unpaid', 'partial']) && $isOverdue): ?>
                                <a href="index.php?page=statement&action=update_status&id=<?php echo $receivable['receivable_id']; ?>&status=overdue" class="btn btn-sm btn-warning">标记逾期</a>
                            <?php endif; ?>

                            <?php if ($receivable['payment_status'] == 'unpaid'): ?>
                                <a href="javascript:void(0);" onclick="confirmDelete(<?php echo $receivable['receivable_id']; ?>, 'AR<?php echo str_pad($receivable['receivable_id'], 6, '0', STR_PAD_LEFT); ?>')" class="btn btn-sm btn-danger">删除</a>
                            <?php endif; ?>
                        </td>
                    </tr>
                <?php endforeach; ?>
            <?php else: ?>
                <tr>
                    <td colspan="9" class="text-center">暂无应收账款数据</td>
                </tr>
            <?php endif; ?>
        </tbody>
    </table>

    <!-- 分页控件 -->
    <?php if ($totalPages > 1): ?>
        <div class="pagination">
            <?php if ($page > 1): ?>
                <a href="index.php?page=statement&listpage=1&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&customer_id=<?php echo $customer_id; ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item">首页</a>
                <a href="index.php?page=statement&listpage=<?php echo $page - 1; ?>&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&customer_id=<?php echo $customer_id; ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item">上一页</a>
            <?php endif; ?>

            <?php
            $startPage = max(1, $page - 2);
            $endPage = min($totalPages, $page + 2);

            for ($i = $startPage; $i <= $endPage; $i++):
            ?>
                <a href="index.php?page=statement&listpage=<?php echo $i; ?>&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&customer_id=<?php echo $customer_id; ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item <?php echo $i == $page ? 'active' : ''; ?>"><?php echo $i; ?></a>
            <?php endfor; ?>

            <?php if ($page < $totalPages): ?>
                <a href="index.php?page=statement&listpage=<?php echo $page + 1; ?>&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&customer_id=<?php echo $customer_id; ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item">下一页</a>
                <a href="index.php?page=statement&listpage=<?php echo $totalPages; ?>&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&customer_id=<?php echo $customer_id; ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item">末页</a>
            <?php endif; ?>
        </div>
    <?php endif; ?>
</div>

<script>
    // 删除应收账款确认
    function confirmDelete(receivableId, receivableNumber) {
        if (confirm('确定要删除应收账款记录 ' + receivableNumber + ' 吗？此操作不可恢复！')) {
            window.location.href = 'index.php?page=statement&action=delete&id=' + receivableId;
        }
    }
</script>

<style>
    /* 逾期记录样式 */
    tr.overdue {
        background-color: #fff3f3;
    }

    /* 今日到期样式 */
    tr.due-today {
        background-color: #fff9e6;
    }
</style>