<?php
// 防止直接访问
defined('IN_SYSTEM') || die('禁止访问');

// 获取订单状态展示样式类
function getOrderStatusBadgeClass($status)
{
    switch ($status) {
        case 'pending':
            return 'secondary';
        case 'processing':
            return 'info';
        case 'completed':
            return 'success';
        case 'cancelled':
            return 'danger';
        default:
            return 'secondary';
    }
}

// 获取订单状态名称
function getOrderStatusName($status)
{
    switch ($status) {
        case 'pending':
            return '待处理';
        case 'processing':
            return '处理中';
        case 'completed':
            return '已完成';
        case 'cancelled':
            return '已取消';
        default:
            return $status;
    }
}

// 获取发票状态展示样式类
function getInvoiceStatusBadgeClass($status)
{
    switch ($status) {
        case 'pending':
            return 'secondary';
        case 'issued':
            return 'info';
        case 'paid':
            return 'success';
        case 'cancelled':
            return 'danger';
        default:
            return 'secondary';
    }
}

// 获取发票状态名称
function getInvoiceStatusName($status)
{
    switch ($status) {
        case 'pending':
            return '待开票';
        case 'issued':
            return '已开票';
        case 'paid':
            return '已付款';
        case 'cancelled':
            return '已取消';
        default:
            return $status;
    }
}
?>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<div class="module-tools">
    <div class="tool-left">
        <a href="index.php?page=statement" class="btn btn-secondary">返回列表</a>
        <?php if ($viewData['payment_status'] != 'paid'): ?>
            <a href="index.php?page=statement&action=edit&id=<?php echo $viewData['receivable_id']; ?>" class="btn btn-primary">编辑</a>
            <a href="index.php?page=statement&action=add_payment&id=<?php echo $viewData['receivable_id']; ?>" class="btn btn-success">记录回款</a>
        <?php endif; ?>
    </div>
</div>

<div class="data-wrapper">
    <h4 class="data-title">应收账款详情</h4>

    <div class="detail-container">
        <h3>基本信息</h3>
        <div class="detail-group">
            <label>应收账款编号：</label>
            <span><?php echo "AR" . str_pad($viewData['receivable_id'] ?? '', 6, '0', STR_PAD_LEFT); ?></span>
        </div>
        <div class="detail-group">
            <label>客户：</label>
            <span><?php echo htmlspecialchars($viewData['customer_name'] ?? ''); ?></span>
        </div>
        <div class="detail-group">
            <label>关联发票ID：</label>
            <span><?php echo htmlspecialchars($viewData['invoice_id'] ?? '无'); ?></span>
        </div>
        <div class="detail-group">
            <label>应收金额：</label>
            <span><?php echo number_format($viewData['amount'] ?? 0, 2); ?> 元</span>
        </div>
        <div class="detail-group">
            <label>已付金额：</label>
            <span><?php echo number_format($viewData['paid_amount'] ?? 0, 2); ?> 元</span>
        </div>
        <div class="detail-group">
            <label>未付金额：</label>
            <span><?php echo number_format(($viewData['amount'] ?? 0) - ($viewData['paid_amount'] ?? 0), 2); ?> 元</span>
        </div>
        <div class="detail-group">
            <label>账期日期：</label>
            <span><?php echo $viewData['due_date'] ?? ''; ?></span>
        </div>
        <div class="detail-group">
            <label>付款状态：</label>
            <span>
                <span class="badge badge-<?php echo getPaymentStatusBadgeClass($viewData['payment_status'] ?? 'unpaid'); ?>">
                    <?php
                    // 检查是否是应该显示为逾期的记录
                    $status = $viewData['payment_status'] ?? 'unpaid';
                    $today = date('Y-m-d');
                    $dueDate = $viewData['due_date'] ?? '';
                    $isOverdue = $today > $dueDate && $status != 'paid';

                    if ($isOverdue && $status == 'unpaid') {
                        echo getPaymentStatusName('overdue');
                    } else {
                        echo getPaymentStatusName($status);
                    }
                    ?>
                </span>

                <?php if ($viewData['payment_status'] != 'paid'): ?>
                    <?php
                    $today = date('Y-m-d');
                    $dueDate = $viewData['due_date'] ?? '';
                    $isOverdue = $today > $dueDate;
                    ?>

                    <?php if ($isOverdue && $viewData['payment_status'] == 'unpaid'): ?>
                        <a href="index.php?page=statement&action=update_status&id=<?php echo $viewData['receivable_id']; ?>&status=overdue&return=view" class="btn btn-xs btn-warning">标记为逾期</a>
                    <?php elseif ($viewData['paid_amount'] > 0 && $viewData['payment_status'] == 'unpaid'): ?>
                        <a href="index.php?page=statement&action=update_status&id=<?php echo $viewData['receivable_id']; ?>&status=partial&return=view" class="btn btn-xs btn-info">标记为部分付款</a>
                    <?php elseif ($viewData['paid_amount'] >= $viewData['amount'] && $viewData['payment_status'] != 'paid'): ?>
                        <a href="index.php?page=statement&action=update_status&id=<?php echo $viewData['receivable_id']; ?>&status=paid&return=view" class="btn btn-xs btn-success">标记为已付清</a>
                    <?php endif; ?>
                <?php endif; ?>
            </span>
        </div>
        <div class="detail-group">
            <label>备注：</label>
            <span><?php echo nl2br(htmlspecialchars($viewData['remark'] ?? '')); ?></span>
        </div>
        <div class="detail-group">
            <label>创建时间：</label>
            <span><?php echo $viewData['created_at'] ?? ''; ?></span>
        </div>
        <div class="detail-group">
            <label>最后更新：</label>
            <span><?php echo $viewData['updated_at'] ?? ''; ?></span>
        </div>
    </div>

    <div class="detail-container">
        <h3>回款记录</h3>
        <?php if (count($viewPayments) > 0): ?>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>回款单号</th>
                        <th>回款日期</th>
                        <th>回款方式</th>
                        <th>金额(元)</th>
                        <th>备注</th>
                        <th>记录人</th>
                        <th>创建时间</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($viewPayments as $payment): ?>
                        <?php
                        // 转换英文付款方式为中文
                        $payment_method_map = [
                            'cash' => '现金',
                            'bank_transfer' => '转账',
                            'alipay' => '支付宝',
                            'wechat' => '微信',
                            'other' => '其他'
                        ];
                        $payment_method = isset($payment_method_map[$payment['payment_method']]) ?
                            $payment_method_map[$payment['payment_method']] : $payment['payment_method'];
                        ?>
                        <tr>
                            <td><?php echo htmlspecialchars($payment['payment_number'] ?? ''); ?></td>
                            <td><?php echo $payment['payment_date'] ?? ''; ?></td>
                            <td><?php echo htmlspecialchars($payment_method); ?></td>
                            <td class="text-right"><?php echo number_format($payment['amount'] ?? 0, 2); ?></td>
                            <td><?php echo nl2br(htmlspecialchars($payment['remark'] ?? '')); ?></td>
                            <td><?php echo htmlspecialchars($payment['created_by_name'] ?? ''); ?></td>
                            <td><?php echo $payment['created_at'] ?? ''; ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
                <tfoot>
                    <tr>
                        <td colspan="2" class="text-right"><strong>总计：</strong></td>
                        <td class="text-right"><strong><?php echo number_format($viewData['paid_amount'] ?? 0, 2); ?></strong></td>
                        <td colspan="4"></td>
                    </tr>
                </tfoot>
            </table>
        <?php else: ?>
            <div class="alert alert-info">暂无回款记录</div>
        <?php endif; ?>
    </div>

    <div class="detail-container">
        <h3>关联单据</h3>

        <!-- 关联订单 -->
        <h4>订单</h4>
        <?php
        $relatedOrders = [];
        try {
            $ordersSql = "SELECT so.*, c.customer_name 
                          FROM sales_orders so
                          LEFT JOIN customers c ON so.customer_id = c.customer_id
                          WHERE so.receivable_id = ?";
            $ordersStmt = $conn->prepare($ordersSql);
            if ($ordersStmt) {
                $ordersStmt->bind_param("i", $viewData['receivable_id']);
                $ordersStmt->execute();
                $ordersResult = $ordersStmt->get_result();

                while ($order = $ordersResult->fetch_assoc()) {
                    $relatedOrders[] = $order;
                }
            } else {
                error_log("SQL准备失败: " . $conn->error);
            }
        } catch (Exception $e) {
            error_log("获取关联订单错误: " . $e->getMessage());
        }
        ?>

        <?php if (count($relatedOrders) > 0): ?>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>订单编号</th>
                        <th>客户</th>
                        <th>订单日期</th>
                        <th>金额(元)</th>
                        <th>状态</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($relatedOrders as $order): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($order['order_number'] ?? ''); ?></td>
                            <td><?php echo htmlspecialchars($order['customer_name'] ?? ''); ?></td>
                            <td><?php echo $order['order_date'] ?? ''; ?></td>
                            <td class="text-right"><?php echo number_format($order['total_amount'] ?? 0, 2); ?></td>
                            <td>
                                <span class="badge badge-<?php echo getOrderStatusBadgeClass($order['order_status'] ?? 'pending'); ?>">
                                    <?php echo getOrderStatusName($order['order_status'] ?? 'pending'); ?>
                                </span>
                            </td>
                            <td>
                                <a href="index.php?page=order&action=view&id=<?php echo $order['order_id']; ?>" class="btn btn-sm btn-info">查看</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        <?php else: ?>
            <div class="alert alert-info">暂无关联订单</div>
        <?php endif; ?>

        <!-- 关联发票 -->
        <h4>发票</h4>
        <?php
        $relatedInvoices = [];
        try {
            $invoicesSql = "SELECT si.*, c.customer_name 
                            FROM sales_invoices si
                            LEFT JOIN customers c ON si.customer_id = c.customer_id
                            WHERE si.receivable_id = ?";
            $invoicesStmt = $conn->prepare($invoicesSql);
            if ($invoicesStmt) {
                $invoicesStmt->bind_param("i", $viewData['receivable_id']);
                $invoicesStmt->execute();
                $invoicesResult = $invoicesStmt->get_result();

                while ($invoice = $invoicesResult->fetch_assoc()) {
                    $relatedInvoices[] = $invoice;
                }
            } else {
                error_log("SQL准备失败: " . $conn->error);
            }
        } catch (Exception $e) {
            error_log("获取关联发票错误: " . $e->getMessage());
        }
        ?>

        <?php if (count($relatedInvoices) > 0): ?>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>发票编号</th>
                        <th>客户</th>
                        <th>发票日期</th>
                        <th>金额(元)</th>
                        <th>状态</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($relatedInvoices as $invoice): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($invoice['invoice_number'] ?? ''); ?></td>
                            <td><?php echo htmlspecialchars($invoice['customer_name'] ?? ''); ?></td>
                            <td><?php echo $invoice['invoice_date'] ?? ''; ?></td>
                            <td class="text-right"><?php echo number_format($invoice['total_amount'] ?? 0, 2); ?></td>
                            <td>
                                <span class="badge badge-<?php echo getInvoiceStatusBadgeClass($invoice['invoice_status'] ?? 'pending'); ?>">
                                    <?php echo getInvoiceStatusName($invoice['invoice_status'] ?? 'pending'); ?>
                                </span>
                            </td>
                            <td>
                                <a href="index.php?page=invoice&action=view&id=<?php echo $invoice['invoice_id']; ?>" class="btn btn-sm btn-info">查看</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        <?php else: ?>
            <div class="alert alert-info">暂无关联发票</div>
        <?php endif; ?>
    </div>
</div>