<?php
session_start();
require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取当前页面
$page = isset($_GET['page']) ? $_GET['page'] : 'user';

// 页面标题
$pageTitle = '系统管理';
$subTitle = '';

// 获取子页面内容
$contentFile = '';
switch ($page) {
    case 'user':
        $contentFile = 'user.php';
        $subTitle = '用户管理';
        break;
    case 'log':
        $contentFile = 'log.php';
        $subTitle = '操作日志';
        break;
    case 'backup':
        $contentFile = 'backup.php';
        $subTitle = '数据备份';
        break;
    default:
        $contentFile = 'user.php';
        $subTitle = '用户管理';
}

// 检查文件是否存在
if (!file_exists($contentFile)) {
    $contentFile = 'user.php';
    $subTitle = '用户管理';
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $subTitle; ?> - <?php echo $pageTitle; ?> - <?php echo SITE_NAME; ?></title>
    <link rel="stylesheet" href="../../css/style.css">
</head>

<body>
    <header class="main-header">
        <div class="user-info">
            <span class="user-name"><?php echo isset($_SESSION['full_name']) ? $_SESSION['full_name'] : '用户'; ?></span>
            <span class="user-role"><?php echo $_SESSION['user_role']; ?></span>
        </div>

        <div class="site-title">
            <h1><?php echo SITE_NAME; ?></h1>
            <p><?php echo SITE_SUBTITLE; ?></p>
        </div>

        <div class="header-actions">
            <a href="../../logout.php" class="btn btn-logout">退出登录</a>
        </div>
    </header>

    <div class="module-layout">
        <aside class="module-sidebar">
            <div class="module-sidebar-header">
                <h2><?php echo $pageTitle; ?></h2>
            </div>

            <nav class="module-nav">
                <a href="../../home.php" class="module-nav-item">返回首页</a>
                <a href="index.php?page=user" class="module-nav-item <?php echo $page == 'user' ? 'active' : ''; ?>">用户管理</a>
                <a href="index.php?page=log" class="module-nav-item <?php echo $page == 'log' ? 'active' : ''; ?>">操作日志</a>
                <a href="index.php?page=backup" class="module-nav-item <?php echo $page == 'backup' ? 'active' : ''; ?>">数据备份</a>
            </nav>
        </aside>

        <main class="module-content">
            <div class="module-content-header">
                <h2><?php echo $subTitle; ?></h2>
            </div>
            <?php
            // 包含子页面内容
            if (file_exists($contentFile)) {
                include $contentFile;
            } else {
                echo "<div class='alert alert-error'>找不到页面文件: {$contentFile}</div>";
            }
            ?>
        </main>
    </div>

    <footer class="main-footer">
        <p>&copy; <?php echo date('Y'); ?> <?php echo SITE_NAME; ?> - 版权所有</p>
    </footer>
</body>

</html>